@@ -5,9 +5,6 @@ public static final int GL_INVALID_INDEX = 0xFFFFFFFF ;
 /** Part of <code>GL_ARB_sync</code> */
 public static final long GL_TIMEOUT_IGNORED = 0xFFFFFFFFFFFFFFFFL ;
 
-/** Part of <code>GL_ARB_shader_image_load_store</code> */
-public static final int GL_ALL_BARRIER_BITS = 0xFFFFFFFF ;
-
 public boolean isPBOPackBound();
 
 public boolean isPBOUnpackBound();
