@@ -18,10 +18,21 @@ function dump_versions() {
 }
 
 function do_it() {
-    dump_versions $1/nativewindow/classes
-    dump_versions $1/jogl/classes
-    dump_versions $1/newt/classes
-    dump_versions $1/test/build/classes
+    if [ -e $1/nativewindow/classes -a -e $1/jogl/classes -a -e $1/newt/classes -a -e $1/test/build/classes ] ; then
+        # regular build
+        dump_versions $1/nativewindow/classes
+        dump_versions $1/jogl/classes
+        dump_versions $1/newt/classes
+        dump_versions $1/test/build/classes
+    elif [ -e $1/com -a -e $1/gluegen -a -e $1/jogamp ] ; then
+        # inflated fat platform jar
+        dump_versions $1/com
+        dump_versions $1/gluegen
+        dump_versions $1/jogamp
+    else
+        echo "No class files as expected"
+        exit 1
+    fi
 }
 
 do_it $1 2>&1 | tee check-java-major-version.log
