@@ -309,12 +309,14 @@ fi
 
 }
 function gluegen_gl3es3() {
+# --logLevel INFO \
+# --debug \
+
 java \
 -classpath \
 ../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
 com.jogamp.gluegen.GlueGen \
---debug \
---dumpCPP \
+--logLevel INFO \
 -O../$rootrel/jogl \
 -Ecom.jogamp.gluegen.opengl.GLEmitter \
 -C./config/jogl/gl-if-gl3_es3.cfg \
@@ -349,8 +351,7 @@ java \
 -classpath \
 ../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
 com.jogamp.gluegen.GlueGen \
---debug \
---dumpCPP \
+--logLevel INFO \
 -O../$rootrel/jogl \
 -Ecom.jogamp.gluegen.opengl.GLEmitter \
 -C./config/jogl/gl-if-es3.cfg \
@@ -455,12 +456,14 @@ copy_temp
 }
 
 function gluegen_gl2gl3() {
+# --logLevel INFO \
+# --debug \
+
 java \
 -classpath \
 ../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
 com.jogamp.gluegen.GlueGen \
---debug \
---dumpCPP \
+--logLevel INFO \
 -O../$rootrel/jogl \
 -Ecom.jogamp.gluegen.opengl.GLEmitter \
 -C./config/jogl/gl-if-gl2gl3-subset.cfg \
@@ -493,8 +496,7 @@ java \
 -classpath \
 ../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
 com.jogamp.gluegen.GlueGen \
---debug \
---dumpCPP \
+--logLevel INFO \
 -O../$rootrel/jogl \
 -Ecom.jogamp.gluegen.opengl.GLEmitter \
 -C./config/jogl/gl-if-gl2_gl3.cfg \
@@ -525,7 +527,45 @@ copy_temp
 
 }
 
-function gluegen_gl4() {
+function gluegen_gl3() {
+# --logLevel INFO \
+# --debug \
+
+java \
+-classpath \
+../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
+com.jogamp.gluegen.GlueGen \
+--logLevel INFO \
+-O../$rootrel/jogl \
+-Ecom.jogamp.gluegen.opengl.GLEmitter \
+-C./config/jogl/gl-if-gl3.cfg \
+-Istub_includes/jni \
+-Istub_includes/jni/macosx \
+-Istub_includes/jni/win32 \
+-Istub_includes/jni/x11 \
+-Istub_includes/khr \
+-Istub_includes/khr/KD \
+-Istub_includes/khr/KHR \
+-Istub_includes/macosx \
+-Istub_includes/macosx/AppKit \
+-Istub_includes/macosx/OpenGL \
+-Istub_includes/macosx/QuartzCore \
+-Istub_includes/opengl \
+-Istub_includes/opengl/GL \
+-Istub_includes/opengl/GL3 \
+-Istub_includes/opengl/GLES \
+-Istub_includes/opengl/GLES2 \
+-Istub_includes/win32 \
+-Istub_includes/x11 \
+-Istub_includes/x11/X11 \
+-Istub_includes/x11/X11/extensions \
+-I../../gluegen/make/stub_includes/gluegen \
+stub_includes/opengl/gl3.c \
+
+copy_temp
+
+}
+function gluegen_gl3bc() {
 java \
 -classpath \
 ../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
@@ -534,6 +574,45 @@ com.jogamp.gluegen.GlueGen \
 --dumpCPP \
 -O../$rootrel/jogl \
 -Ecom.jogamp.gluegen.opengl.GLEmitter \
+-C./config/jogl/gl-gl3bc.cfg \
+-Istub_includes/jni \
+-Istub_includes/jni/macosx \
+-Istub_includes/jni/win32 \
+-Istub_includes/jni/x11 \
+-Istub_includes/khr \
+-Istub_includes/khr/KD \
+-Istub_includes/khr/KHR \
+-Istub_includes/macosx \
+-Istub_includes/macosx/AppKit \
+-Istub_includes/macosx/OpenGL \
+-Istub_includes/macosx/QuartzCore \
+-Istub_includes/opengl \
+-Istub_includes/opengl/GL \
+-Istub_includes/opengl/GL3 \
+-Istub_includes/opengl/GLES \
+-Istub_includes/opengl/GLES2 \
+-Istub_includes/win32 \
+-Istub_includes/x11 \
+-Istub_includes/x11/X11 \
+-Istub_includes/x11/X11/extensions \
+-I../../gluegen/make/stub_includes/gluegen \
+stub_includes/opengl/gl3bc.c \
+
+copy_temp
+
+}
+
+function gluegen_gl4() {
+# --logLevel INFO \
+# --debug \
+
+java \
+-classpath \
+../../gluegen/$rootrel/gluegen.jar:../$rootrel/jogl/gluegen-gl.jar \
+com.jogamp.gluegen.GlueGen \
+--logLevel INFO \
+-O../$rootrel/jogl \
+-Ecom.jogamp.gluegen.opengl.GLEmitter \
 -C./config/jogl/gl-if-gl4.cfg \
 -Istub_includes/jni \
 -Istub_includes/jni/macosx \
@@ -913,7 +992,9 @@ function gluegen_all() {
 #   gluegen_es3_impl
 #   gluegen_gl2
 #   gluegen_gl2gl3
-#   gluegen_gl4
+#   gluegen_gl3
+#   gluegen_gl3bc
+   gluegen_gl4
 #   gluegen_gl4bc
 #
 #   gluegen_egl
