@@ -1,7 +1,3 @@
-#! /bin/sh
-
-SDIR=$(readlink -f `dirname $0`)
-
 if [ -e ${SDIR}/../../../gluegen/make/scripts/setenv-build-jogamp-x86_64.sh ] ; then
     . ${SDIR}/../../../gluegen/make/scripts/setenv-build-jogamp-x86_64.sh
 fi
@@ -10,7 +6,6 @@ LOGF=make.jogl.all.android-aarch64-cross.log
 rm -f ${LOGF}
 
 export ANDROID_HOME=/opt-linux-x86_64/android-sdk-linux_x86_64
-export ANDROID_API_LEVEL=24
 export ANDROID_HOST_TAG=linux-x86_64
 export ANDROID_ABI=arm64-v8a
 
@@ -43,10 +38,6 @@ export TARGET_ADB_PORT=5555
 export TARGET_ROOT=/data/projects
 export TARGET_ANT_HOME=/usr/share/ant
 
-export SOURCE_LEVEL=1.8
-export TARGET_LEVEL=1.8
-export TARGET_RT_JAR=/opt-share/jre1.8.0_212/lib/rt.jar
-
 #export JUNIT_DISABLED="true"
 #export JUNIT_RUN_ARG0="-Dnewt.test.Screen.disableScreenMode"
 
