@@ -41,6 +41,7 @@ import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLRunnable;
 import com.jogamp.common.net.Uri;
+import com.jogamp.common.os.Clock;
 import com.jogamp.common.util.InterruptSource;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.GLRegion;
@@ -96,7 +97,7 @@ public class MovieCube implements GLEventListener {
     }
 
     /**
-     * Default constructor which also issues {@link #playStream(URI, int, int, int)} w/ default values
+     * Default constructor which also issues {@link #playStream(URI, int, int, int, int)} w/ default values
      * and polls until the {@link GLMediaPlayer} is {@link GLMediaPlayer.State#Initialized}.
      * If {@link GLMediaEventListener#EVENT_CHANGE_EOS} is reached, the stream is started over again.
      * <p>
@@ -107,9 +108,6 @@ public class MovieCube implements GLEventListener {
         this(zoom_def, 0f, 0f, true);
 
         mPlayer.addEventListener(new GLMediaEventListener() {
-            @Override
-            public void newFrameAvailable(final GLMediaPlayer ts, final TextureFrame newFrame, final long when) { }
-
             @Override
             public void attributesChanged(final GLMediaPlayer mp, final GLMediaPlayer.EventMask eventMask, final long when) {
                 System.err.println("MovieCube.0 AttributesChanges: "+eventMask+", when "+when);
@@ -132,7 +130,7 @@ public class MovieCube implements GLEventListener {
     }
 
     /**
-     * Custom constructor, user needs to issue {@link #playStream(URI, int, int, int)} afterwards.
+     * Custom constructor, user needs to issue {@link #playStream(URI, int, int, int, int)} afterwards.
      */
     public MovieCube(final float zoom0, final float rotx, final float roty, final boolean showText) throws IOException {
         this.zoom0 = zoom0;
@@ -144,7 +142,7 @@ public class MovieCube implements GLEventListener {
     }
 
     public void playStream(final Uri streamLoc, final int vid, final int aid, final int textureCount) {
-        mPlayer.playStream(streamLoc, vid, aid, textureCount);
+        mPlayer.playStream(streamLoc, vid, aid, GLMediaPlayer.STREAM_ID_NONE, textureCount);
         System.out.println("pC.1b "+mPlayer);
     }
 
@@ -156,8 +154,6 @@ public class MovieCube implements GLEventListener {
         resetGLState = true;
     }
 
-    final int[] textSampleCount = { 4 };
-
     private final class InfoTextRendererGLELBase extends TextRendererGLELBase {
         private static final float z_diff = 0.001f;
         private final Font font = getFont(0, 0, 0);
@@ -168,10 +164,10 @@ public class MovieCube implements GLEventListener {
 
         InfoTextRendererGLELBase(final GLProfile glp, final int rmode) {
             // FIXME: Graph TextRenderer does not AA well w/o MSAA and FBO
-            super(rmode, MovieCube.this.textSampleCount);
+            super(rmode, Region.DEFAULT_AA_SAMPLE_COUNT);
             this.setRendererCallbacks(RegionRenderer.defaultBlendEnable, RegionRenderer.defaultBlendDisable);
             regionFPS = GLRegion.create(glp, renderModes, null, 0, 0);
-            System.err.println("RegionFPS "+Region.getRenderModeString(renderModes)+", sampleCount "+textSampleCount[0]+", class "+regionFPS.getClass().getName());
+            System.err.println("RegionFPS "+Region.getRenderModeString(renderModes)+", sampleCount "+Region.DEFAULT_AA_SAMPLE_COUNT+", class "+regionFPS.getClass().getName());
             staticRGBAColor[0] = 0.1f;
             staticRGBAColor[1] = 0.1f;
             staticRGBAColor[2] = 0.1f;
@@ -214,8 +210,7 @@ public class MovieCube implements GLEventListener {
             final GLAnimatorControl anim = drawable.getAnimator();
             final float lfps = null != anim ? anim.getLastFPS() : 0f;
             final float tfps = null != anim ? anim.getTotalFPS() : 0f;
-            final boolean hasVideo = GLMediaPlayer.STREAM_ID_NONE != mPlayer.getVID();
-            final float pts = ( hasVideo ? mPlayer.getVideoPTS() : mPlayer.getAudioPTS() ) / 1000f;
+            final float pts = mPlayer.getPTS().getCurrent() / 1000f;
 
             // Note: MODELVIEW is from [ -1 .. 1 ]
 
@@ -296,7 +291,8 @@ public class MovieCube implements GLEventListener {
                 return;
             }
             System.err.println("MC "+e);
-            final int pts0 = GLMediaPlayer.STREAM_ID_NONE != mPlayer.getVID() ? mPlayer.getVideoPTS() : mPlayer.getAudioPTS();
+            final int pts0 = mPlayer.getPTS().getCurrent();
+
             int pts1 = 0;
             switch(e.getKeySymbol()) {
                 case KeyEvent.VK_V: {
@@ -316,7 +312,6 @@ public class MovieCube implements GLEventListener {
                 case KeyEvent.VK_LEFT:       pts1 = pts0 -  1000; break;
                 case KeyEvent.VK_DOWN:       pts1 = pts0 - 10000; break;
                 case KeyEvent.VK_PAGE_DOWN:  pts1 = pts0 - 30000; break;
-                case KeyEvent.VK_ESCAPE:
                 case KeyEvent.VK_HOME:
                 case KeyEvent.VK_BACK_SPACE: {
                     mPlayer.seek(0);
@@ -369,6 +364,13 @@ public class MovieCube implements GLEventListener {
                         printScreenOnGLThread(autoDrawable);
                     }
                     break;
+                case KeyEvent.VK_F4:
+                case KeyEvent.VK_ESCAPE:
+                case KeyEvent.VK_Q:
+                    if(null != autoDrawable) {
+                        MiscUtils.destroyWindow(autoDrawable);
+                    }
+                    break;
             }
 
             if( 0 != pts1 ) {
@@ -500,7 +502,8 @@ public class MovieCube implements GLEventListener {
         int aid = GLMediaPlayer.STREAM_ID_AUTO;
         final boolean origSize;
 
-        String url_s=null, file_s=null;
+        String url_s=null;
+        final String file_s=null;
         {
             boolean _origSize = false;
             for(int i=0; i<args.length; i++) {
@@ -524,9 +527,6 @@ public class MovieCube implements GLEventListener {
                 } else if(args[i].equals("-url")) {
                     i++;
                     url_s = args[i];
-                } else if(args[i].equals("-file")) {
-                    i++;
-                    file_s = args[i];
                 } else if(args[i].equals("-es2")) {
                     forceES2 = true;
                 } else if(args[i].equals("-es3")) {
@@ -544,16 +544,14 @@ public class MovieCube implements GLEventListener {
             }
             origSize = _origSize;
         }
-        final Uri streamLoc;
+        Uri streamLoc = null;
         if( null != url_s ) {
-            streamLoc = Uri.cast( url_s );
-        } else if( null != file_s ) {
-            streamLoc = Uri.valueOf(new File(file_s));
-        } else {
+            streamLoc = Uri.tryUriOrFile( url_s );
+        }
+        if( null == streamLoc ) {
             streamLoc = defURI;
         }
         System.err.println("url_s "+url_s);
-        System.err.println("file_s "+file_s);
         System.err.println("stream "+streamLoc);
         System.err.println("vid "+vid+", aid "+aid);
         System.err.println("textureCount "+textureCount);
@@ -596,10 +594,6 @@ public class MovieCube implements GLEventListener {
         anim.start();
 
         mc.mPlayer.addEventListener(new GLMediaEventListener() {
-            @Override
-            public void newFrameAvailable(final GLMediaPlayer ts, final TextureFrame newFrame, final long when) {
-            }
-
             @Override
             public void attributesChanged(final GLMediaPlayer mp, final GLMediaPlayer.EventMask event_mask, final long when) {
                 System.err.println("MovieCube.1 AttributesChanges: events_mask "+event_mask+", when "+when);
@@ -614,8 +608,7 @@ public class MovieCube implements GLEventListener {
                     anim.setUpdateFPSFrames(60, null);
                     anim.resetFPSCounter();
                     mc.resetGLState();
-                }
-                if( event_mask.isSet(GLMediaPlayer.EventMask.Bit.Play) ) {
+                } else if( event_mask.isSet(GLMediaPlayer.EventMask.Bit.Play) ) {
                     anim.resetFPSCounter();
                 }
                 if( event_mask.isSet(GLMediaPlayer.EventMask.Bit.EOS) ) {
@@ -632,11 +625,7 @@ public class MovieCube implements GLEventListener {
                     if( null != se ) {
                         se.printStackTrace();
                     }
-                    new InterruptSource.Thread() {
-                        @Override
-                        public void run() {
-                            window.destroy();
-                        } }.start();
+                    new InterruptSource.Thread( () -> { window.destroy(); } ).start();
                 }
             }
         });
