@@ -33,7 +33,9 @@ import java.io.IOException;
 import java.net.URI;
 import java.net.URISyntaxException;
 
+import com.jogamp.common.av.PTS;
 import com.jogamp.common.net.Uri;
+import com.jogamp.common.os.Clock;
 import com.jogamp.common.util.InterruptSource;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.GLRegion;
@@ -114,8 +116,6 @@ public class MovieSimple implements GLEventListener {
         defURI = _defURI;
     }
 
-    final int[] textSampleCount = { 4 };
-
     private final class InfoTextRendererGLELBase extends TextRendererGLELBase {
         private final Font font = getFont(0, 0, 0);
         private final float fontSize = 10f;
@@ -123,10 +123,10 @@ public class MovieSimple implements GLEventListener {
 
         InfoTextRendererGLELBase(final GLProfile glp, final int rmode) {
             // FIXME: Graph TextRenderer does not AA well w/o MSAA and FBO
-            super(rmode, textSampleCount);
+            super(rmode, Region.DEFAULT_AA_SAMPLE_COUNT);
             this.setRendererCallbacks(RegionRenderer.defaultBlendEnable, RegionRenderer.defaultBlendDisable);
             regionFPS = GLRegion.create(glp, renderModes, null, 0, 0);
-            System.err.println("RegionFPS "+Region.getRenderModeString(renderModes)+", sampleCount "+textSampleCount[0]+", class "+regionFPS.getClass().getName());
+            System.err.println("RegionFPS "+Region.getRenderModeString(renderModes)+", sampleCount "+Region.DEFAULT_AA_SAMPLE_COUNT+", class "+regionFPS.getClass().getName());
             staticRGBAColor[0] = 0.9f;
             staticRGBAColor[1] = 0.9f;
             staticRGBAColor[2] = 0.9f;
@@ -153,8 +153,10 @@ public class MovieSimple implements GLEventListener {
             final GLAnimatorControl anim = drawable.getAnimator();
             final float lfps = null != anim ? anim.getLastFPS() : 0f;
             final float tfps = null != anim ? anim.getTotalFPS() : 0f;
-            final boolean hasVideo = GLMediaPlayer.STREAM_ID_NONE != mPlayer.getVID();
-            final float pts = ( hasVideo ? mPlayer.getVideoPTS() : mPlayer.getAudioPTS() ) / 1000f;
+            final long currentMillis = Clock.currentMillis();
+            final PTS scr = mPlayer.getPTS();
+            final float pts_s = scr.get(currentMillis) / 1000f;
+            final float now = currentMillis / 1000f;
 
             // Note: MODELVIEW is from [ 0 .. height ]
 
@@ -163,8 +165,8 @@ public class MovieSimple implements GLEventListener {
             final float aspect = (float)mPlayer.getWidth() / (float)mPlayer.getHeight();
 
             final String ptsPrec = null != regionFPS ? "3.1" : "3.0";
-            final String text1 = String.format("%0"+ptsPrec+"f/%0"+ptsPrec+"f s, %s (%01.2fx, vol %01.2f), a %01.2f, fps %02.1f -> %02.1f / %02.1f, swap %d",
-                    pts, mPlayer.getDuration() / 1000f,
+            final String text1 = String.format("%0"+ptsPrec+"f/%0"+ptsPrec+"f/%0"+ptsPrec+"f s, %s (%01.2fx, vol %01.2f), a %01.2f, fps %02.1f -> %02.1f / %02.1f, swap %d",
+                    now, pts_s, mPlayer.getDuration() / 1000f,
                     mPlayer.getState().toString().toLowerCase(), mPlayer.getPlaySpeed(), mPlayer.getAudioVolume(),
                     aspect, mPlayer.getFramerate(), lfps, tfps, drawable.getGL().getSwapInterval());
             final String text2 = String.format("audio: id %d, kbps %d, codec %s",
@@ -216,6 +218,14 @@ public class MovieSimple implements GLEventListener {
     }
 
     private final MouseListener mouseAction = new MouseAdapter() {
+
+        @Override
+        public void mouseClicked(final MouseEvent e) {
+            if(null != autoDrawable && e.getClickCount() == 3 ) {
+                MiscUtils.destroyWindow(autoDrawable);
+            }
+        }
+
         @Override
         public void mousePressed(final MouseEvent e) {
             if(e.getY()<=surfHeight/2 && null!=mPlayer && 1 == e.getClickCount()) {
@@ -249,7 +259,7 @@ public class MovieSimple implements GLEventListener {
 
             if(y>surfHeight/2) {
                 final float dp  = (float)(x-prevMouseX)/(float)surfWidth;
-                final int pts0 = GLMediaPlayer.STREAM_ID_NONE != mPlayer.getVID() ? mPlayer.getVideoPTS() : mPlayer.getAudioPTS();
+                final int pts0 = mPlayer.getPTS().getCurrent();
                 mPlayer.seek(pts0 + (int) (mPlayer.getDuration() * dp));
             } else {
                 mPlayer.resume();
@@ -281,7 +291,7 @@ public class MovieSimple implements GLEventListener {
                 return;
             }
             System.err.println("MC "+e);
-            final int pts0 = GLMediaPlayer.STREAM_ID_NONE != mPlayer.getVID() ? mPlayer.getVideoPTS() : mPlayer.getAudioPTS();
+            final int pts0 = mPlayer.getPTS().getCurrent();
             int pts1 = 0;
             switch(e.getKeySymbol()) {
                 case KeyEvent.VK_V: {
@@ -301,9 +311,9 @@ public class MovieSimple implements GLEventListener {
                 case KeyEvent.VK_LEFT:       pts1 = pts0 -  1000; break;
                 case KeyEvent.VK_DOWN:       pts1 = pts0 - 10000; break;
                 case KeyEvent.VK_PAGE_DOWN:  pts1 = pts0 - 30000; break;
-                case KeyEvent.VK_ESCAPE:
                 case KeyEvent.VK_HOME:
                 case KeyEvent.VK_BACK_SPACE: {
+                    System.err.println("Seek: "+pts0+" -> 0");
                     mPlayer.seek(0);
                     break;
                 }
@@ -354,9 +364,17 @@ public class MovieSimple implements GLEventListener {
                         printScreenOnGLThread(autoDrawable);
                     }
                     break;
+                case KeyEvent.VK_F4:
+                case KeyEvent.VK_ESCAPE:
+                case KeyEvent.VK_Q:
+                    if(null != autoDrawable) {
+                        MiscUtils.destroyWindow(autoDrawable);
+                    }
+                    break;
             }
 
             if( 0 != pts1 ) {
+                System.err.println("Seek: "+pts0+" -> "+pts1);
                 mPlayer.seek(pts1);
             }
         } };
@@ -373,9 +391,6 @@ public class MovieSimple implements GLEventListener {
         this(null);
 
         mPlayer.addEventListener(new GLMediaEventListener() {
-            @Override
-            public void newFrameAvailable(final GLMediaPlayer ts, final TextureFrame newFrame, final long when) { }
-
             @Override
             public void attributesChanged(final GLMediaPlayer mp, final GLMediaPlayer.EventMask eventMask, final long when) {
                 System.err.println("MovieSimple.0 AttributesChanges: "+eventMask+", when "+when);
@@ -408,7 +423,7 @@ public class MovieSimple implements GLEventListener {
     }
 
     public void playStream(final Uri streamLoc, final int vid, final int aid, final int textureCount) {
-        mPlayer.playStream(streamLoc, vid, aid, textureCount);
+        mPlayer.playStream(streamLoc, vid, aid, GLMediaPlayer.STREAM_ID_NONE, textureCount);
         System.out.println("pC.1b "+mPlayer);
     }
 
@@ -564,17 +579,8 @@ public class MovieSimple implements GLEventListener {
 
     static class MyGLMediaEventListener implements GLMediaEventListener {
             void destroyWindow(final Window window) {
-                new InterruptSource.Thread() {
-                    @Override
-                    public void run() {
-                        window.destroy();
-                    } }.start();
+                new InterruptSource.Thread( () -> { window.destroy(); } ).start();
             }
-
-            @Override
-            public void newFrameAvailable(final GLMediaPlayer ts, final TextureFrame newFrame, final long when) {
-            }
-
             @Override
             public void attributesChanged(final GLMediaPlayer mp, final GLMediaPlayer.EventMask eventMask, final long when) {
                 System.err.println("MovieSimple.1 AttributesChanges: "+eventMask+", when "+when);
@@ -614,8 +620,7 @@ public class MovieSimple implements GLEventListener {
                             }
                         }.start();
                     */
-                }
-                if( eventMask.isSet(GLMediaPlayer.EventMask.Bit.Play) ) {
+                } else if( eventMask.isSet(GLMediaPlayer.EventMask.Bit.Play) ) {
                     window.getAnimator().resetFPSCounter();
                 }
 
@@ -664,6 +669,7 @@ public class MovieSimple implements GLEventListener {
 
     public static void main(final String[] args) throws IOException, URISyntaxException {
         int swapInterval = 1;
+        float playSpeed = 1.0f;
         int width = 800;
         int height = 600;
         int textureCount = 3; // default - threaded
@@ -676,22 +682,23 @@ public class MovieSimple implements GLEventListener {
         boolean forceGLDef = false;
         int vid = GLMediaPlayer.STREAM_ID_AUTO;
         int aid = GLMediaPlayer.STREAM_ID_AUTO;
+        float audioVolume = 1.0f;
 
         final int windowCount;
         {
-            int _windowCount = 1;
+            int _windowCount = 0;
             for(int i=0; i<args.length; i++) {
-                if(args[i].equals("-windows")) {
+                if(args[i].equals("-url")) {
                     i++;
-                    _windowCount = MiscUtils.atoi(args[i], _windowCount);
+                    _windowCount++;
                 }
             }
-            windowCount = _windowCount;
+            windowCount = Math.max(1, _windowCount);
         }
         final String[] urls_s = new String[windowCount];
-        String file_s1=null, file_s2=null;
         {
             boolean _origSize = false;
+            int url_idx = 0;
             for(int i=0; i<args.length; i++) {
                 if(args[i].equals("-vid")) {
                     i++;
@@ -721,45 +728,34 @@ public class MovieSimple implements GLEventListener {
                 } else if(args[i].equals("-vsync")) {
                     i++;
                     swapInterval = MiscUtils.atoi(args[i], swapInterval);
+                } else if(args[i].equals("-speed")) {
+                    i++;
+                    playSpeed = MiscUtils.atof(args[i], playSpeed);
+                } else if(args[i].equals("-mute")) {
+                    audioVolume = 0.0f;
                 } else if(args[i].equals("-projection")) {
                     ortho=false;
                 } else if(args[i].equals("-orig_scale")) {
                     useOrigScale=true;
                 } else if(args[i].equals("-loop")) {
                     loopEOS=true;
-                } else if(args[i].equals("-urlN")) {
-                    i++;
-                    final int n = MiscUtils.atoi(args[i], 0);
-                    i++;
-                    urls_s[n] = args[i];
                 } else if(args[i].equals("-url")) {
                     i++;
-                    urls_s[0] = args[i];
-                } else if(args[i].equals("-file1")) {
-                    i++;
-                    file_s1 = args[i];
-                } else if(args[i].equals("-file2")) {
-                    i++;
-                    file_s2 = args[i];
+                    urls_s[url_idx++] = args[i];
                 } else if(args[i].equals("-wait")) {
                     waitForKey = true;
                 }
             }
             origSize = _origSize;
         }
-        final Uri streamLoc0;
+        Uri streamLoc0 = null;
         if( null != urls_s[0] ) {
-            streamLoc0 = Uri.cast( urls_s[0] );
-        } else if( null != file_s1 ) {
-            final File movieFile = new File(file_s1);
-            streamLoc0 = Uri.valueOf(movieFile);
-        } else if( null != file_s2 ) {
-            streamLoc0 = Uri.valueOf(new File(file_s2));
-        } else {
+            streamLoc0 = Uri.tryUriOrFile( urls_s[0] );
+        }
+        if( null == streamLoc0 ) {
             streamLoc0 = defURI;
         }
         System.err.println("url_s "+urls_s[0]);
-        System.err.println("file_s 1: "+file_s1+", 2: "+file_s2);
         System.err.println("stream0 "+streamLoc0);
         System.err.println("vid "+vid+", aid "+aid);
         System.err.println("textureCount "+textureCount);
@@ -768,6 +764,8 @@ public class MovieSimple implements GLEventListener {
         System.err.println("forceGL3   "+forceGL3);
         System.err.println("forceGLDef "+forceGLDef);
         System.err.println("swapInterval "+swapInterval);
+        System.err.println("playSpeed "+playSpeed);
+        System.err.println("audioVolume "+audioVolume);
 
         final GLProfile glp;
         if(forceGLDef) {
@@ -801,6 +799,8 @@ public class MovieSimple implements GLEventListener {
             mss[i].setSwapInterval(swapInterval);
             mss[i].setUseOriginalScale(useOrigScale);
             mss[i].setOrthoProjection(ortho);
+            mss[i].mPlayer.setPlaySpeed(playSpeed);
+            mss[i].mPlayer.setAudioVolume(audioVolume);
             mss[i].mPlayer.attachObject(WINDOW_KEY, windows[i]);
             mss[i].mPlayer.addEventListener(myGLMediaEventListener);
 
@@ -810,13 +810,14 @@ public class MovieSimple implements GLEventListener {
             windows[i].setSize(width, height);
             windows[i].setVisible(true);
 
-            final Uri streamLocN;
+            Uri streamLocN = null;
             if( 0 == i ) {
                 streamLocN = streamLoc0;
             } else {
                 if( null != urls_s[i] ) {
-                    streamLocN = Uri.cast(urls_s[i]);
-                } else {
+                    streamLocN = Uri.tryUriOrFile( urls_s[i] );
+                }
+                if( null == streamLocN ) {
                     streamLocN = defURI;
                 }
             }
