@@ -24,7 +24,10 @@ import java.nio.FloatBuffer;
 
 import com.jogamp.common.nio.Buffers;
 import com.jogamp.common.util.VersionUtil;
-import com.jogamp.nativewindow.NativeWindow;
+import com.jogamp.math.Matrix4f;
+import com.jogamp.math.Quaternion;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.util.PMVMatrix4f;
 import com.jogamp.newt.Window;
 import com.jogamp.newt.event.GestureHandler;
 import com.jogamp.newt.event.GestureHandler.GestureEvent;
@@ -39,23 +42,16 @@ import com.jogamp.newt.event.WindowEvent;
 import com.jogamp.newt.opengl.GLWindow;
 import com.jogamp.opengl.GL;
 import com.jogamp.opengl.GL2ES2;
-import com.jogamp.opengl.GLAnimatorControl;
 import com.jogamp.opengl.GLAutoDrawable;
 import com.jogamp.opengl.GLCapabilities;
-import com.jogamp.opengl.GLProfile;
-import com.jogamp.opengl.GLRendererQuirks;
 import com.jogamp.opengl.GLUniformData;
 import com.jogamp.opengl.JoglVersion;
 import com.jogamp.opengl.demos.GearsObject;
 import com.jogamp.opengl.demos.util.CommandlineOptions;
 import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
-import com.jogamp.opengl.math.Matrix4f;
-import com.jogamp.opengl.math.Quaternion;
-import com.jogamp.opengl.math.Vec3f;
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.util.CustomGLEventListener;
 import com.jogamp.opengl.util.PMVMatrix;
-import com.jogamp.opengl.util.TileRendererBase;
 import com.jogamp.opengl.util.caps.NonFSAAGLCapsChooser;
 import com.jogamp.opengl.util.glsl.ShaderCode;
 import com.jogamp.opengl.util.glsl.ShaderProgram;
@@ -68,7 +64,7 @@ import com.jogamp.opengl.util.stereo.ViewerPose;
  * GearsES2.java <BR>
  * @author Brian Paul (converted to Java by Ron Cemer and Sven Gothel) <P>
  */
-public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRendererListener {
+public class GearsES2 implements StereoGLEventListener {
     private final FloatBuffer lightPos = Buffers.newDirectFloatBuffer( new float[] { 5.0f, 5.0f, 10.0f } );
 
     private ShaderState st = null;
@@ -76,29 +72,24 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
     private GLUniformData pmvMatrixUniform = null;
     private GLUniformData colorU = null;
     private volatile float view_rotx = 20.0f, view_roty = 30.0f;
-    private boolean flipVerticalInGLOrientation = false;
-    private final boolean customRendering = false;
 
     private final float view_rotz = 0.0f;
     private float panX = 0.0f, panY = 0.0f, panZ=0.0f;
+    private float scalexyz=1.0f;
+
     private volatile GearsObjectES2 gear1=null, gear2=null, gear3=null;
-    private GearsES2 sharedGears = null;
-    private Object syncObjects = null;
     private boolean useMappedBuffers = false;
     private boolean validateBuffers = false;
-    private volatile boolean usesSharedGears = false;
-    private FloatBuffer gear1Color=GearsObject.red, gear2Color=GearsObject.green, gear3Color=GearsObject.blue;
     private float angle = 0.0f;
     private int swapInterval = 0;
     // private MouseListener gearsMouse = new TraceMouseAdapter(new GearsMouseAdapter());
     public MouseListener gearsMouse = new GearsMouseAdapter();
     public KeyListener gearsKeys = new GearsKeyAdapter();
-    private TileRendererBase tileRendererInUse = null;
-    private boolean doRotateBeforePrinting;
 
     private boolean doRotate = true;
     private float[] clearColor = null;
     private boolean clearBuffers = true;
+    private boolean clearStencilBuffer = false;
     private boolean verbose = true;
     private volatile boolean isInit = false;
 
@@ -113,55 +104,45 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         this.swapInterval = 1;
     }
 
-    @Override
-    public void addTileRendererNotify(final TileRendererBase tr) {
-        tileRendererInUse = tr;
-        doRotateBeforePrinting = doRotate;
-        setDoRotation(false);
-    }
-    @Override
-    public void removeTileRendererNotify(final TileRendererBase tr) {
-        tileRendererInUse = null;
-        setDoRotation(doRotateBeforePrinting);
-    }
-    @Override
-    public void startTileRendering(final TileRendererBase tr) {
-        System.err.println("GearsES2.startTileRendering: "+sid()+""+tr);
-    }
-    @Override
-    public void endTileRendering(final TileRendererBase tr) {
-        System.err.println("GearsES2.endTileRendering: "+sid()+""+tr);
-    }
-
     public void setDoRotation(final boolean rotate) { this.doRotate = rotate; }
     public void setClearBuffers(final boolean v) { clearBuffers = v; }
+    public void setClearStencilBuffer(final boolean v) { clearStencilBuffer = v; }
     public void setVerbose(final boolean v) { verbose = v; }
-    public void setFlipVerticalInGLOrientation(final boolean v) { flipVerticalInGLOrientation=v; }
 
     /** float[4] */
     public void setClearColor(final float[] clearColor) {
         this.clearColor = clearColor;
     }
 
-    public void setGearsColors(final FloatBuffer gear1Color, final FloatBuffer gear2Color, final FloatBuffer gear3Color) {
-        this.gear1Color = gear1Color;
-        this.gear2Color = gear2Color;
-        this.gear3Color = gear3Color;
+    public void setGearsColor(final int idx, final float r, final float g, final float b, final float a) {
+        switch(idx) {
+            case -1:
+                gear1.setColor(r, g, b, a);
+                gear2.setColor(r, g, b, a);
+                gear3.setColor(r, g, b, a);
+                return;
+            case 0: gear1.setColor(r, g, b, a); return;
+            case 1: gear2.setColor(r, g, b, a); return;
+            case 2: gear3.setColor(r, g, b, a); return;
+            default: return;
+        }
+    }
+    public void resetGearsColor() {
+        gear1.setColor(GearsObject.red.get(0), GearsObject.red.get(1), GearsObject.red.get(2), GearsObject.red.get(3));
+        gear2.setColor(GearsObject.green.get(0), GearsObject.green.get(1), GearsObject.green.get(2), GearsObject.green.get(3));
+        gear3.setColor(GearsObject.blue.get(0), GearsObject.blue.get(1), GearsObject.blue.get(2), GearsObject.blue.get(3));
     }
 
-    public void setSharedGears(final GearsES2 shared) {
-        sharedGears = shared;
-    }
-
-    public void setSyncObjects(final Object sync) {
-        syncObjects = sync;
-    }
+    public float getScale() { return scalexyz; }
+    public void setScale(final float v) { scalexyz=v; }
 
     public float getRotX() { return view_rotx; }
     public float getRotY() { return view_roty; }
     public void setRotX(final float v) { view_rotx = v; }
     public void setRotY(final float v) { view_roty = v; }
 
+    public void addPanning(final float x, final float y, final float z) { panX += x; panY += y; panZ += z; }
+
     /**
      * @return gear1
      */
@@ -177,12 +158,10 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
      */
     public GearsObjectES2 getGear3() { return gear3; }
 
-    public boolean usesSharedGears() { return usesSharedGears; }
-
     public void setUseMappedBuffers(final boolean v) { useMappedBuffers = v; }
     public void setValidateBuffers(final boolean v) { validateBuffers = v; }
 
-    public PMVMatrix getPMVMatrix() {
+    public PMVMatrix4f getPMVMatrix() {
         return pmvMatrix;
     }
 
@@ -205,15 +184,9 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
 
     @Override
     public void init(final GLAutoDrawable drawable) {
-        if(null != sharedGears && !sharedGears.isInit() ) {
-            System.err.println(Thread.currentThread()+" GearsES2.init.0 "+sid()+": pending shared Gears .. re-init later XXXXX");
-            drawable.setGLEventListenerInitState(this, false);
-            return;
-        }
-
         final GL2ES2 gl = drawable.getGL().getGL2ES2();
         if(verbose) {
-            System.err.println(Thread.currentThread()+" GearsES2.init.0 "+sid()+": tileRendererInUse "+tileRendererInUse+", "+this);
+            System.err.println(Thread.currentThread()+" GearsES2.init.0 "+sid()+", "+this);
             System.err.println("GearsES2 init "+sid()+" on "+Thread.currentThread());
             System.err.println("Chosen GLCapabilities: " + drawable.getChosenGLCapabilities());
             System.err.println("INIT GL IS: " + gl.getClass().getName());
@@ -239,9 +212,9 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         // Use debug pipeline
         // drawable.setGL(new DebugGL(drawable.getGL()));
 
-        pmvMatrix = new PMVMatrix(PMVMatrix.INVERSE_MODELVIEW | PMVMatrix.INVERSE_TRANSPOSED_MODELVIEW);
+        pmvMatrix = new PMVMatrix(PMVMatrix4f.INVERSE_MODELVIEW | PMVMatrix4f.INVERSE_TRANSPOSED_MODELVIEW);
         st.attachObject("pmvMatrix", pmvMatrix);
-        pmvMatrixUniform = new GLUniformData("pmvMatrix", 4, 4, pmvMatrix.getSyncPMvMviMvitMat()); // P, Mv, Mvi and Mvit
+        pmvMatrixUniform = new GLUniformData("pmvMatrix", 4, 4, pmvMatrix.getSyncPMvMviMvit()); // P, Mv, Mvi and Mvit
         st.ownUniform(pmvMatrixUniform);
         st.uniform(gl, pmvMatrixUniform);
 
@@ -249,45 +222,25 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         st.ownUniform(lightU);
         st.uniform(gl, lightU);
 
-        colorU = new GLUniformData("color", 4, GearsObject.red);
+        colorU = new GLUniformData("color", 4, Buffers.newDirectFloatBuffer(4));
         st.ownUniform(colorU);
         st.uniform(gl, colorU);
 
-        if( null != sharedGears ) {
-            gear1 = new GearsObjectES2(sharedGears.getGear1(), st, pmvMatrix, pmvMatrixUniform, colorU);
-            gear2 = new GearsObjectES2(sharedGears.getGear2(), st, pmvMatrix, pmvMatrixUniform, colorU);
-            gear3 = new GearsObjectES2(sharedGears.getGear3(), st, pmvMatrix, pmvMatrixUniform, colorU);
-            usesSharedGears = true;
-            if(verbose) {
-                System.err.println("gear1 "+sid()+" created w/ share: "+sharedGears.getGear1()+" -> "+gear1);
-                System.err.println("gear2 "+sid()+" created w/ share: "+sharedGears.getGear2()+" -> "+gear2);
-                System.err.println("gear3 "+sid()+" created w/ share: "+sharedGears.getGear3()+" -> "+gear3);
-            }
-            if( gl.getContext().hasRendererQuirk(GLRendererQuirks.NeedSharedObjectSync) ) {
-                syncObjects = sharedGears;
-                System.err.println("Shared GearsES2: Synchronized Objects due to quirk "+GLRendererQuirks.toString(GLRendererQuirks.NeedSharedObjectSync));
-            } else if( null == syncObjects ) {
-                syncObjects = new Object();
-                System.err.println("Shared GearsES2: Unsynchronized Objects");
-            }
-        } else {
-            gear1 = new GearsObjectES2(gl, useMappedBuffers, st, gear1Color, 1.0f, 4.0f, 1.0f, 20, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
+        {
+            gear1 = new GearsObjectES2(gl, useMappedBuffers, st, GearsObject.red, 1.0f, 4.0f, 1.0f, 20, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
             if(verbose) {
                 System.err.println("gear1 "+sid()+" created: "+gear1);
             }
 
-            gear2 = new GearsObjectES2(gl, useMappedBuffers, st, gear2Color, 0.5f, 2.0f, 2.0f, 10, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
+            gear2 = new GearsObjectES2(gl, useMappedBuffers, st, GearsObject.green, 0.5f, 2.0f, 2.0f, 10, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
             if(verbose) {
                 System.err.println("gear2 "+sid()+" created: "+gear2);
             }
 
-            gear3 = new GearsObjectES2(gl, useMappedBuffers, st, gear3Color, 1.3f, 2.0f, 0.5f, 10, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
+            gear3 = new GearsObjectES2(gl, useMappedBuffers, st, GearsObject.blue, 1.3f, 2.0f, 0.5f, 10, 0.7f, pmvMatrix, pmvMatrixUniform, colorU, validateBuffers);
             if(verbose) {
                 System.err.println("gear3 "+sid()+" created: "+gear2);
             }
-            if( null == syncObjects ) {
-                syncObjects = new Object();
-            }
         }
 
         final Object upstreamWidget = drawable.getUpstreamWidget();
@@ -321,24 +274,6 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         }
     };
 
-    @Override
-    public void reshape(final GLAutoDrawable glad, final int x, final int y, final int width, final int height) {
-        if( !isInit ) { return; }
-        final GL2ES2 gl = glad.getGL().getGL2ES2();
-        gl.setSwapInterval(swapInterval);
-        reshapeImpl(gl, x, y, width, height, width, height);
-    }
-
-    @Override
-    public void reshapeTile(final TileRendererBase tr,
-                            final int tileX, final int tileY, final int tileWidth, final int tileHeight,
-                            final int imageWidth, final int imageHeight) {
-        if( !isInit ) { return; }
-        final GL2ES2 gl = tr.getAttachedDrawable().getGL().getGL2ES2();
-        gl.setSwapInterval(0);
-        reshapeImpl(gl, tileX, tileY, tileWidth, tileHeight, imageWidth, imageHeight);
-    }
-
     private float zNear = 5f;
     private float zFar = 10000f;
     private float zViewDist = 40.0f;
@@ -348,52 +283,42 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         this.zFar = zFar;
         this.zViewDist = zViewDist;
     }
+    public float getZNear() { return zNear; }
+    public float getZFar() { return zFar; }
+    public float getZViewDist() { return zViewDist; }
 
-    void reshapeImpl(final GL2ES2 gl, final int tileX, final int tileY, final int tileWidth, final int tileHeight, final int imageWidth, final int imageHeight) {
+    @Override
+    public void reshape(final GLAutoDrawable glad, final int x, final int y, final int width, final int height) {
+        if( !isInit ) { return; }
+        final GL2ES2 gl = glad.getGL().getGL2ES2();
         final boolean msaa = gl.getContext().getGLDrawable().getChosenGLCapabilities().getSampleBuffers();
         if(verbose) {
-            System.err.println(Thread.currentThread()+" GearsES2.reshape "+sid()+" "+tileX+"/"+tileY+" "+tileWidth+"x"+tileHeight+" of "+imageWidth+"x"+imageHeight+", swapInterval "+swapInterval+", drawable 0x"+Long.toHexString(gl.getContext().getGLDrawable().getHandle())+", msaa "+msaa+", tileRendererInUse "+tileRendererInUse);
+            System.err.println(Thread.currentThread()+" GearsES2.reshape "+sid()+" "+x+"/"+y+" "+width+"x"+height+", swapInterval "+swapInterval+
+                               ", drawable 0x"+Long.toHexString(gl.getContext().getGLDrawable().getHandle())+", msaa "+msaa);
         }
+        gl.setSwapInterval(swapInterval);
 
         if( !gl.hasGLSL() ) {
             return;
         }
 
-        // compute projection parameters 'normal'
-        float left, right, bottom, top;
-        if( imageHeight > imageWidth ) {
-            final float a = (float)imageHeight / (float)imageWidth;
-            left = -1.0f;
-            right = 1.0f;
-            bottom = -a;
-            top = a;
+        // compute projection parameters
+        float l, r, b, t;
+        if( height > width ) {
+            final float a = (float)height / (float)width;
+            l = -1.0f;
+            r = 1.0f;
+            b = -a;
+            t = a;
         } else {
-            final float a = (float)imageWidth / (float)imageHeight;
-            left = -a;
-            right = a;
-            bottom = -1.0f;
-            top = 1.0f;
+            final float a = (float)width / (float)height;
+            l = -a;
+            r = a;
+            b = -1.0f;
+            t = 1.0f;
         }
-        final float w = right - left;
-        final float h = top - bottom;
-
-        // compute projection parameters 'tiled'
-        final float l = left + tileX * w / imageWidth;
-        final float r = l + tileWidth * w / imageWidth;
-        final float b = bottom + tileY * h / imageHeight;
-        final float t = b + tileHeight * h / imageHeight;
-
-        final float _w = r - l;
-        final float _h = t - b;
-        if(verbose) {
-            System.err.println(">> GearsES2 "+sid()+", angle "+angle+", [l "+left+", r "+right+", b "+bottom+", t "+top+"] "+w+"x"+h+" -> [l "+l+", r "+r+", b "+b+", t "+t+"] "+_w+"x"+_h+", v-flip "+flipVerticalInGLOrientation);
-        }
-
         pmvMatrix.glMatrixMode(GLMatrixFunc.GL_PROJECTION);
         pmvMatrix.glLoadIdentity();
-        if( flipVerticalInGLOrientation && gl.getContext().getGLDrawable().isGLOriented() ) {
-            pmvMatrix.glScalef(1f, -1f, 1f);
-        }
         pmvMatrix.glFrustumf(l, r, b, t, zNear, zFar);
 
         pmvMatrix.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
@@ -424,13 +349,7 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
             //
             final Matrix4f mat4 = new Matrix4f();
             pmvMatrix.glMatrixMode(GLMatrixFunc.GL_PROJECTION);
-            if( flipVerticalInGLOrientation && gl.getContext().getGLDrawable().isGLOriented() ) {
-                mat4Tmp1.setToScale(1f, -1f, 1f);
-                mat4Tmp2.setToPerspective(eyeParam.fovhv, zNear, zFar);
-                mat4.mul(mat4Tmp1, mat4Tmp2);
-            } else {
-                mat4.setToPerspective(eyeParam.fovhv, zNear, zFar);
-            }
+            mat4.setToPerspective(eyeParam.fovhv, zNear, zFar);
             pmvMatrix.glLoadMatrixf(mat4);
 
             //
@@ -467,7 +386,7 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         if( !isInit ) { return; }
         isInit = false;
         if(verbose) {
-            System.err.println(Thread.currentThread()+" GearsES2.dispose "+sid()+": tileRendererInUse "+tileRendererInUse);
+            System.err.println(Thread.currentThread()+" GearsES2.dispose "+sid());
         }
         final Object upstreamWidget = drawable.getUpstreamWidget();
         if (upstreamWidget instanceof Window) {
@@ -493,8 +412,6 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         colorU = null;
         st.destroy(gl);
         st = null;
-        sharedGears = null;
-        syncObjects = null;
 
         if(verbose) {
             System.err.println(Thread.currentThread()+" GearsES2.dispose "+sid()+" FIN");
@@ -509,8 +426,6 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
     @Override
     public void display(final GLAutoDrawable drawable, final int flags) {
         if( !isInit ) { return; }
-        if(null != sharedGears && !sharedGears.isInit() ) { return; }
-        final GLAnimatorControl anim = drawable.getAnimator();
 
         final boolean repeatedFrame = 0 != ( CustomGLEventListener.DISPLAY_REPEAT & flags );
         final boolean dontClear = 0 != ( CustomGLEventListener.DISPLAY_DONTCLEAR & flags );
@@ -523,38 +438,32 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         // Get the GL corresponding to the drawable we are animating
         final GL2ES2 gl = drawable.getGL().getGL2ES2();
 
-        final boolean hasFocus;
-        final Object upstreamWidget = drawable.getUpstreamWidget();
-        if(upstreamWidget instanceof NativeWindow) {
-          hasFocus = ((NativeWindow)upstreamWidget).hasFocus();
-        } else {
-          hasFocus = true;
-        }
-
         if( clearBuffers && !dontClear ) {
             if( null != clearColor ) {
               gl.glClearColor(clearColor[0], clearColor[1], clearColor[2], clearColor[3]);
-            } else if( null != tileRendererInUse ) {
-              gl.glClearColor(1.0f, 1.0f, 1.0f, 0.0f);
             } else {
               gl.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
             }
-            gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
+            if( clearStencilBuffer ) {
+                gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT | GL.GL_STENCIL_BUFFER_BIT);
+            } else {
+                gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
+            }
         }
         if( !gl.hasGLSL() ) {
             return;
         }
 
-        setGLStates(gl, true);
+        setGLStatesImpl(gl, true);
 
         st.useProgram(gl, true);
         pmvMatrix.glPushMatrix();
         pmvMatrix.glTranslatef(panX, panY, panZ);
+        pmvMatrix.glScalef(scalexyz, scalexyz, scalexyz);
         pmvMatrix.glRotatef(view_rotx, 1.0f, 0.0f, 0.0f);
         pmvMatrix.glRotatef(view_roty, 0.0f, 1.0f, 0.0f);
         pmvMatrix.glRotatef(view_rotz, 0.0f, 0.0f, 1.0f);
-
-        synchronized ( syncObjects ) {
+        {
             gear1.draw(gl, -3.0f, -2.0f,  1f * angle -    0f);
             gear2.draw(gl,  3.1f, -2.0f, -2f * angle -  9.0f);
             gear3.draw(gl, -3.1f,  4.2f, -2f * angle - 25.0f);
@@ -562,12 +471,12 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         pmvMatrix.glPopMatrix();
         st.useProgram(gl, false);
 
-        setGLStates(gl, false);
+        setGLStatesImpl(gl, false);
     }
 
-    public void setGLStates(final GL2ES2 gl, final boolean enable) {
+    private void setGLStatesImpl(final GL2ES2 gl, final boolean enable) {
         // Culling only possible if we do not flip the projection matrix
-        final boolean useCullFace = ! ( flipVerticalInGLOrientation && gl.getContext().getGLDrawable().isGLOriented() || customRendering );
+        final boolean useCullFace = !gl.getContext().getGLDrawable().isGLOriented();
         if( enable ) {
             gl.glEnable(GL.GL_DEPTH_TEST);
             if( useCullFace ) {
@@ -583,7 +492,7 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
 
     @Override
     public String toString() {
-        return "GearsES2[obj "+sid()+" isInit "+isInit+", usesShared "+usesSharedGears+", 1 "+gear1+", 2 "+gear2+", 3 "+gear3+", sharedGears "+sharedGears+"]";
+        return "GearsES2[obj "+sid()+" isInit "+isInit+", 1 "+gear1+", 2 "+gear2+", 3 "+gear3+"]";
     }
 
     public KeyListener getKeyListener() { return this.gearsKeys; }
@@ -632,6 +541,7 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
                 // panning
                 panX -= rot[0]; // positive -> left
                 panY += rot[1]; // positive -> up
+                System.err.println("panXY.2: incr ("+rot[0]+", "+rot[1]+") -> ("+panX+", "+panY+")");
             }
         }
 
@@ -704,17 +614,10 @@ public class GearsES2 implements StereoGLEventListener, TileRendererBase.TileRen
         System.err.println(VersionUtil.getPlatformInfo());
         // System.err.println(JoglVersion.getAllAvailableCapabilitiesInfo(dpy.getGraphicsDevice(), null).toString());
 
-        final GLProfile glp = GLProfile.get(options.glProfileName);
-        System.err.println("GLProfile: "+glp);
-        final GLCapabilities caps = new GLCapabilities(glp);
-        caps.setAlphaBits(4);
-        if( options.sceneMSAASamples > 0 ) {
-            caps.setSampleBuffers(true);
-            caps.setNumSamples(options.sceneMSAASamples);
-        }
-        System.out.println("Requested: " + caps);
+        final GLCapabilities reqCaps = options.getGLCaps();
+        System.out.println("Requested: " + reqCaps);
 
-        final GLWindow window = GLWindow.create(caps);
+        final GLWindow window = GLWindow.create(reqCaps);
         if( 0 == options.sceneMSAASamples ) {
             window.setCapabilitiesChooser(new NonFSAAGLCapsChooser(false));
         }
