@@ -44,7 +44,6 @@ import com.jogamp.opengl.GL2ES2;
 import com.jogamp.opengl.GLAutoDrawable;
 import com.jogamp.opengl.GLCapabilities;
 import com.jogamp.opengl.GLEventListener;
-import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLUniformData;
 import com.jogamp.opengl.demos.util.CommandlineOptions;
 
@@ -143,8 +142,8 @@ public class LandscapeES2 implements GLEventListener {
 
         shaderState.useProgram(gl, true);
 
-        resolution[0] = drawable.getSurfaceWidth();
-        resolution[1] = drawable.getSurfaceHeight();
+        resolution[0] = width;
+        resolution[1] = height;
         shaderState.uniform(gl, resolutionUni);
 
         shaderState.useProgram(gl, false);
@@ -205,17 +204,10 @@ public class LandscapeES2 implements GLEventListener {
         System.err.println(VersionUtil.getPlatformInfo());
         // System.err.println(JoglVersion.getAllAvailableCapabilitiesInfo(dpy.getGraphicsDevice(), null).toString());
 
-        final GLProfile glp = GLProfile.get(options.glProfileName);
-        System.err.println("GLProfile: "+glp);
-        final GLCapabilities caps = new GLCapabilities(glp);
-        caps.setAlphaBits(4);
-        if( options.sceneMSAASamples > 0 ) {
-            caps.setSampleBuffers(true);
-            caps.setNumSamples(options.sceneMSAASamples);
-        }
-        System.out.println("Requested: " + caps);
+        final GLCapabilities reqCaps = options.getGLCaps();
+        System.out.println("Requested: " + reqCaps);
 
-        final GLWindow window = GLWindow.create(caps);
+        final GLWindow window = GLWindow.create(reqCaps);
         if( 0 == options.sceneMSAASamples ) {
             window.setCapabilitiesChooser(new NonFSAAGLCapsChooser(false));
         }
