@@ -38,8 +38,8 @@ import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLUniformData;
 import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
-
 import com.jogamp.common.os.Platform;
+import com.jogamp.math.FloatUtil;
 import com.jogamp.newt.Window;
 import com.jogamp.newt.event.MouseAdapter;
 import com.jogamp.newt.event.MouseEvent;
@@ -225,7 +225,7 @@ public class TextureSequenceCubeES2 implements GLEventListener {
 
         pmvMatrix = new PMVMatrix();
         reshapePMV(drawable.getSurfaceWidth(), drawable.getSurfaceHeight());
-        pmvMatrixUniform = new GLUniformData("mgl_PMVMatrix", 4, 4, pmvMatrix.getSyncPMvMat()); // P, Mv
+        pmvMatrixUniform = new GLUniformData("mgl_PMVMatrix", 4, 4, pmvMatrix.getSyncPMv()); // P, Mv
         if(!st.uniform(gl, pmvMatrixUniform)) {
             throw new GLException("Error setting PMVMatrix in shader: "+st);
         }
@@ -335,7 +335,7 @@ public class TextureSequenceCubeES2 implements GLEventListener {
             pmvMatrix.glMatrixMode(GLMatrixFunc.GL_PROJECTION);
             pmvMatrix.glLoadIdentity();
             if(!innerCube) {
-                pmvMatrix.gluPerspective(45.0f, (float)width / (float)height, 1f, 10.0f);
+                pmvMatrix.gluPerspective(FloatUtil.QUARTER_PI, (float)width / (float)height, 1f, 10.0f);
                 nearPlaneNormalized = 1f/(100f-1f);
             } else {
                 pmvMatrix.glOrthof(-1.0f, 1.0f, -1.0f, 1.0f, 1.0f, 10.0f);
