@@ -35,7 +35,6 @@ import com.jogamp.opengl.GLAnimatorControl;
 import com.jogamp.opengl.GLAutoDrawable;
 import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLProfile;
-import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
 import com.jogamp.common.util.InterruptSource;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.GLRegion;
@@ -46,14 +45,13 @@ import com.jogamp.graph.font.Font;
 import com.jogamp.graph.font.FontFactory;
 import com.jogamp.graph.font.FontScale;
 import com.jogamp.graph.font.FontSet;
-import com.jogamp.graph.geom.plane.AffineTransform;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.util.PMVMatrix4f;
 import com.jogamp.newt.Window;
 import com.jogamp.newt.event.KeyEvent;
 import com.jogamp.newt.event.KeyListener;
 import com.jogamp.newt.opengl.GLWindow;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.geom.AABBox;
-import com.jogamp.opengl.util.PMVMatrix;
 
 /**
  *
@@ -81,7 +79,6 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
     boolean drawFPS = true;
     final float fontSizeFName = 10f;
     final float fontSizeFPS = 10f;
-    final int[] sampleCountFPS = new int[] { 8 };
     float fontSizeHead = 12f;
     float fontSizeCenter = 16f;
     float dpiV = 96;
@@ -150,17 +147,19 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
     Window upstream_window = null;
     StringBuilder userString = new StringBuilder(textX1);
     boolean userInput = false;
-    public GPUTextRendererListenerBase01(final GLProfile glp, final int renderModes, final int sampleCount, final boolean blending, final boolean debug, final boolean trace) {
+    public GPUTextRendererListenerBase01(final GLProfile glp, final int renderModes, final int aaQuality, final int sampleCount, final boolean blending, final boolean debug, final boolean trace) {
         // NOTE_ALPHA_BLENDING: We use alpha-blending
         super(RegionRenderer.create(blending ? RegionRenderer.defaultBlendEnable : null, blending ? RegionRenderer.defaultBlendDisable : null),
                                     renderModes, debug, trace);
-        this.getRenderer().setHintMask(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED);
+        this.getRenderer().setHintBits(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED);
         this.textRegionUtil = new TextRegionUtil(renderModes);
         this.regionFPS = GLRegion.create(glp, renderModes, null, 0, 0);
         this.regionHead = GLRegion.create(glp, renderModes, null, 0, 0);
         this.regionBottom = GLRegion.create(glp, renderModes, null, 0, 0);
         setFontSet(fontSet, FontSet.FAMILY_LIGHT, FontSet.STYLE_NONE);
-        setMatrix(0, 0, 0, 0f, sampleCount);
+        setMatrix(0, 0, 0, 0f);
+        getRenderer().setAAQuality(aaQuality);
+        getRenderer().setSampleCount(sampleCount);
     }
 
     void switchHeadBox() {
@@ -302,20 +301,21 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
         // final int[] view = new int[] { 0, 0, drawable.getWidth(),  drawable.getHeight() };
 
         final RegionRenderer renderer = getRenderer();
-        final PMVMatrix pmv = renderer.getMatrix();
-        pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-        pmv.glLoadIdentity();
+        final PMVMatrix4f pmv = renderer.getMatrix();
+        pmv.loadMvIdentity();
         renderer.setColorStatic(0.1f, 0.1f, 0.1f, 1.0f);
         final float pixelSizeFName = FontScale.toPixels(fontSizeFName, dpiV);
         final float pixelSizeHead = FontScale.toPixels(fontSizeHead, dpiV);
         final float mmSizeHead = pixelSizeHead / ppmmV;
         final float pixelSizeCenter = FontScale.toPixels(fontSizeCenter, dpiV);
         final float mmSizeCenter = pixelSizeCenter / ppmmV;
+        final int pass2AAQual = getRenderer().getAAQuality();
+        final int pass2Samples = getRenderer().getSampleCount();
 
         renderer.enable(gl, true);
 
         if( drawFPS ) {
-            pmv.glPushMatrix();
+            pmv.pushMv();
             final float pixelSizeFPS = FontScale.toPixels(fontSizeFPS, dpiV);
             final float lfps, tfps;
             final GLAnimatorControl animator = drawable.getAnimator();
@@ -326,68 +326,68 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
                 lfps = 0f;
                 tfps = 0f;
             }
-            final String modeS = Region.getRenderModeString(regionFPS.getRenderModes());
-            final String text = String.format("%03.1f/%03.1f fps, v-sync %d, dpiV %.2f %.2f px/mm, font[head %.1fpt %.2fpx %.2fmm, center %.1fpt %.2fpx %.2fmm], %s-samples[%d, this %d], blend %b, alpha %d",
+            final String modeS = Region.getRenderModeString(regionFPS.getRenderModes())+"-q"+pass2AAQual;
+            final String text = String.format("%03.1f/%03.1f fps, v-sync %d, dpiV %.2f %.2f px/mm, font[head %.1fpt %.2fpx %.2fmm, center %.1fpt %.2fpx %.2fmm], %s-samples[%d], blend %b, alpha %d",
                     lfps, tfps, gl.getSwapInterval(), dpiV, ppmmV,
                     fontSizeHead, pixelSizeHead, mmSizeHead,
                     fontSizeCenter, pixelSizeCenter, mmSizeCenter,
-                    modeS, getSampleCount()[0], sampleCountFPS[0],
-                    renderer.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED),
+                    modeS, pass2Samples,
+                    renderer.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED),
                     drawable.getChosenGLCapabilities().getAlphaBits());
 
             // bottom, half line up
-            pmv.glTranslatef(nearPlaneX0, nearPlaneY0+(nearPlaneS * pixelSizeFPS / 2f), nearPlaneZ0);
+            pmv.translateMv(nearPlaneX0, nearPlaneY0+(nearPlaneS * pixelSizeFPS / 2f), nearPlaneZ0);
             {
                 final float sxy = nearPlaneS * pixelSizeFPS;
-                pmv.glScalef(sxy, sxy, 1.0f);
+                pmv.scaleMv(sxy, sxy, 1.0f);
             }
             // No cache, keep region alive!
-            TextRegionUtil.drawString3D(gl, regionFPS.clear(gl), renderer, font, text, null, sampleCountFPS, tempT1, tempT2);
-            pmv.glPopMatrix();
+            TextRegionUtil.drawString3D(gl, regionFPS.clear(gl), renderer, font, text, null, tempT1, tempT2);
+            pmv.popMv();
         }
 
         // float dx = width - ( fontNameBox.getWidth() + font.getAdvanceWidth( Glyph.ID_SPACE ) ) * pixelSizeFName;
         float dx = width - ( fontNameBox.getWidth() + 2 * font.getAdvanceWidth( font.getGlyphID('X') ) ) * pixelSizeFName;
         float dy = height - fontNameBox.getHeight() * pixelSizeFName;
         {
-            pmv.glPushMatrix();
-            pmv.glTranslatef(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
+            pmv.pushMv();
+            pmv.translateMv(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
             {
                 final float sxy = nearPlaneS * pixelSizeFName;
-                pmv.glScalef(sxy, sxy, 1.0f);
+                pmv.scaleMv(sxy, sxy, 1.0f);
             }
             // System.err.printf("FontN: [%f %f] -> [%f %f]%n", dx, dy, nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy));
-            textRegionUtil.drawString3D(gl, renderer, font, fontName, null, getSampleCount());
-            pmv.glPopMatrix();
+            textRegionUtil.drawString3D(gl, renderer, font, fontName, null);
+            pmv.popMv();
         }
 
         dx  =  10f;
         dy += -fontNameBox.getHeight() * pixelSizeFName - 10f;
 
         if(null != headtext) {
-            pmv.glPushMatrix();
+            pmv.pushMv();
             // System.err.printf("Head: [%f %f] -> [%f %f]%n", dx, dy, nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy));
-            pmv.glTranslatef(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
+            pmv.translateMv(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
             {
                 final float sxy = nearPlaneS * pixelSizeHead;
-                pmv.glScalef(sxy, sxy, 1.0f);
+                pmv.scaleMv(sxy, sxy, 1.0f);
             }
             // pmv.glTranslatef(x0, y1, z0);
-            textRegionUtil.drawString3D(gl, renderer, font, headtext, null, getSampleCount());
-            pmv.glPopMatrix();
+            textRegionUtil.drawString3D(gl, renderer, font, headtext, null);
+            pmv.popMv();
         }
 
         dy += ( -headbox.getHeight() - font.getLineHeight() ) * pixelSizeCenter;
 
         {
-            pmv.glPushMatrix();
-            pmv.glTranslatef(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
+            pmv.pushMv();
+            pmv.translateMv(nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy), nearPlaneZ0);
             // System.err.printf("Bottom: [%f %f] -> [%f %f]%n", dx, dy, nearPlaneX0+(dx*nearPlaneSx), nearPlaneY0+(dy*nearPlaneSy));
-            pmv.glTranslatef(getXTran(), getYTran(), getZTran());
-            pmv.glRotatef(getAngle(), 0, 1, 0);
+            pmv.translateMv(getXTran(), getYTran(), getZTran());
+            pmv.rotateMv(getAngleRad(), 0, 1, 0);
             {
                 final float sxy = nearPlaneS * pixelSizeCenter;
-                pmv.glScalef(sxy, sxy, 1.0f);
+                pmv.scaleMv(sxy, sxy, 1.0f);
             }
             renderer.setColorStatic(0.9f, 0.0f, 0.0f, 1.0f);
 
@@ -396,18 +396,18 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
             }
             if(!userInput) {
                 if( bottomTextUseFrustum ) {
-                    TextRegionUtil.drawString3D(gl, regionBottom.clear(gl), renderer, font, text2, null, getSampleCount(), tempT1, tempT2);
+                    TextRegionUtil.drawString3D(gl, regionBottom.clear(gl), renderer, font, text2, null, tempT1, tempT2);
                 } else {
-                    textRegionUtil.drawString3D(gl, renderer, font, text2, null, getSampleCount());
+                    textRegionUtil.drawString3D(gl, renderer, font, text2, null);
                 }
             } else {
                 if( bottomTextUseFrustum ) {
-                    TextRegionUtil.drawString3D(gl, regionBottom.clear(gl), renderer, font, userString.toString(), null, getSampleCount(), tempT1, tempT2);
+                    TextRegionUtil.drawString3D(gl, regionBottom.clear(gl), renderer, font, userString.toString(), null, tempT1, tempT2);
                 } else {
-                    textRegionUtil.drawString3D(gl, renderer, font, userString.toString(), null, getSampleCount());
+                    textRegionUtil.drawString3D(gl, renderer, font, userString.toString(), null);
                 }
             }
-            pmv.glPopMatrix();
+            pmv.popMv();
         }
         renderer.enable(gl, false);
     }
@@ -441,7 +441,7 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
 
     public boolean nextFontSet() {
         try {
-            final int set = ( fontSet == FontFactory.UBUNTU ) ? FontFactory.JAVA : FontFactory.UBUNTU ;
+            final int set = ( fontSet == FontFactory.UBUNTU ) ? FontFactory.UBUNTU : FontFactory.UBUNTU ;
             final Font _font = FontFactory.get(set).getDefault();
             if(null != _font) {
                 fontSet = set;
@@ -488,7 +488,7 @@ public abstract class GPUTextRendererListenerBase01 extends GPURendererListenerB
     public boolean isUserInputMode() { return userInput; }
 
     void dumpMatrix(final boolean bbox) {
-        System.err.println("Matrix: " + getXTran() + "/" + getYTran() + " x"+getZTran() + " @"+getAngle() +" fontSize "+fontSizeCenter);
+        System.err.println("Matrix: " + getXTran() + "/" + getYTran() + " x"+getZTran() + " @"+getAngleDeg() +" fontSize "+fontSizeCenter);
         if(bbox) {
             System.err.println("bbox em: "+font.getMetricBounds(text2));
             System.err.println("bbox px: "+font.getMetricBounds(text2).scale( nearPlaneS * FontScale.toPixels(fontSizeCenter, dpiV) ) );
