@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -39,15 +39,9 @@ import com.jogamp.opengl.GLCapabilities;
 import com.jogamp.opengl.GLEventListener;
 import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLPipelineFactory;
-import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLRunnable;
 import com.jogamp.opengl.demos.graph.MSAATool;
-import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
-import com.jogamp.opengl.math.FloatUtil;
-import com.jogamp.opengl.math.Recti;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.Vec4f;
-import com.jogamp.opengl.math.geom.AABBox;
+import com.jogamp.opengl.demos.util.CommandlineOptions;
 import com.jogamp.common.util.InterruptSource;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.RegionRenderer;
@@ -55,10 +49,16 @@ import com.jogamp.graph.curve.opengl.TextRegionUtil;
 import com.jogamp.graph.font.Font;
 import com.jogamp.graph.font.FontFactory;
 import com.jogamp.graph.font.FontSet;
-import com.jogamp.graph.geom.plane.AffineTransform;
 import com.jogamp.graph.ui.Shape;
 import com.jogamp.graph.ui.shapes.Button;
 import com.jogamp.graph.ui.shapes.CrossHair;
+import com.jogamp.math.FloatUtil;
+import com.jogamp.math.Recti;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.Vec4f;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.util.PMVMatrix4f;
 import com.jogamp.newt.Window;
 import com.jogamp.newt.event.KeyAdapter;
 import com.jogamp.newt.event.KeyEvent;
@@ -70,7 +70,6 @@ import com.jogamp.newt.event.WindowEvent;
 import com.jogamp.newt.opengl.GLWindow;
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.util.GLReadBufferUtil;
-import com.jogamp.opengl.util.PMVMatrix;
 
 /**
  * Basic UIShape and Type Rendering demo.
@@ -87,34 +86,33 @@ public class UIShapeDemo01 implements GLEventListener {
     static final boolean DEBUG = false;
     static final boolean TRACE = false;
 
+    static CommandlineOptions options = new CommandlineOptions(1280, 720, Region.VBAA_RENDERING_BIT);
+
     public static void main(final String[] args) throws IOException {
         Font font = null;
-        final int width = 1280, height = 720;
-        if( 0 != args.length ) {
-            for(int i=0; i<args.length; i++) {
-                if(args[i].equals("-font")) {
-                    i++;
-                    font = FontFactory.get(new File(args[i]));
-                }
+        final int[] idx = { 0 };
+        for (idx[0] = 0; idx[0] < args.length; ++idx[0]) {
+            if( options.parse(args, idx) ) {
+                continue;
+            } else if(args[idx[0]].equals("-font")) {
+                idx[0]++;
+                font = FontFactory.get(new File(args[idx[0]]));
             }
         }
+        System.err.println(options);
         if( null == font ) {
             font = FontFactory.get(FontFactory.UBUNTU).get(FontSet.FAMILY_LIGHT, FontSet.STYLE_SERIF);
         }
         System.err.println("Font: "+font.getFullFamilyName());
 
-        final GLProfile glp = GLProfile.getGL2ES2();
-        final GLCapabilities caps = new GLCapabilities(glp);
-        caps.setAlphaBits(4);
-        System.out.println("Requested: " + caps);
+        final GLCapabilities reqCaps = options.getGLCaps();
+        System.out.println("Requested: " + reqCaps);
 
-        final int renderModes = Region.VBAA_RENDERING_BIT;
-
-        final GLWindow window = GLWindow.create(caps);
+        final GLWindow window = GLWindow.create(reqCaps);
         // window.setPosition(10, 10);
-        window.setSize(width, height);
+        window.setSize(options.surface_width, options.surface_height);
         window.setTitle(UIShapeDemo01.class.getSimpleName()+": "+window.getSurfaceWidth()+" x "+window.getSurfaceHeight());
-        final UIShapeDemo01 uiGLListener = new UIShapeDemo01(font, renderModes, DEBUG, TRACE);
+        final UIShapeDemo01 uiGLListener = new UIShapeDemo01(font, options.renderModes, DEBUG, TRACE);
         uiGLListener.attachInputListenerTo(window);
         window.addGLEventListener(uiGLListener);
         window.setVisible(true);
@@ -126,12 +124,9 @@ public class UIShapeDemo01 implements GLEventListener {
         window.addKeyListener(new KeyAdapter() {
             @Override
             public void keyPressed(final KeyEvent arg0) {
-                if(arg0.getKeyCode() == KeyEvent.VK_F4) {
-                    new InterruptSource.Thread() {
-                        @Override
-                        public void run() {
-                            window.destroy();
-                        } }.start();
+                final short keySym = arg0.getKeySymbol();
+                if( keySym == KeyEvent.VK_F4 || keySym == KeyEvent.VK_ESCAPE || keySym == KeyEvent.VK_Q ) {
+                    new InterruptSource.Thread( () -> { window.destroy(); } ).start();
                 }
             }
         });
@@ -177,6 +172,8 @@ public class UIShapeDemo01 implements GLEventListener {
         this.font = font;
         this.renderModes = renderModes;
         this.rRenderer = RegionRenderer.create(RegionRenderer.defaultBlendEnable, RegionRenderer.defaultBlendDisable);
+        this.rRenderer.setAAQuality(options.graphAAQuality);
+        this.rRenderer.setSampleCount(options.graphAASamples);
         this.debug = debug;
         this.trace = trace;
         this.screenshot = new GLReadBufferUtil(false, false);
@@ -184,7 +181,7 @@ public class UIShapeDemo01 implements GLEventListener {
         final float sz1_w = 1/8f;
         final float sz2 = 1/20f;
         button = new Button(renderModes, font, "Click me!", sz1_w, sz1_w/2f);
-        button.setLabelColor(0.0f,0.0f,0.0f);
+        button.setLabelColor(0.0f,0.0f,0.0f, 1.0f);
         /** Button defaults !
                 button.setLabelColor(1.0f,1.0f,1.0f);
                 button.setButtonColor(0.6f,0.6f,0.6f);
@@ -194,7 +191,7 @@ public class UIShapeDemo01 implements GLEventListener {
         System.err.println(button);
         crossHair = new CrossHair(renderModes, sz2, sz2, 1/1000f);
         crossHair.setColor(0f,0f,1f,1f);
-        crossHair.setEnabled(true);
+        crossHair.setVisible(true);
     }
 
     public final RegionRenderer getRegionRenderer() { return rRenderer; }
@@ -224,26 +221,23 @@ public class UIShapeDemo01 implements GLEventListener {
         // final GL2ES2 gl = drawable.getGL().getGL2ES2();
         // gl.glViewport(xstart, ystart, width, height);
 
-        rRenderer.reshapePerspective(45.0f, width, height, zNear, zFar);
+        rRenderer.reshapePerspective(FloatUtil.QUARTER_PI, width, height, zNear, zFar);
         // rRenderer.reshapeOrtho(width, height, zNear, zFar);
 
-        final PMVMatrix pmv = rRenderer.getMatrix();
-        pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-        pmv.glLoadIdentity();
-        pmv.glTranslatef(xTran, yTran, zTran);
+        final PMVMatrix4f pmv = rRenderer.getMatrix();
+        pmv.loadMvIdentity();
+        pmv.translateMv(xTran, yTran, zTran);
 
         if( drawable instanceof Window ) {
             ((Window)drawable).setTitle(UIShapeDemo01.class.getSimpleName()+": "+drawable.getSurfaceWidth()+" x "+drawable.getSurfaceHeight());
         }
     }
 
-    final int[] sampleCount = { 4 };
-
     private void drawShape(final GL2ES2 gl, final RegionRenderer renderer, final Shape shape) {
-        final PMVMatrix pmv = renderer.getMatrix();
-        pmv.glPushMatrix();
-        shape.setTransform(pmv);
-        shape.draw(gl, renderer, sampleCount);
+        final PMVMatrix4f pmv = renderer.getMatrix();
+        pmv.pushMv();
+        shape.applyMatToMv(pmv);
+        shape.draw(gl, renderer);
         if( once ) {
             System.err.println("draw.0: "+shape);
             final int[] winSize = shape.getSurfaceSize(pmv, renderer.getViewport(), new int[2]);
@@ -251,7 +245,7 @@ public class UIShapeDemo01 implements GLEventListener {
             final int[] winPos = shape.shapeToWinCoord(pmv, renderer.getViewport(), shape.getPosition(), new int[2]);
             System.err.println("draw.2: winCoord "+winPos[0]+" x "+winPos[1]);
         }
-        pmv.glPopMatrix();
+        pmv.popMv();
     }
 
     @Override
@@ -262,7 +256,7 @@ public class UIShapeDemo01 implements GLEventListener {
         gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
 
         final RegionRenderer renderer = getRegionRenderer();
-        final PMVMatrix pmv = renderer.getMatrix();
+        final PMVMatrix4f pmv = renderer.getMatrix();
         renderer.enable(gl, true);
         drawShape(gl, renderer, button);
         drawShape(gl, renderer, crossHair);
@@ -276,14 +270,14 @@ public class UIShapeDemo01 implements GLEventListener {
                 final float winZ = FloatUtil.getOrthoWinZ(orthoDist, zNear, zFar);
                 final Vec3f objCoord0 = new Vec3f();
                 final Vec3f objCoord1 = new Vec3f();
-                if( pmv.gluUnProject(glWinX, glWinY, winZ, renderer.getViewport(), objCoord0) ) {
+                if( pmv.mapWinToObj(glWinX, glWinY, winZ, renderer.getViewport(), objCoord0) ) {
                     if( once ) {
                         System.err.printf("winToObjCoord: win [%f, %f, %f] -> obj [%s]%n", glWinX, glWinY, winZ, objCoord0);
                     }
                 }
                 glWinX = drawable.getSurfaceWidth();
                 glWinY = drawable.getSurfaceHeight();
-                if( pmv.gluUnProject(glWinX, glWinY, winZ, renderer.getViewport(), objCoord1) ) {
+                if( pmv.mapWinToObj(glWinX, glWinY, winZ, renderer.getViewport(), objCoord1) ) {
                     if( once ) {
                         System.err.printf("winToObjCoord: win [%f, %f, %f] -> obj [%s]%n", glWinX, glWinY, winZ, objCoord1);
                     }
@@ -293,20 +287,20 @@ public class UIShapeDemo01 implements GLEventListener {
             final AABBox txt_box_em = font.getGlyphBounds(text, tempT1, tempT2);
             final float full_width_s = full_width_o / txt_box_em.getWidth();
             final float txt_scale = full_width_s/2f;
-            pmv.glPushMatrix();
-            pmv.glScalef(txt_scale, txt_scale, 1f);
-            pmv.glTranslatef(-txt_box_em.getWidth(), 0f, 0f);
-            final AABBox txt_box_r = TextRegionUtil.drawString3D(gl, renderModes, renderer, font, text, new Vec4f( 0, 0, 0, 1 ), sampleCount, tempT1, tempT2);
+            pmv.pushMv();
+            pmv.scaleMv(txt_scale, txt_scale, 1f);
+            pmv.translateMv(-txt_box_em.getWidth(), 0f, 0f);
+            final AABBox txt_box_r = TextRegionUtil.drawString3D(gl, renderModes, renderer, font, text, new Vec4f( 0, 0, 0, 1 ));
             if( once ) {
                 final AABBox txt_box_em2 = font.getGlyphShapeBounds(null, text);
                 System.err.println("XXX: full_width: "+full_width_o+" / "+txt_box_em.getWidth()+" -> "+full_width_s);
                 System.err.println("XXX: txt_box_em "+txt_box_em);
                 System.err.println("XXX: txt_box_e2 "+txt_box_em2);
                 System.err.println("XXX: txt_box_rg "+txt_box_r);
-                once = false;
             }
-            pmv.glPopMatrix();
+            pmv.popMv();
         }
+        once = false;
         renderer.enable(gl, false);
     }
     static boolean once = true;
@@ -387,10 +381,9 @@ public class UIShapeDemo01 implements GLEventListener {
                     System.err.println("\n\nMouse: "+e);
 
                     final RegionRenderer renderer = getRegionRenderer();
-                    final PMVMatrix pmv = renderer.getMatrix();
-                    pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-                    pmv.glLoadIdentity();
-                    pmv.glTranslatef(xTran, yTran, zTran);
+                    final PMVMatrix4f pmv = renderer.getMatrix();
+                    pmv.loadMvIdentity();
+                    pmv.translateMv(xTran, yTran, zTran);
 
                     // flip to GL window coordinates, origin bottom-left
                     final Recti viewport = renderer.getViewport(new Recti());
@@ -398,8 +391,8 @@ public class UIShapeDemo01 implements GLEventListener {
                     final int glWinY = viewport.height() - e.getY() - 1;
 
                     {
-                        pmv.glPushMatrix();
-                        button.setTransform(pmv);
+                        pmv.pushMv();
+                        button.applyMatToMv(pmv);
 
                         System.err.println("\n\nButton: "+button);
                         final Vec3f objPos = button.winToShapeCoord(pmv, viewport, glWinX, glWinY, new Vec3f());
@@ -412,11 +405,11 @@ public class UIShapeDemo01 implements GLEventListener {
                             System.err.println("Button: Size: Pixel "+surfaceSize[0]+" x "+surfaceSize[1]);
                         }
 
-                        pmv.glPopMatrix();
+                        pmv.popMv();
                     }
                     {
-                        pmv.glPushMatrix();
-                        crossHair.setTransform(pmv);
+                        pmv.pushMv();
+                        crossHair.applyMatToMv(pmv);
 
                         final Vec3f objPosC = crossHair.getBounds().getCenter();
                         System.err.println("\n\nCrossHair: "+crossHair);
@@ -431,7 +424,7 @@ public class UIShapeDemo01 implements GLEventListener {
                             // final float[] translate = crossHair.getTranslate();
                             // final float[] objPosT = new float[] { objPosC[0]+translate[0], objPosC[1]+translate[1], objPosC[2]+translate[2] };
                             final Vec3f diff = winObjPos.minus(objPosC);
-                            if( !FloatUtil.isZero(diff.x(), FloatUtil.EPSILON) || !FloatUtil.isZero(diff.y(), FloatUtil.EPSILON) ) {
+                            if( !FloatUtil.isZero(diff.x()) || !FloatUtil.isZero(diff.y()) ) {
                                 System.err.println("CrossHair: Move.1: Win "+glWinX+"/"+glWinY+" -> Obj "+winObjPos+" -> diff "+diff);
                                 crossHair.move(diff.x(), diff.y(), 0f);
                             } else {
@@ -442,7 +435,7 @@ public class UIShapeDemo01 implements GLEventListener {
                         final int[] surfaceSize = crossHair.getSurfaceSize(pmv, viewport, new int[2]);
                         System.err.println("CrossHair: Size: Pixel "+surfaceSize[0]+" x "+surfaceSize[1]);
 
-                        pmv.glPopMatrix();
+                        pmv.popMv();
                     }
                     return true;
                 } } );
@@ -493,12 +486,12 @@ public class UIShapeDemo01 implements GLEventListener {
                 button.move(button.getWidth()/10f, 0f, 0f);
             }
             else if(arg0.getKeyCode() == KeyEvent.VK_4){
-                button.setSpacing(button.getSpacingX()-0.01f, button.getSpacingY()-0.005f);
-                System.err.println("Button Spacing: " + button.getSpacingX());
+                button.setSpacing(button.getSpacing().x()-0.01f, button.getSpacing().y()-0.005f);
+                System.err.println("Button Spacing: " + button.getSpacing());
             }
             else if(arg0.getKeyCode() == KeyEvent.VK_5){
-                button.setSpacing(button.getSpacingX()+0.01f, button.getSpacingY()+0.005f);
-                System.err.println("Button Spacing: " + button.getSpacingX());
+                button.setSpacing(button.getSpacing().x()+0.01f, button.getSpacing().y()+0.005f);
+                System.err.println("Button Spacing: " + button.getSpacing());
             }
             else if(arg0.getKeyCode() == KeyEvent.VK_6){
                 button.setCorner(button.getCorner()-0.01f);
