@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -39,10 +39,17 @@ import com.jogamp.graph.font.Font;
 import com.jogamp.graph.font.Font.Glyph;
 import com.jogamp.graph.font.FontFactory;
 import com.jogamp.graph.font.FontSet;
-import com.jogamp.graph.geom.plane.AffineTransform;
+import com.jogamp.graph.ui.GraphShape;
 import com.jogamp.graph.ui.Shape;
 import com.jogamp.graph.ui.shapes.CrossHair;
 import com.jogamp.graph.ui.shapes.Rectangle;
+import com.jogamp.math.FloatUtil;
+import com.jogamp.math.Recti;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.Vec4f;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.util.PMVMatrix4f;
 import com.jogamp.newt.Window;
 import com.jogamp.newt.event.KeyAdapter;
 import com.jogamp.newt.event.KeyEvent;
@@ -65,16 +72,10 @@ import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.GLRunnable;
 import com.jogamp.opengl.demos.graph.MSAATool;
 import com.jogamp.opengl.demos.graph.ui.testshapes.Glyph03FreeMonoRegular_M;
+import com.jogamp.opengl.demos.util.CommandlineOptions;
 import com.jogamp.opengl.demos.util.MiscUtils;
-import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
-import com.jogamp.opengl.math.FloatUtil;
-import com.jogamp.opengl.math.Recti;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.Vec4f;
-import com.jogamp.opengl.math.geom.AABBox;
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.util.GLReadBufferUtil;
-import com.jogamp.opengl.util.PMVMatrix;
 
 /**
  * Basic UIShape and Type Rendering demo.
@@ -91,25 +92,28 @@ public class UITypeDemo01 implements GLEventListener {
     static final boolean DEBUG = false;
     static final boolean TRACE = false;
 
+    static CommandlineOptions options = new CommandlineOptions(1280, 720, Region.VBAA_RENDERING_BIT);
+
     public static void main(final String[] args) throws IOException {
-        Font font = null;
-        final int width = 1280, height = 720;
         String text = "Hello Origin.";
+        Font font = null;
         int glyph_id = Glyph.ID_UNKNOWN;
-        if( 0 != args.length ) {
-            for(int i=0; i<args.length; i++) {
-                if(args[i].equals("-font")) {
-                    i++;
-                    font = FontFactory.get(new File(args[i]));
-                } else if(args[i].equals("-text")) {
-                    i++;
-                    text = args[i];
-                } else if(args[i].equals("-glyph")) {
-                    i++;
-                    glyph_id = MiscUtils.atoi(args[i], 0);
-                }
+        final int[] idx = { 0 };
+        for (idx[0] = 0; idx[0] < args.length; ++idx[0]) {
+            if( options.parse(args, idx) ) {
+                continue;
+            } else if(args[idx[0]].equals("-font")) {
+                idx[0]++;
+                font = FontFactory.get(new File(args[idx[0]]));
+            } else if(args[idx[0]].equals("-text")) {
+                idx[0]++;
+                text = args[idx[0]];
+            } else if(args[idx[0]].equals("-glyph")) {
+                idx[0]++;
+                glyph_id = MiscUtils.atoi(args[idx[0]], 0);
             }
         }
+        System.err.println(options);
         if( null == font ) {
             font = FontFactory.get(FontFactory.UBUNTU).get(FontSet.FAMILY_LIGHT, FontSet.STYLE_SERIF);
         }
@@ -121,13 +125,11 @@ public class UITypeDemo01 implements GLEventListener {
         caps.setAlphaBits(4);
         System.out.println("Requested: " + caps);
 
-        final int renderModes = Region.VBAA_RENDERING_BIT;
-
         final GLWindow window = GLWindow.create(caps);
         // window.setPosition(10, 10);
-        window.setSize(width, height);
+        window.setSize(options.surface_width, options.surface_height);
         window.setTitle(UITypeDemo01.class.getSimpleName()+": "+window.getSurfaceWidth()+" x "+window.getSurfaceHeight());
-        final UITypeDemo01 uiGLListener = new UITypeDemo01(font, glyph_id, text, renderModes, DEBUG, TRACE);
+        final UITypeDemo01 uiGLListener = new UITypeDemo01(font, glyph_id, text, options.renderModes, DEBUG, TRACE);
         uiGLListener.attachInputListenerTo(window);
         window.addGLEventListener(uiGLListener);
         window.setVisible(true);
@@ -139,12 +141,9 @@ public class UITypeDemo01 implements GLEventListener {
         window.addKeyListener(new KeyAdapter() {
             @Override
             public void keyPressed(final KeyEvent arg0) {
-                if(arg0.getKeyCode() == KeyEvent.VK_F4) {
-                    new InterruptSource.Thread() {
-                        @Override
-                        public void run() {
-                            window.destroy();
-                        } }.start();
+                final short keySym = arg0.getKeySymbol();
+                if( keySym == KeyEvent.VK_F4 || keySym == KeyEvent.VK_ESCAPE || keySym == KeyEvent.VK_Q ) {
+                    new InterruptSource.Thread( () -> { window.destroy(); } ).start();
                 }
             }
         });
@@ -169,7 +168,7 @@ public class UITypeDemo01 implements GLEventListener {
     private final boolean trace;
 
     private final CrossHair crossHair;
-    private final Shape testObj;
+    private final GraphShape testObj;
 
     private KeyAction keyAction;
     private MouseAction mouseAction;
@@ -196,13 +195,15 @@ public class UITypeDemo01 implements GLEventListener {
         this.glyph_id = glyph_id;
         this.renderModes = renderModes;
         this.rRenderer = RegionRenderer.create(RegionRenderer.defaultBlendEnable, RegionRenderer.defaultBlendDisable);
+        this.rRenderer.setAAQuality(options.graphAAQuality);
+        this.rRenderer.setSampleCount(options.graphAASamples);
         this.debug = debug;
         this.trace = trace;
         this.screenshot = new GLReadBufferUtil(false, false);
 
         crossHair = new CrossHair(renderModes, 1/20f, 1/20f, 1/1000f);
         crossHair.setColor(0f,0f,1f,1f);
-        crossHair.setEnabled(true);
+        crossHair.setVisible(true);
 
         if (false ) {
             final Rectangle o = new Rectangle(renderModes, 1/10f, 1/20f, 1/1000f);
@@ -211,13 +212,13 @@ public class UITypeDemo01 implements GLEventListener {
         } else {
             final float scale = 0.15312886f;
             final float size_xz = 0.541f;
-            final Shape o = new Glyph03FreeMonoRegular_M(renderModes);
+            final GraphShape o = new Glyph03FreeMonoRegular_M(renderModes);
             o.scale(scale, scale, 1f);
             // o.translate(size_xz, -size_xz, 0f);
             testObj = o;
         }
         testObj.setColor(0f,  0f,  0f,  1f);
-        testObj.setEnabled(true);
+        testObj.setVisible(true);
     }
 
     public final RegionRenderer getRegionRenderer() { return rRenderer; }
@@ -247,7 +248,7 @@ public class UITypeDemo01 implements GLEventListener {
         final GL2ES2 gl = drawable.getGL().getGL2ES2();
 
         gl.glViewport(xstart, ystart, width, height);
-        rRenderer.reshapePerspective(45.0f, width, height, zNear, zFar);
+        rRenderer.reshapePerspective(FloatUtil.QUARTER_PI, width, height, zNear, zFar);
         // rRenderer.reshapeOrtho(width, height, zNear, zFar);
 
         lastWidth = width;
@@ -258,13 +259,11 @@ public class UITypeDemo01 implements GLEventListener {
     }
     float lastWidth = 0f, lastHeight = 0f;
 
-    final int[] sampleCount = { 4 };
-
-    private void drawShape(final GL2ES2 gl, final PMVMatrix pmv, final RegionRenderer renderer, final Shape shape) {
-        pmv.glPushMatrix();
-        shape.setTransform(pmv);
-        shape.draw(gl, renderer, sampleCount);
-        pmv.glPopMatrix();
+    private void drawShape(final GL2ES2 gl, final PMVMatrix4f pmv, final RegionRenderer renderer, final Shape shape) {
+        pmv.pushMv();
+        shape.applyMatToMv(pmv);
+        shape.draw(gl, renderer);
+        pmv.popMv();
     }
 
     @Override
@@ -275,16 +274,15 @@ public class UITypeDemo01 implements GLEventListener {
         gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
 
         final RegionRenderer renderer = getRegionRenderer();
-        final PMVMatrix pmv = renderer.getMatrix();
-        pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-        pmv.glLoadIdentity();
-        pmv.glTranslatef(xTran, yTran, zTran);
+        final PMVMatrix4f pmv = renderer.getMatrix();
+        pmv.loadMvIdentity();
+        pmv.translateMv(xTran, yTran, zTran);
         renderer.enable(gl, true);
         {
-            pmv.glPushMatrix();
-            pmv.glScalef(0.8f, 0.8f, 1f);
+            pmv.pushMv();
+            pmv.scaleMv(0.8f, 0.8f, 1f);
             drawShape(gl, pmv, renderer, testObj);
-            pmv.glPopMatrix();
+            pmv.popMv();
         }
         drawShape(gl, pmv, renderer, crossHair);
         {
@@ -297,14 +295,14 @@ public class UITypeDemo01 implements GLEventListener {
                 final float winZ = FloatUtil.getOrthoWinZ(orthoDist, zNear, zFar);
                 final Vec3f objCoord0 = new Vec3f();
                 final Vec3f objCoord1 = new Vec3f();
-                if( pmv.gluUnProject(glWinX, glWinY, winZ, renderer.getViewport(), objCoord0) ) {
+                if( pmv.mapWinToObj(glWinX, glWinY, winZ, renderer.getViewport(), objCoord0) ) {
                     if( once ) {
                         System.err.printf("winToObjCoord: win [%f, %f, %f] -> obj [%s]%n", glWinX, glWinY, winZ, objCoord0);
                     }
                 }
                 glWinX = drawable.getSurfaceWidth();
                 glWinY = drawable.getSurfaceHeight();
-                if( pmv.gluUnProject(glWinX, glWinY, winZ, renderer.getViewport(), objCoord1) ) {
+                if( pmv.mapWinToObj(glWinX, glWinY, winZ, renderer.getViewport(), objCoord1) ) {
                     if( once ) {
                         System.err.printf("winToObjCoord: win [%f, %f, %f] -> obj [%s]%n", glWinX, glWinY, winZ, objCoord1);
                     }
@@ -312,7 +310,7 @@ public class UITypeDemo01 implements GLEventListener {
                 full_width_o = objCoord1.x() - objCoord0.x();
                 full_height_o = objCoord1.y() - objCoord0.y();
             }
-            pmv.glPushMatrix();
+            pmv.pushMv();
 
             final Font.Glyph glyph;
             if( Glyph.ID_UNKNOWN < glyph_id ) {
@@ -328,12 +326,12 @@ public class UITypeDemo01 implements GLEventListener {
                 final float full_width_s = full_width_o / txt_box_em.getWidth();
                 final float full_height_s = full_height_o / txt_box_em.getHeight();
                 final float txt_scale = full_width_s < full_height_s ? full_width_s/2f : full_height_s/2f;
-                pmv.glScalef(txt_scale, txt_scale, 1f);
-                pmv.glTranslatef(-txt_box_em.getWidth(), 0f, 0f);
+                pmv.scaleMv(txt_scale, txt_scale, 1f);
+                pmv.translateMv(-txt_box_em.getWidth(), 0f, 0f);
                 if( null != glyph.getShape() ) {
                     final GLRegion region = GLRegion.create(gl.getGLProfile(), renderModes, null, glyph.getShape());
                     region.addOutlineShape(glyph.getShape(), null, fg_color);
-                    region.draw(gl, renderer, sampleCount);
+                    region.draw(gl, renderer);
                     region.destroy(gl);
                 }
                 if( once ) {
@@ -349,9 +347,9 @@ public class UITypeDemo01 implements GLEventListener {
                 final float full_width_s = full_width_o / txt_box_em.getWidth();
                 final float full_height_s = full_height_o / txt_box_em.getHeight();
                 final float txt_scale = full_width_s < full_height_s ? full_width_s/2f : full_height_s/2f;
-                pmv.glScalef(txt_scale, txt_scale, 1f);
-                pmv.glTranslatef(-txt_box_em.getWidth(), 0f, 0f);
-                final AABBox txt_box_r = TextRegionUtil.drawString3D(gl, renderModes, renderer, font, text, fg_color, sampleCount, tempT1, tempT2);
+                pmv.scaleMv(txt_scale, txt_scale, 1f);
+                pmv.translateMv(-txt_box_em.getWidth(), 0f, 0f);
+                final AABBox txt_box_r = TextRegionUtil.drawString3D(gl, renderModes, renderer, font, text, fg_color, tempT1, tempT2);
                 if( once ) {
                     final AABBox txt_box_em2 = font.getGlyphShapeBounds(null, text);
                     System.err.println("XXX: full_width: "+full_width_o+" / "+txt_box_em.getWidth()+" -> "+full_width_s);
@@ -362,7 +360,7 @@ public class UITypeDemo01 implements GLEventListener {
                     System.err.println("XXX: txt_box_rg "+txt_box_r);
                 }
             }
-            pmv.glPopMatrix();
+            pmv.popMv();
             if( once ) {
                 try {
                     printScreen(drawable);
@@ -457,10 +455,9 @@ public class UITypeDemo01 implements GLEventListener {
                     System.err.println("\n\nMouse: "+e);
 
                     final RegionRenderer renderer = getRegionRenderer();
-                    final PMVMatrix pmv = renderer.getMatrix();
-                    pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-                    pmv.glLoadIdentity();
-                    pmv.glTranslatef(xTran, yTran, zTran);
+                    final PMVMatrix4f pmv = renderer.getMatrix();
+                    pmv.loadMvIdentity();
+                    pmv.translateMv(xTran, yTran, zTran);
 
                     // flip to GL window coordinates, origin bottom-left
                     final Recti viewport = renderer.getViewport(new Recti());
@@ -468,8 +465,8 @@ public class UITypeDemo01 implements GLEventListener {
                     final int glWinY = viewport.height() - e.getY() - 1;
 
                     {
-                        pmv.glPushMatrix();
-                        crossHair.setTransform(pmv);
+                        pmv.pushMv();
+                        crossHair.applyMatToMv(pmv);
 
                         final Vec3f objPosC = crossHair.getBounds().getCenter();
                         System.err.println("\n\nCrossHair: "+crossHair);
@@ -485,7 +482,7 @@ public class UITypeDemo01 implements GLEventListener {
                             // final float[] objPosT = new float[] { objPosC[0]+translate[0], objPosC[1]+translate[1], objPosC[2]+translate[2] };
                             final Vec3f diff = winObjPos.minus(objPosC);
                             // final float dz = winObjPos[2] - objPosT[2];
-                            if( !FloatUtil.isZero(diff.x(), FloatUtil.EPSILON) || !FloatUtil.isZero(diff.y(), FloatUtil.EPSILON) ) {
+                            if( !FloatUtil.isZero(diff.x()) || !FloatUtil.isZero(diff.y()) ) {
                                 System.err.println("CrossHair: Move.1: Win "+glWinX+"/"+glWinY+" -> Obj "+winObjPos+" -> diff "+diff);
                                 crossHair.move(diff.x(), diff.y(), 0f);
                             } else {
@@ -496,7 +493,7 @@ public class UITypeDemo01 implements GLEventListener {
                         final int[] surfaceSize = crossHair.getSurfaceSize(pmv, viewport, new int[2]);
                         System.err.println("CrossHair: Size: Pixel "+surfaceSize[0]+" x "+surfaceSize[1]);
 
-                        pmv.glPopMatrix();
+                        pmv.popMv();
                     }
                     return true;
                 } } );
