@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -27,6 +27,7 @@
  */
 package com.jogamp.graph.curve;
 
+import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
@@ -36,14 +37,16 @@ import com.jogamp.graph.curve.tess.Triangulator;
 import com.jogamp.graph.geom.Outline;
 import com.jogamp.graph.geom.Triangle;
 import com.jogamp.graph.geom.Vertex;
-import com.jogamp.graph.geom.plane.AffineTransform;
-import com.jogamp.graph.geom.plane.Path2F;
-import com.jogamp.graph.geom.plane.Winding;
-import com.jogamp.opengl.math.FloatUtil;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.VectorUtil;
-import com.jogamp.opengl.math.Vert2fImmutable;
-import com.jogamp.opengl.math.geom.AABBox;
+import com.jogamp.math.FloatUtil;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.VectorUtil;
+import com.jogamp.math.Vert2fImmutable;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.geom.plane.Path2F;
+import com.jogamp.math.geom.plane.Winding;
+
+import jogamp.opengl.Debug;
 
 /**
  * A Generic shape objects which is defined by a list of Outlines.
@@ -60,15 +63,16 @@ import com.jogamp.opengl.math.geom.AABBox;
  * <a name="windingrules">
  * Outline shape general {@link Winding} rules
  * <ul>
- *   <li>Outer boundary shapes are required as {@link Winding#CCW}, if unsure
+ *   <li>Outer boundary-shapes are required as {@link Winding#CCW}</li>
+ *   <li>Inner hole-shapes should be {@link Winding#CW}</li>
+ *   <li>If unsure
  *   <ul>
- *     <li>You may check {@link Winding} via {@link #getWindingOfLastOutline()} or {@link Outline#getWinding()} (optional)</li>
+ *     <li>You may check {@link Winding} via {@link #getWindingOfLastOutline()} or {@link Outline#getWinding()} (optional, might be incorrect)</li>
  *     <li>Use {@link #setWindingOfLastOutline(Winding)} before {@link #closeLastOutline(boolean)} or {@link #closePath()} } to enforce {@link Winding#CCW}, or</li>
  *     <li>use {@link Outline#setWinding(Winding)} on a specific {@link Outline} to enforce {@link Winding#CCW}.</li>
  *     <li>If e.g. the {@link Winding} has changed for an {@link Outline} by above operations, its vertices have been reversed.</li>
  *   </ul></li>
- *   <li>Inner shapes or holes are adjusted to be {@link Winding#CW}, no user consideration is required here.</li>
- *   <li>Safe path: Simply create all shapes with {@link Winding#CCW} or apply {@link Outline#setWinding(Winding)}.</li>
+ *   <li>Safe path: Simply create all outer boundary-shapes with {@link Winding#CCW} and inner hole-shapes with {@link Winding#CW}.</li>
  * </ul>
  * </p>
  * Example to creating an Outline Shape:
@@ -117,6 +121,9 @@ import com.jogamp.opengl.math.geom.AABBox;
  * @see Region
  */
 public final class OutlineShape implements Comparable<OutlineShape> {
+    private static final boolean FORCE_COMPLEXSHAPE = Debug.debug("graph.curve.triangulation.force.complexshape");
+    private static final boolean FORCE_SIMPLESHAPE = Debug.debug("graph.curve.triangulation.force.simpleshape");
+
     /**
      * Outline's vertices have undefined state until transformed.
      */
@@ -133,15 +140,20 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     /** Initial {@link #getSharpness()} value, which can be modified via {@link #setSharpness(float)}. */
     public static final float DEFAULT_SHARPNESS = 0.5f;
 
-    public static final int DIRTY_BOUNDS = 1 << 0;
+    private static final int DIRTY_BOUNDS = 1 << 0;
     /**
      * Modified shape, requires to update the vertices and triangles, here: vertices.
      */
-    public static final int DIRTY_VERTICES  = 1 << 1;
+    private static final int DIRTY_VERTICES  = 1 << 1;
     /**
      * Modified shape, requires to update the vertices and triangles, here: triangulation.
      */
-    public static final int DIRTY_TRIANGLES  = 1 << 2;
+    private static final int DIRTY_TRIANGLES  = 1 << 2;
+    /**
+     * Modified shape, requires to update the convex determination
+     */
+    private static final int DIRTY_CONVEX  = 1 << 3;
+    private static final int OVERRIDE_CONVEX  = 1 << 4;
 
     /** The list of {@link Outline}s that are part of this
      *  outline shape.
@@ -152,6 +164,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     private final ArrayList<Triangle> triangles;
     private final ArrayList<Vertex> vertices;
     private int addedVerticeCount;
+    private boolean complexShape;
 
     private VerticesState outlineState;
 
@@ -163,6 +176,10 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     private final Vec3f tmpV1 = new Vec3f();
     private final Vec3f tmpV2 = new Vec3f();
     private final Vec3f tmpV3 = new Vec3f();
+    // COLOR
+    // private final Vec4f tmpC1 = new Vec4f();
+    // private final Vec4f tmpC2 = new Vec4f();
+    // private final Vec4f tmpC3 = new Vec4f();
 
     /**
      * Create a new Outline based Shape
@@ -175,6 +192,11 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         this.triangles = new ArrayList<Triangle>();
         this.vertices = new ArrayList<Vertex>();
         this.addedVerticeCount = 0;
+        if( FORCE_COMPLEXSHAPE ) {
+            complexShape = true;
+        } else {
+            complexShape = false;
+        }
         this.dirtyBits = 0;
         this.sharpness = DEFAULT_SHARPNESS;
     }
@@ -208,6 +230,11 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         vertices.clear();
         triangles.clear();
         addedVerticeCount = 0;
+        if( FORCE_COMPLEXSHAPE ) {
+            complexShape = true;
+        } else {
+            complexShape = false;
+        }
         dirtyBits = 0;
     }
 
@@ -215,7 +242,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     public final void clearCache() {
         vertices.clear();
         triangles.clear();
-        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
     }
 
     /** Returns the number of {@link Outline}s. */
@@ -233,7 +260,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     }
 
     /**
-     * Compute the {@link Winding} of the {@link #getLastOutline()} using the {@link #area(ArrayList)} function over all of its vertices.
+     * Compute the {@link Winding} of the {@link #getLastOutline()} using the {@link VectorUtil#area(ArrayList)} function over all of its vertices.
      * @return {@link Winding#CCW} or {@link Winding#CW}
      */
     public final Winding getWindingOfLastOutline() {
@@ -247,6 +274,52 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         getLastOutline().setWinding(enforced);
     }
 
+    /**
+     * Returns cached or computed result if at least one {@code polyline} of {@link #getOutline(int)} is a complex shape, see {@link Outline#isComplex()}.
+     * <p>
+     * A polyline with less than 3 elements is marked a simple shape for simplicity.
+     * </p>
+     * <p>
+     * The result is cached.
+     * </p>
+     * @see #setOverrideConvex(boolean)
+     * @see #clearOverrideConvex()
+     */
+    public boolean isComplex() {
+        if( !FORCE_COMPLEXSHAPE && !FORCE_SIMPLESHAPE &&
+            0 == ( OVERRIDE_CONVEX & dirtyBits ) &&
+            0 != ( DIRTY_CONVEX & dirtyBits ) )
+        {
+            complexShape = false;
+            final int sz = this.getOutlineCount();
+            for(int i=0; i<sz && !complexShape; ++i) {
+                complexShape = getOutline(i).isComplex();
+            }
+            dirtyBits &= ~DIRTY_CONVEX;
+        }
+        return complexShape;
+    }
+    /**
+     * Overrides {@link #isComplex()} using the given value instead of computing via {@link Outline#isComplex()}.
+     * @see #clearOverrideConvex()
+     * @see #isComplex()
+     */
+    public void setOverrideConvex(final boolean convex) {
+        if( !FORCE_COMPLEXSHAPE && !FORCE_SIMPLESHAPE ) {
+            dirtyBits |= OVERRIDE_CONVEX;
+            complexShape = convex;
+        }
+    }
+    /**
+     * Clears the {@link #isComplex()} override done by {@link #setOverrideConvex(boolean)}
+     * @see #setOverrideConvex(boolean)
+     * @see #isComplex()
+     */
+    public void clearOverrideConvex() {
+        dirtyBits &= ~OVERRIDE_CONVEX;
+        dirtyBits |= DIRTY_CONVEX;
+    }
+
     /**
      * Add a new empty {@link Outline}
      * to the end of this shape's outline list.
@@ -302,7 +375,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
                     bbox.resize(outline.getBounds());
                 }
                 // vertices.addAll(outline.getVertices()); // FIXME: can do and remove DIRTY_VERTICES ?
-                dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+                dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
                 return;
             }
         }
@@ -310,7 +383,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         if( 0 == ( dirtyBits & DIRTY_BOUNDS ) ) {
             bbox.resize(outline.getBounds());
         }
-        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
     }
 
     /**
@@ -345,7 +418,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
             throw new NullPointerException("outline is null");
         }
         outlines.set(position, outline);
-        dirtyBits |= DIRTY_BOUNDS | DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_BOUNDS | DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
     }
 
     /**
@@ -356,7 +429,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * @throws IndexOutOfBoundsException if position is out of range (position < 0 || position >= getOutlineNumber())
      */
     public final Outline removeOutline(final int position) throws IndexOutOfBoundsException {
-        dirtyBits |= DIRTY_BOUNDS | DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_BOUNDS | DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
         return outlines.remove(position);
     }
 
@@ -390,7 +463,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
             bbox.resize(v.getCoord());
         }
         // vertices.add(v); // FIXME: can do and remove DIRTY_VERTICES ?
-        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
     }
 
     /**
@@ -406,7 +479,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         if( 0 == ( dirtyBits & DIRTY_BOUNDS ) ) {
             bbox.resize(v.getCoord());
         }
-        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+        dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
     }
 
     /**
@@ -502,15 +575,15 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * Closes the last outline in the shape.
      * <p>
      * Checks whether the last vertex equals to the first of the last outline.
-     * If not equal, it either appends a clone of the first vertex
-     * or prepends a clone of the last vertex, depending on <code>closeTail</code>.
+     * If not equal, it either appends a copy of the first vertex
+     * or prepends a copy of the last vertex, depending on <code>closeTail</code>.
      * </p>
-     * @param closeTail if true, a clone of the first vertex will be appended,
-     *                  otherwise a clone of the last vertex will be prepended.
+     * @param closeTail if true, a copy of the first vertex will be appended,
+     *                  otherwise a copy of the last vertex will be prepended.
      */
     public final void closeLastOutline(final boolean closeTail) {
         if( getLastOutline().setClosed( closeTail ) ) {
-            dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES;
+            dirtyBits |= DIRTY_TRIANGLES | DIRTY_VERTICES | DIRTY_CONVEX;
         }
     }
 
@@ -671,7 +744,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * @param y point (P1)
      * @param z point (P1)
      * @see Path2F#moveTo(float, float)
-     * @see #addPath(com.jogamp.graph.geom.plane.Path2F.Iterator, boolean)
+     * @see #addPath(com.jogamp.math.geom.plane.Path2F.Iterator, boolean)
      * @see <a href="#windingrules">see winding rules</a>
      */
     public final void moveTo(final float x, final float y, final float z) {
@@ -691,7 +764,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * @param y final point (P1)
      * @param z final point (P1)
      * @see Path2F#lineTo(float, float)
-     * @see #addPath(com.jogamp.graph.geom.plane.Path2F.Iterator, boolean)
+     * @see #addPath(com.jogamp.math.geom.plane.Path2F.Iterator, boolean)
      * @see <a href="#windingrules">see winding rules</a>
      */
     public final void lineTo(final float x, final float y, final float z) {
@@ -708,7 +781,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * @param y2 final interpolated control point (P2)
      * @param z2 quadratic parametric control point (P2)
      * @see Path2F#quadTo(float, float, float, float)
-     * @see #addPath(com.jogamp.graph.geom.plane.Path2F.Iterator, boolean)
+     * @see #addPath(com.jogamp.math.geom.plane.Path2F.Iterator, boolean)
      * @see <a href="#windingrules">see winding rules</a>
      */
     public final void quadTo(final float x1, final float y1, final float z1, final float x2, final float y2, final float z2) {
@@ -729,7 +802,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
      * @param y3 final interpolated control point (P3)
      * @param z3 final interpolated control point (P3)
      * @see Path2F#cubicTo(float, float, float, float, float, float)
-     * @see #addPath(com.jogamp.graph.geom.plane.Path2F.Iterator, boolean)
+     * @see #addPath(com.jogamp.math.geom.plane.Path2F.Iterator, boolean)
      * @see <a href="#windingrules">see winding rules</a>
      */
     public final void cubicTo(final float x1, final float y1, final float z1, final float x2, final float y2, final float z2, final float x3, final float y3, final float z3) {
@@ -741,7 +814,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     /**
      * Closes the current sub-path segment by drawing a straight line back to the coordinates of the last moveTo. If the path is already closed then this method has no effect.
      * @see Path2F#closePath()
-     * @see #addPath(com.jogamp.graph.geom.plane.Path2F.Iterator, boolean)
+     * @see #addPath(com.jogamp.math.geom.plane.Path2F.Iterator, boolean)
      */
     public final void closePath() {
         if ( 0 < getLastOutline().getVertexCount() ) {
@@ -767,9 +840,14 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     }
 
     private void subdivideTriangle(final Outline outline, final Vertex a, final Vertex b, final Vertex c, final int index){
-        VectorUtil.midVec3(tmpV1, a.getCoord(), b.getCoord());
-        VectorUtil.midVec3(tmpV3, b.getCoord(), c.getCoord());
-        VectorUtil.midVec3(tmpV2, tmpV1, tmpV3);
+        VectorUtil.midpoint(tmpV1, a.getCoord(), b.getCoord());
+        VectorUtil.midpoint(tmpV3, b.getCoord(), c.getCoord());
+        VectorUtil.midpoint(tmpV2, tmpV1, tmpV3);
+
+        // COLOR
+        // tmpC1.set(a.getColor()).add(b.getColor()).scale(0.5f);
+        // tmpC3.set(b.getColor()).add(b.getColor()).scale(0.5f);
+        // tmpC2.set(tmpC1).add(tmpC1).scale(0.5f);
 
         //drop off-curve vertex to image on the curve
         b.setCoord(tmpV2);
@@ -841,60 +919,24 @@ public final class OutlineShape implements Comparable<OutlineShape> {
             final Outline outline = getOutline(cc);
             final int vertexCount = outline.getVertexCount();
             for(int i=0; i < vertexCount; i++) {
-                final Vertex current = outline.getVertex(i);
-                if(current.isOnCurve() || current == a || current == b || current == c) {
-                    continue;
-                }
-                final Vertex nextV = outline.getVertex((i+1)%vertexCount);
-                final Vertex prevV = outline.getVertex((i+vertexCount-1)%vertexCount);
+                final Vertex currV = outline.getVertex(i);
+                if( !currV.isOnCurve() && currV != a && currV != b && currV != c) {
+                    final Vertex nextV = outline.getVertex((i+1)%vertexCount);
+                    final Vertex prevV = outline.getVertex((i+vertexCount-1)%vertexCount);
 
-                //skip neighboring triangles
-                if(prevV == c || nextV == a) {
-                    continue;
-                }
-
-                if( VectorUtil.isVec3InTriangle3(a.getCoord(), b.getCoord(), c.getCoord(),
-                                                 current.getCoord(), nextV.getCoord(), prevV.getCoord(),
-                                                 tmpV1, tmpV2, tmpV3) ) {
-                    return current;
-                }
-                if(VectorUtil.testTri2SegIntersection(a, b, c, prevV, current) ||
-                   VectorUtil.testTri2SegIntersection(a, b, c, current, nextV) ||
-                   VectorUtil.testTri2SegIntersection(a, b, c, prevV, nextV) ) {
-                    return current;
-                }
-            }
-        }
-        return null;
-    }
-    @SuppressWarnings("unused")
-    private Vertex checkTriOverlaps1(final Vertex a, final Vertex b, final Vertex c) {
-        final int count = getOutlineCount();
-        for (int cc = 0; cc < count; cc++) {
-            final Outline outline = getOutline(cc);
-            final int vertexCount = outline.getVertexCount();
-            for(int i=0; i < vertexCount; i++) {
-                final Vertex current = outline.getVertex(i);
-                if(current.isOnCurve() || current == a || current == b || current == c) {
-                    continue;
-                }
-                final Vertex nextV = outline.getVertex((i+1)%vertexCount);
-                final Vertex prevV = outline.getVertex((i+vertexCount-1)%vertexCount);
-
-                //skip neighboring triangles
-                if(prevV == c || nextV == a) {
-                    continue;
-                }
-
-                if( VectorUtil.isVec3InTriangle3(a.getCoord(), b.getCoord(), c.getCoord(),
-                                                 current.getCoord(), nextV.getCoord(), prevV.getCoord(),
-                                                 tmpV1, tmpV2, tmpV3, FloatUtil.EPSILON) ) {
-                    return current;
-                }
-                if(VectorUtil.testTri2SegIntersection(a, b, c, prevV, current, FloatUtil.EPSILON) ||
-                   VectorUtil.testTri2SegIntersection(a, b, c, current, nextV, FloatUtil.EPSILON) ||
-                   VectorUtil.testTri2SegIntersection(a, b, c, prevV, nextV, FloatUtil.EPSILON) ) {
-                    return current;
+                    //skip neighboring triangles
+                    if(prevV != c && nextV != a) {
+                        if( VectorUtil.isInTriangle3(a.getCoord(), b.getCoord(), c.getCoord(),
+                                                         currV.getCoord(), nextV.getCoord(), prevV.getCoord(),
+                                                         tmpV1, tmpV2, tmpV3) ) {
+                            return currV;
+                        }
+                        if(VectorUtil.testTri2SegIntersection(a, b, c, prevV, currV) ||
+                           VectorUtil.testTri2SegIntersection(a, b, c, currV, nextV) ||
+                           VectorUtil.testTri2SegIntersection(a, b, c, prevV, nextV) ) {
+                            return currV;
+                        }
+                    }
                 }
             }
         }
@@ -914,9 +956,10 @@ public final class OutlineShape implements Comparable<OutlineShape> {
                     final int j = (i+1)%vertexCount;
                     final Vertex nextVertex = outline.getVertex(j);
                     if ( !currentVertex.isOnCurve() && !nextVertex.isOnCurve() ) {
-                        VectorUtil.midVec3(tmpV1, currentVertex.getCoord(), nextVertex.getCoord());
+                        VectorUtil.midpoint(tmpV1, currentVertex.getCoord(), nextVertex.getCoord());
                         System.err.println("XXX: Cubic: "+i+": "+currentVertex+", "+j+": "+nextVertex);
                         final Vertex v = new Vertex(tmpV1, true);
+                        // COLOR: tmpC1.set(currentVertex.getColor()).add(nextVertex.getColor()).scale(0.5f)
                         i++;
                         vertexCount++;
                         addedVerticeCount++;
@@ -969,14 +1012,24 @@ public final class OutlineShape implements Comparable<OutlineShape> {
             dirtyBits &= ~DIRTY_VERTICES;
             // updated = true;
         // } else {
-        //    updated = false;
+        //     updated = false;
         }
-        // if(Region.DEBUG_INSTANCE) {
-        //    System.err.println("OutlineShape.getVertices(): o "+outlines.size()+", v "+vertices.size()+", updated "+updated);
-        // }
+        /**
+        if(Region.DEBUG_INSTANCE) {
+            System.err.println("OutlineShape.getVertices().X: "+vertices.size()+", updated "+updated);
+            if( updated ) {
+                int i=0;
+                for(final Vertex v : vertices) {
+                    System.err.printf("- [%d]: %s%n", i++, v);
+                }
+            }
+        } */
         return vertices;
     }
 
+    public static void printPerf(final PrintStream out) {
+        // jogamp.graph.curve.tess.Loop.printPerf(out);
+    }
     private void triangulateImpl() {
         if( 0 < outlines.size() ) {
             sortOutlines();
@@ -984,6 +1037,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
 
             triangles.clear();
             final Triangulator triangulator2d = Triangulation.create();
+            triangulator2d.setComplexShape( isComplex() );
             for(int index = 0; index<outlines.size(); index++) {
                 triangulator2d.addCurve(triangles, outlines.get(index), sharpness);
             }
@@ -1018,6 +1072,12 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         }
         if(Region.DEBUG_INSTANCE) {
             System.err.println("OutlineShape.getTriangles().X: "+triangles.size()+", updated "+updated);
+            if( updated ) {
+                int i=0;
+                for(final Triangle t : triangles) {
+                    System.err.printf("- [%d]: %s%n", i++, t);
+                }
+            }
         }
         return triangles;
     }
@@ -1060,7 +1120,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     public final int compareTo(final OutlineShape other) {
         final float thisSize = getBounds().getSize();
         final float otherSize = other.getBounds().getSize();
-        if( FloatUtil.isEqual(thisSize, otherSize, FloatUtil.EPSILON) ) {
+        if( FloatUtil.isEqual2(thisSize, otherSize) ) {
             return 0;
         } else if( thisSize < otherSize ){
             return -1;
@@ -1078,7 +1138,7 @@ public final class OutlineShape implements Comparable<OutlineShape> {
     }
 
     public final AABBox getBounds() {
-        if( 0 == ( dirtyBits & DIRTY_BOUNDS ) ) {
+        if( 0 != ( dirtyBits & DIRTY_BOUNDS ) ) {
             validateBoundingBox();
         }
         return bbox;
@@ -1125,4 +1185,17 @@ public final class OutlineShape implements Comparable<OutlineShape> {
         // Avoid calling this.hashCode() !
         return getClass().getName() + "@" + Integer.toHexString(super.hashCode());
     }
+
+    public void print(final PrintStream out) {
+        final int oc = getOutlineCount();
+        for (int oi = 0; oi < oc; oi++) {
+            final Outline outline = getOutline(oi);
+            final int vc = outline.getVertexCount();
+            out.printf("- OL[%d]: %s%n", vc, outline.getWinding());
+            for(int vi=0; vi < vc; vi++) {
+                final Vertex v = outline.getVertex(vi);
+                out.printf("-- OS[%d][%d]: %s%n", oi, vi, v);
+            }
+        }
+    }
 }
