@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -40,17 +40,17 @@ import jogamp.opengl.Debug;
 
 import com.jogamp.graph.geom.Triangle;
 import com.jogamp.graph.geom.Vertex;
-import com.jogamp.graph.geom.plane.AffineTransform;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.Vec4f;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.Frustum;
+import com.jogamp.math.geom.plane.AffineTransform;
 import com.jogamp.common.nio.Buffers;
 import com.jogamp.common.os.Clock;
 import com.jogamp.common.util.PerfCounterCtrl;
 import com.jogamp.graph.curve.opengl.GLRegion;
 import com.jogamp.opengl.GLCapabilitiesImmutable;
 import com.jogamp.opengl.GLProfile;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.Vec4f;
-import com.jogamp.opengl.math.geom.AABBox;
-import com.jogamp.opengl.math.geom.Frustum;
 import com.jogamp.opengl.util.texture.TextureSequence;
 
 /**
@@ -61,15 +61,20 @@ import com.jogamp.opengl.util.texture.TextureSequence;
  */
 public abstract class Region {
 
-    /** Debug flag for region impl (graph.curve) */
-    public static final boolean DEBUG = Debug.debug("graph.curve");
-    public static final boolean DEBUG_INSTANCE = Debug.debug("graph.curve.Instance");
+    public static final boolean DEBUG_ALL_EVENT = Debug.debugExplicit("graph.curve.AllEvent");
+    public static final boolean DEBUG_INSTANCE = Debug.debugExplicit("graph.curve.Instance");
+
+    /** Debug flag for [com.]jogamp.graph.curve.* incl. Region (graph.curve) */
+    public static final boolean DEBUG = DEBUG_ALL_EVENT || Debug.debug("graph.curve");
 
     /**
      * Rendering-Mode bit for {@link #getRenderModes() Region}
      * <p>
      * One pass `norm` rendering either using no AA or underlying full-screen AA (fsaa).
      * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
      */
     public static final int NORM_RENDERING_BIT        = 0;
 
@@ -77,9 +82,15 @@ public abstract class Region {
      * Rendering-Mode bit for {@link #getRenderModes() Region}
      * <p>
      * MSAA based Anti-Aliasing, a two pass region rendering, slower and more
-     * resource hungry (FBO), but providing fast MSAA in case
+     * resource hungry (FBO with sample buffer), but providing fast MSAA in case
      * the whole scene is not rendered with MSAA.
      * </p>
+     * <p>
+     * In case sample count is 1, no FBO sample buffer is used but a simple bilinear texture filter.
+     * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
      */
     public static final int MSAA_RENDERING_BIT        = 1 <<  0;
 
@@ -90,9 +101,22 @@ public abstract class Region {
      * resource hungry (FBO), but AA is perfect. Otherwise the default fast one
      * pass MSAA region rendering is being used.
      * </p>
+     * <p>
+     * In case sample count is 1, no FBO supersampling is performed but a simple bilinear texture filter used.
+     * </p>
+     * <p>
+     * Depending on AA-quality, {@link #MAX_AA_QUALITY} denotes full 4x billinear filtering per sample
+     * and {@code 0} denotes 1x flipquad filtering per sample.
+     * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
      */
     public static final int VBAA_RENDERING_BIT        = 1 <<  1;
 
+    /** 2-pass rendering bit-mask including {@link #MSAA_RENDERING_BIT} and {@link #VBAA_RENDERING_BIT}. */
+    public static final int AA_RENDERING_MASK         = MSAA_RENDERING_BIT | VBAA_RENDERING_BIT;
+
     /**
      * Rendering-Mode bit for {@link #getRenderModes() Region}
      * <p>
@@ -100,6 +124,9 @@ public abstract class Region {
      * Otherwise the default weight 1.0 for uniform curve region rendering is
      * being applied.
      * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
      */
     public static final int VARWEIGHT_RENDERING_BIT    = 1 <<  8;
 
@@ -110,6 +137,9 @@ public abstract class Region {
      * otherwise {@link com.jogamp.graph.curve.opengl.RegionRenderer#setColorStatic(com.jogamp.opengl.GL2ES2, float, float, float, float) static color}
      * can being used for a monotonic color.
      * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
      * @see #getRenderModes()
      * @see #hasColorChannel()
      * @see #addOutlineShape(OutlineShape, AffineTransform, float[])
@@ -120,13 +150,33 @@ public abstract class Region {
     /**
      * Rendering-Mode bit for {@link #getRenderModes() Region}
      * <p>
-     * If set, a color texture is used to determine the color.
+     * If set, a color texture is used to determine the color via {#link TextureSequence} passed to implementation, e.g. GLRegion.
      * </p>
+     * <p>
+     * This mode-bit is a shader-key.
+     * </p>
+     * @see TextureSequence#useARatioAdjustment()
+     * @see TextureSequence#useARatioLetterbox()
      */
     public static final int COLORTEXTURE_RENDERING_BIT = 1 <<  10;
 
-    /** Default maximum {@link #getQuality() quality}, {@value}. */
-    public static final int MAX_QUALITY  = 1;
+    /** Minimum pass2 AA-quality rendering {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link #VBAA_RENDERING_BIT}. */
+    public static final int MIN_AA_QUALITY  = 0;
+    /** Maximum pass2 AA-quality rendering {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link #VBAA_RENDERING_BIT}. */
+    public static final int MAX_AA_QUALITY  = 1;
+    /** Default pass2 AA-quality rendering {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link #VBAA_RENDERING_BIT}. */
+    public static final int DEFAULT_AA_QUALITY  = MAX_AA_QUALITY;
+    /** Returns clipped AA quality value to [{@link Region#MIN_AA_QUALITY}..{@link Region#MAX_AA_QUALITY}] */
+    public static final int clipAAQuality(final int v) { return Math.min(Region.MAX_AA_QUALITY, Math.max(v, Region.MIN_AA_QUALITY)); }
+
+    /** Minimum pass2 AA sample count {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link Region#VBAA_RENDERING_BIT} or {@link Region#MSAA_RENDERING_BIT}. */
+    public static final int MIN_AA_SAMPLE_COUNT  = 1;
+    /** Maximum pass2 AA sample count {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link Region#VBAA_RENDERING_BIT} or {@link Region#MSAA_RENDERING_BIT}. */
+    public static final int MAX_AA_SAMPLE_COUNT  = 8;
+    /** Default pass2 AA sample count {@value} for Graph Region AA {@link Region#getRenderModes() render-modes}: {@link #VBAA_RENDERING_BIT} or {@link Region#MSAA_RENDERING_BIT}. */
+    public static final int DEFAULT_AA_SAMPLE_COUNT = 4;
+    /** Returns clipped AA sample-count to [{@link Region#MIN_AA_SAMPLE_COUNT}..{@link Region#MAX_AA_SAMPLE_COUNT}] */
+    public static final int clipAASampleCount(final int v) { return Math.min(Region.MAX_AA_SAMPLE_COUNT, Math.max(v, Region.MIN_AA_SAMPLE_COUNT)); }
 
     public static final int DEFAULT_TWO_PASS_TEXTURE_UNIT = 0;
 
@@ -136,22 +186,32 @@ public abstract class Region {
     private final int renderModes;
     private final boolean use_int32_idx;
     private final int max_indices;
-    private int quality;
     private int dirty = DIRTY_SHAPE | DIRTY_STATE;
     private int numVertices = 0;
     protected final AABBox box = new AABBox();
     protected Frustum frustum = null;
 
+    public static final boolean isRenderModeSet(final int renderModes, final int mask) { return mask == ( renderModes & mask ); }
+    public static final int setRenderMode(int renderModes, final int mask, final boolean v) { if( v ) { renderModes |= mask; } else { renderModes &= ~mask; }; return renderModes; }
+
+    /** Returns true if given {@code renderModes} has {@link Region#VBAA_RENDERING_BIT} set. */
     public static boolean isVBAA(final int renderModes) {
         return 0 != (renderModes & Region.VBAA_RENDERING_BIT);
     }
 
+    /** Returns true if given {@code renderModes} has {@link Region#MSAA_RENDERING_BIT} set. */
     public static boolean isMSAA(final int renderModes) {
         return 0 != (renderModes & Region.MSAA_RENDERING_BIT);
     }
 
+    /** Returns true if given {@code renderModes} has any of {@link Region#AA_RENDERING_MASK} set. */
+    public static boolean isGraphAA(final int renderModes) {
+        return 0 != ( renderModes & Region.AA_RENDERING_MASK );
+    }
+
+    /** Returns true if given {@code renderModes} has any of {@link Region#AA_RENDERING_MASK} set. */
     public static boolean isTwoPass(final int renderModes) {
-        return 0 != ( renderModes & ( Region.VBAA_RENDERING_BIT | Region.MSAA_RENDERING_BIT) );
+        return 0 != ( renderModes & Region.AA_RENDERING_MASK );
     }
 
     /**
@@ -191,7 +251,12 @@ public abstract class Region {
     public static String getRenderModeString(final int renderModes) {
         final String curveS = hasVariableWeight(renderModes) ? "-curve" : "";
         final String cChanS = hasColorChannel(renderModes) ? "-cols" : "";
-        final String cTexS = hasColorTexture(renderModes) ? "-ctex" : "";
+        final String cTexS;
+        if( hasColorTexture(renderModes) ) {
+            cTexS = "-ctex";
+        } else {
+            cTexS = "";
+        }
         if( Region.isVBAA(renderModes) ) {
             return "vbaa"+curveS+cChanS+cTexS;
         } else if( Region.isMSAA(renderModes) ) {
@@ -204,15 +269,20 @@ public abstract class Region {
     /**
      * Return a unique technical description string for renderModes and sample counts as follows:
      * <pre>
-     *    {@link #getRenderModeString(int)}-s{sampleCount}-fsaa{CapsNumSamples}
+     *    {@link #getRenderModeString(int)}-q{AA-quality}-s{sampleCount}-fsaa{CapsNumSamples}
      * </pre>
      *
      * @param renderModes the used Graph renderModes, see {@link GLRegion#create(GLProfile, int, TextureSequence) create(..)}
+     * @param graphAAQuality Graph AA quality, see {@link #DEFAULT_AA_QUALITY}, set to negative value to mark undefined
      * @param graphSampleCount Graph sample count for {@link Region#VBAA_RENDERING_BIT} or {@link Region#MSAA_RENDERING_BIT}
      * @param fsaaSampleCount full-screen AA (fsaa) sample count, retrieved e.g. via {@link GLCapabilitiesImmutable#getNumSamples()}
      */
-    public static String getRenderModeString(final int renderModes, final int graphSampleCount, final int fsaaSampleCount) {
-        return String.format((Locale)null, "%s-s%02d-fsaa%d", Region.getRenderModeString(renderModes), graphSampleCount, fsaaSampleCount);
+    public static String getRenderModeString(final int renderModes, final int graphAAQuality, final int graphSampleCount, final int fsaaSampleCount) {
+        if( Region.MIN_AA_QUALITY > graphAAQuality ) {
+            return String.format((Locale)null, "%s-qu-s%02d-fsaa%d", Region.getRenderModeString(renderModes), graphSampleCount, fsaaSampleCount);
+        } else {
+            return String.format((Locale)null, "%s-q%01d-s%02d-fsaa%d", Region.getRenderModeString(renderModes), graphAAQuality, graphSampleCount, fsaaSampleCount);
+        }
     }
 
     protected Region(final int regionRenderModes, final boolean use_int32_idx) {
@@ -223,7 +293,6 @@ public abstract class Region {
         } else {
             this.max_indices = GL_UINT16_MAX;
         }
-        this.quality = MAX_QUALITY;
     }
 
     /** Print implementation buffer stats like detailed and total size and capacity in bytes etc */
@@ -274,18 +343,14 @@ public abstract class Region {
      */
     public final int getRenderModes() { return renderModes; }
 
-    /** See {@link #MAX_QUALITY} */
-    public final int getQuality() { return quality; }
-
-    /** See {@link #MAX_QUALITY} */
-    public final void setQuality(final int q) { quality=q; }
-
     protected final void clearImpl() {
         dirty = DIRTY_SHAPE | DIRTY_STATE;
         numVertices = 0;
         box.reset();
     }
 
+    public final boolean isRenderModeSet(final int mask) { return mask == ( renderModes & mask ); }
+
     /**
      * Returns true if capable of two pass rendering - VBAA, otherwise false.
      * @see #getRenderModes()
@@ -327,12 +392,12 @@ public abstract class Region {
      * i.e. the bit {@link #COLORTEXTURE_RENDERING_BIT} is set,
      * otherwise false.
      * @see #getRenderModes()
+     * @see #isColorTextureLetterbox()
      */
     public final boolean hasColorTexture() {
         return Region.hasColorTexture(renderModes);
     }
 
-
     /** See {@link #setFrustum(Frustum)} */
     public final Frustum getFrustum() { return frustum; }
 
@@ -344,6 +409,7 @@ public abstract class Region {
     }
 
     private void pushNewVertexImpl(final Vertex vertIn, final AffineTransform transform, final Vec4f rgba) {
+        // if(DEBUG_INSTANCE) { System.err.printf("pushVertex.0[%d]: v %s]%n", numVertices, vertIn); }
         if( null != transform ) {
             final Vec3f coordsEx1 = transform.transform(vertIn.getCoord(), new Vec3f());
             box.resize(coordsEx1);
@@ -356,6 +422,7 @@ public abstract class Region {
     }
 
     private void pushNewVerticesImpl(final Vertex vertIn1, final Vertex vertIn2, final Vertex vertIn3, final AffineTransform transform, final Vec4f rgba) {
+        // if(DEBUG_INSTANCE) { System.err.printf("pushVertex.0[%d]:%n- %s,%n- %s,%n- %s]%n", numVertices, vertIn1, vertIn2, vertIn3); }
         if( null != transform ) {
             final Vec3f coordsEx1 = transform.transform(vertIn1.getCoord(), new Vec3f());
             final Vec3f coordsEx2 = transform.transform(vertIn2.getCoord(), new Vec3f());
@@ -377,12 +444,18 @@ public abstract class Region {
 
     @SuppressWarnings("unused")
     private void pushNewVertexIdxImpl(final Vertex vertIn, final AffineTransform transform, final Vec4f rgba) {
+        // if(DEBUG_INSTANCE) { System.err.printf("pushIndices.0[%d]: %d]%n", numIndices , numVertices); }
         pushIndex(numVertices);
         pushNewVertexImpl(vertIn, transform, rgba);
+        // numIndices += 1;
     }
+    // int numIndices = 0;
+
     private void pushNewVerticesIdxImpl(final Vertex vertIn1, final Vertex vertIn2, final Vertex vertIn3, final AffineTransform transform, final Vec4f rgba) {
+        // if(DEBUG_INSTANCE) { System.err.printf("pushIndices.0[%d]: %d, %d, %d]%n", numIndices , numVertices, numVertices+1, numVertices+2); }
         pushIndices(numVertices, numVertices+1, numVertices+2);
         pushNewVerticesImpl(vertIn1, vertIn2, vertIn3, transform, rgba);
+        // numIndices += 3;
     }
 
     protected static void put3i(final IntBuffer b, final int v1, final int v2, final int v3) {
@@ -550,7 +623,7 @@ public abstract class Region {
             } else {
                 shapeBoxT = shapeBox;
             }
-            if( frustum.isAABBoxOutside(shapeBoxT) ) {
+            if( frustum.isOutside(shapeBoxT) ) {
                 return;
             }
         }
@@ -570,6 +643,7 @@ public abstract class Region {
         {
             final int verticeCount = vertsIn.size() + shape.getAddedVerticeCount();
             final int indexCount = trisIn.size() * 3;
+            // if(DEBUG_INSTANCE) { System.err.printf("add.0 triangles %d, vertices %d; verticeCount %d, indexCount %d%n", trisIn.size(), vertsIn.size(), verticeCount, indexCount); }
             growBuffer(verticeCount, indexCount);
         }
 
@@ -591,15 +665,18 @@ public abstract class Region {
 
                 if ( max_indices - idxOffset > tv0Idx ) {
                     // valid 'known' idx - move by offset
+                    // if(DEBUG_INSTANCE) { System.err.printf("pushIndices.0[%d, m %d]: %d, %d, %d]%n", numIndices , 1, tv0Idx+idxOffset, triInVertices[1].getId()+idxOffset, triInVertices[2].getId()+idxOffset); }
                     pushIndices(tv0Idx+idxOffset,
                                 triInVertices[1].getId()+idxOffset,
                                 triInVertices[2].getId()+idxOffset);
+                    // numIndices += 3;
                 } else {
                     // FIXME: If exceeding max_indices, we would need to generate a new buffer w/ indices
                     pushNewVerticesIdxImpl(triInVertices[0], triInVertices[1], triInVertices[2], t, rgbaColor);
                 }
             }
         }
+        // if(DEBUG_INSTANCE) { System.err.printf("add.x num[vertices %d, indices %d]%n", numVertices, numIndices); }
     }
     private final void addOutlineShape1(final OutlineShape shape, final AffineTransform t, final Vec4f rgbaColor) {
         ++perf.count;
@@ -711,7 +788,7 @@ public abstract class Region {
      * Mark this region's shape dirty,
      * i.e. its vertices, triangles, lines and/or color-texture coordinates changed.
      * <p>
-     * The data will be re-uploaded to the GPU at next {@link GLRegion#draw(com.jogamp.opengl.GL2ES2, com.jogamp.graph.curve.opengl.RegionRenderer, int[]) draw(..)}.
+     * The data will be re-uploaded to the GPU at next {@link GLRegion#draw(com.jogamp.opengl.GL2ES2, com.jogamp.graph.curve.opengl.RegionRenderer) draw(..)}.
      * </p>
      * <p>
      * In 2-pass mode, this implies updating the FBO itself as well.
@@ -749,6 +826,6 @@ public abstract class Region {
 
     @Override
     public String toString() {
-        return "Region[0x"+Integer.toHexString(hashCode())+", "+getRenderModeString(this.renderModes)+", q "+quality+", dirty "+dirty+", vertices "+numVertices+", box "+box+"]";
+        return "Region[0x"+Integer.toHexString(hashCode())+", "+getRenderModeString(this.renderModes)+", dirty "+dirty+", vertices "+numVertices+", box "+box+"]";
     }
-}
\ No newline at end of file
+}
