@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -35,8 +35,6 @@ import com.jogamp.opengl.util.GLArrayDataEditable;
 import com.jogamp.opengl.util.GLArrayDataServer;
 import com.jogamp.opengl.util.GLArrayDataWrapper;
 import com.jogamp.opengl.GLProfile;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.Vec4f;
 
 import jogamp.graph.curve.opengl.VBORegion2PMSAAES2;
 import jogamp.graph.curve.opengl.VBORegion2PVBAAES2;
@@ -44,11 +42,12 @@ import jogamp.graph.curve.opengl.VBORegionSPES2;
 import jogamp.graph.curve.opengl.shader.AttributeNames;
 import jogamp.opengl.Debug;
 
-import com.jogamp.opengl.util.PMVMatrix;
 import com.jogamp.opengl.util.glsl.ShaderProgram;
 import com.jogamp.opengl.util.texture.TextureSequence;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.font.Font;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.Vec4f;
 
 import java.io.PrintStream;
 import java.nio.FloatBuffer;
@@ -187,8 +186,10 @@ public abstract class GLRegion extends Region {
         final int[] vertIndexCount = { 0, 0 };
         final Font.GlyphVisitor2 visitor = new Font.GlyphVisitor2() {
             @Override
-            public final void visit(final char symbol, final Font.Glyph glyph) {
-                Region.countOutlineShape(glyph.getShape(), vertIndexCount);
+            public final void visit(final Font.Glyph glyph) {
+                if( !glyph.isNonContour() ) {
+                    Region.countOutlineShape(glyph.getShape(), vertIndexCount);
+                }
             } };
         font.processString(visitor, str);
         return GLRegion.create(glp, renderModes, colorTexSeq, vertIndexCount[0], vertIndexCount[1]);
@@ -365,6 +366,7 @@ public abstract class GLRegion extends Region {
         // gca_VerticesAttr.putf(coords, 0, 3);
         // gca_CurveParamsAttr.putf(texParams, 0, 3);
         // gca_VerticesAttr.put3f(coords.x(), coords.y(), coords.z());
+        // System.err.println("GLRegion V: "+coords);
         put3f((FloatBuffer)vpc_ileave.getBuffer(), coords);
         put3f((FloatBuffer)vpc_ileave.getBuffer(), texParams);
         if( hasColorChannel() ) {
@@ -383,6 +385,7 @@ public abstract class GLRegion extends Region {
         if( cc && null == rgba ) {
             throw new IllegalArgumentException("Null color given for COLOR_CHANNEL rendering mode");
         }
+        // System.err.println("GLRegion V: "+coords1+", "+coords2+", "+coords3);
         put3f((FloatBuffer)vpc_ileave.getBuffer(), coords1);
         put3f((FloatBuffer)vpc_ileave.getBuffer(), texParams1);
         if( cc ) {
@@ -485,8 +488,7 @@ public abstract class GLRegion extends Region {
 
     /**
      * Renders the associated OGL objects specifying
-     * current width/hight of window for multi pass rendering
-     * of the region.
+     * current width/hight of window for optional multi pass rendering of the region.
      * <p>
      * User shall consider {@link RegionRenderer#enable(GL2ES2, boolean) enabling}
      * the renderer beforehand and {@link RegionRenderer#enable(GL2ES2, boolean) disabling}
@@ -506,46 +508,73 @@ public abstract class GLRegion extends Region {
      * {@link RegionRenderer#create(Vertex.Factory<? extends Vertex>, RenderState, com.jogamp.graph.curve.opengl.RegionRenderer.GLCallback, com.jogamp.graph.curve.opengl.RegionRenderer.GLCallback) created}
      * with the appropriate {@link RegionRenderer.GLCallback callbacks}.
      * </p>
-     * @param matrix current {@link PMVMatrix}.
+     * @param gl current {@link GL2ES2}.
      * @param renderer the {@link RegionRenderer} to be used
-     * @param sampleCount desired multisampling sample count for vbaa- or msaa-rendering.
-     *        Use -1 for glSelect mode, pass1 w/o any color texture nor channel, use static select color only.
-     *        The actual used scample-count is written back when msaa-rendering is enabled, otherwise the store is untouched.
      * @see RegionRenderer#enable(GL2ES2, boolean)
+     * @see RegionRenderer#setAAQuality(int)
+     * @see RegionRenderer#setSampleCount(int)
+     * @see RegionRenderer#setClipBBox(com.jogamp.math.geom.AABBox)
      */
-    public final void draw(final GL2ES2 gl, final RegionRenderer renderer, final int[/*1*/] sampleCount) {
+    public final void draw(final GL2ES2 gl, final RegionRenderer renderer) {
+        final int pass2Quality = renderer.getAAQuality();
+        final int pass2SampleCount = renderer.getSampleCount();
         final int curRenderModes;
-        if( null == sampleCount || 0 == sampleCount[0] ) {
+        if( 0 == pass2SampleCount ) {
             // no sampling, reduce to pass1
             curRenderModes = getRenderModes() & ~( VBAA_RENDERING_BIT | MSAA_RENDERING_BIT );
-        } else if( 0 > sampleCount[0] ) {
+        } else if( 0 > pass2SampleCount ) {
             // negative sampling, hint we perform glSelect: pass1 w/o any color texture nor channel, use static select color only
             curRenderModes = getRenderModes() & ~( VBAA_RENDERING_BIT | MSAA_RENDERING_BIT | COLORCHANNEL_RENDERING_BIT | COLORTEXTURE_RENDERING_BIT );
         } else {
             // normal 2-pass sampling
             curRenderModes = getRenderModes();
         }
+        // System.err.println("XXX.0 "+Region.getRenderModeString(getRenderModes(), sampleCount[0], 0)+": "+
+        //        Region.getRenderModeString(lastRenderModes, sampleCount[0], 0)+" -> "+Region.getRenderModeString(curRenderModes, sampleCount[0], 0));
+
+        if( lastRenderModes != curRenderModes ) {
+            markShapeDirty();
+            markStateDirty();
+        } else if( Region.isGraphAA(curRenderModes) &&
+                   ( lastPass2Quality != pass2Quality || lastPass2SampleCount != pass2SampleCount ) ) {
+            markStateDirty();
+        }
+        if( isShapeDirty() ) {
+            updateImpl(gl, renderer, curRenderModes);
+        }
+        drawImpl(gl, renderer, curRenderModes);
+        clearDirtyBits(DIRTY_SHAPE|DIRTY_STATE);
+        lastRenderModes = curRenderModes;
+        lastPass2Quality = pass2Quality;
+        lastPass2SampleCount = pass2SampleCount;
+    }
+
+    /** Perform glSelect false color rendering: pass1 w/o any color texture nor channel, use static select color only */
+    public final void drawToSelect(final GL2ES2 gl, final RegionRenderer renderer) {
+        final int curRenderModes = getRenderModes() & ~( VBAA_RENDERING_BIT | MSAA_RENDERING_BIT | COLORCHANNEL_RENDERING_BIT | COLORTEXTURE_RENDERING_BIT );
         if( lastRenderModes != curRenderModes ) {
             markShapeDirty();
             markStateDirty();
         }
         if( isShapeDirty() ) {
-            updateImpl(gl, curRenderModes);
+            updateImpl(gl, renderer, curRenderModes);
         }
-        drawImpl(gl, renderer, curRenderModes, sampleCount);
+        drawImpl(gl, renderer, curRenderModes);
         clearDirtyBits(DIRTY_SHAPE|DIRTY_STATE);
         lastRenderModes = curRenderModes;
     }
+
     private int lastRenderModes = 0;
+    private int lastPass2Quality = -1;
+    private int lastPass2SampleCount = -1;
 
     /**
      * Updates a graph region by updating the ogl related
      * objects for use in rendering if {@link #isShapeDirty()}.
      * <p>Allocates the ogl related data and initializes it the 1st time.<p>
      * <p>Called by {@link #draw(GL2ES2, RenderState, int, int, int)}.</p>
-     * @param curRenderModes TODO
      */
-    protected abstract void updateImpl(final GL2ES2 gl, int curRenderModes);
+    protected abstract void updateImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes);
 
-    protected abstract void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, int curRenderModes, final int[/*1*/] sampleCount);
+    protected abstract void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes);
 }
