@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -42,7 +42,7 @@ import com.jogamp.common.util.SecurityUtil;
 import com.jogamp.common.util.cache.TempJarCache;
 
 import jogamp.graph.font.FontConstructor;
-import jogamp.graph.font.JavaFontLoader;
+import jogamp.graph.font.SymbolsFontLoader;
 import jogamp.graph.font.UbuntuFontLoader;
 
 /**
@@ -60,8 +60,8 @@ public class FontFactory {
     /** Ubuntu is the default font family, {@value} */
     public static final int UBUNTU = 0;
 
-    /** Java fonts are optional, {@value} */
-    public static final int JAVA = 1;
+    /** Symbols is the default symbol font family and contains rounded material symbol fonts, {@value} */
+    public static final int SYMBOLS = 10;
 
     private static final FontConstructor fontConstr;
 
@@ -84,8 +84,8 @@ public class FontFactory {
 
     public static final FontSet get(final int font) {
         switch (font) {
-            case JAVA:
-                return JavaFontLoader.get();
+            case SYMBOLS:
+                return SymbolsFontLoader.get();
             default:
                 return UbuntuFontLoader.get();
         }
@@ -217,4 +217,32 @@ public class FontFactory {
         final Character.UnicodeBlock block = Character.UnicodeBlock.of( c );
         return block != null && block != Character.UnicodeBlock.SPECIALS;
     }
+
+    /** Returns {@link FontSet#getDefault() default} {@link Font} of {@link #getDefault() default} {@link FontSet} or {@code null} if n/a */
+    public static Font getDefaultFont() {
+        try {
+            return getDefault().getDefault();
+        } catch(final IOException ioe) {
+            ioe.printStackTrace();
+            return null;
+        }
+    }
+
+    /** Returns the default symbols {@link Font} or {@code null} if n/a */
+    public static Font getSymbolsFont() {
+        try {
+            return get(SYMBOLS).getDefault();
+        } catch(final IOException ioe) {
+            ioe.printStackTrace();
+            return null;
+        }
+    }
+
+    /** Returns registered fallback {@link Font}, maybe {@code null}. See {@link #setFallbackFont(Font)}. */
+    public static synchronized Font getFallbackFont() {
+        return fallbackFont;
+    }
+    /** Registers given {@link Font} as the default fallback font. */
+    public static synchronized void setFallbackFont(final Font f) { fallbackFont = f; }
+    private static Font fallbackFont = null;
 }
