@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -27,15 +27,16 @@
  */
 package com.jogamp.graph.geom;
 
+import java.io.PrintStream;
 import java.util.ArrayList;
 
-import com.jogamp.graph.geom.plane.AffineTransform;
-import com.jogamp.graph.geom.plane.Winding;
+import com.jogamp.math.FloatUtil;
+import com.jogamp.math.VectorUtil;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.geom.plane.Winding;
 import com.jogamp.graph.curve.OutlineShape;
 import com.jogamp.graph.curve.Region;
-import com.jogamp.opengl.math.FloatUtil;
-import com.jogamp.opengl.math.VectorUtil;
-import com.jogamp.opengl.math.geom.AABBox;
 
 
 
@@ -56,7 +57,11 @@ public class Outline implements Comparable<Outline> {
     private final AABBox bbox;
     private boolean dirtyBBox;
     private Winding winding;
-    private boolean dirtyWinding;
+    private boolean complexShape;
+    private int dirtyBits;
+
+    private static final int DIRTY_WINDING = 1 << 0;
+    private static final int DIRTY_COMPLEXSHAPE  = 1 << 0;
 
     /**Create an outline defined by control vertices.
      * An outline can contain off Curve vertices which define curved
@@ -68,7 +73,8 @@ public class Outline implements Comparable<Outline> {
         bbox = new AABBox();
         dirtyBBox = false;
         winding = Winding.CCW;
-        dirtyWinding = false;
+        complexShape = false;
+        dirtyBits = 0;
     }
 
     /**
@@ -77,10 +83,19 @@ public class Outline implements Comparable<Outline> {
     public Outline(final Outline src) {
         final int count = src.vertices.size();
         vertices = new ArrayList<Vertex>(count);
-        winding = src.getWinding();
-        dirtyWinding = false;
+        winding = Winding.CCW;
+        complexShape = false;
+        dirtyBits = DIRTY_WINDING | DIRTY_COMPLEXSHAPE;
+        if( 0 == ( src.dirtyBits & DIRTY_WINDING ) ) {
+            winding = src.winding;
+            dirtyBits &= ~DIRTY_WINDING;
+        }
+        if( 0 == ( src.dirtyBits & DIRTY_COMPLEXSHAPE ) ) {
+            complexShape = src.complexShape;
+            dirtyBits &= ~DIRTY_COMPLEXSHAPE;
+        }
         for(int i=0; i<count; i++) {
-            vertices.add( src.vertices.get(i).clone() );
+            vertices.add( src.vertices.get(i).copy() );
         }
         closed = src.closed;
         bbox = new AABBox(src.bbox);
@@ -98,19 +113,24 @@ public class Outline implements Comparable<Outline> {
     public Outline(final Outline src, final Winding enforce) {
         final int count = src.vertices.size();
         vertices = new ArrayList<Vertex>(count);
-        final Winding had_winding = src.getWinding();;
+        complexShape = false;
+        dirtyBits = DIRTY_COMPLEXSHAPE;
+        final Winding had_winding = src.getWinding();
         winding = had_winding;
-        dirtyWinding = false;
         if( enforce != had_winding ) {
             for(int i=count-1; i>=0; --i) {
-                vertices.add( src.vertices.get(i).clone() );
+                vertices.add( src.vertices.get(i).copy() );
             }
             winding = enforce;
         } else {
             for(int i=0; i<count; ++i) {
-                vertices.add( src.vertices.get(i).clone() );
+                vertices.add( src.vertices.get(i).copy() );
             }
         }
+        if( 0 == ( src.dirtyBits & DIRTY_COMPLEXSHAPE ) ) {
+            complexShape = src.complexShape;
+            dirtyBits &= ~DIRTY_COMPLEXSHAPE;
+        }
         closed = src.closed;
         bbox = new AABBox(src.bbox);
         dirtyBBox = src.dirtyBBox;
@@ -133,15 +153,19 @@ public class Outline implements Comparable<Outline> {
             }
             vertices = ccw;
             winding = enforce;
+            dirtyBits &= ~DIRTY_WINDING;
         }
     }
 
     /**
-     * Compute the winding of the {@link #getLastOutline()} using the {@link #area(ArrayList)} function over all of its vertices.
+     * Returns the cached or computed winding of this {@link Outline}s {@code polyline} using {@link VectorUtil#area(ArrayList)}.
+     * <p>
+     * The result is cached.
+     * </p>
      * @return {@link Winding#CCW} or {@link Winding#CW}
      */
     public final Winding getWinding() {
-        if( !dirtyWinding ) {
+        if( 0 == ( dirtyBits & DIRTY_WINDING ) ) {
             return winding;
         }
         final int count = getVertexCount();
@@ -150,10 +174,29 @@ public class Outline implements Comparable<Outline> {
         } else {
             winding = VectorUtil.getWinding( getVertices() );
         }
-        dirtyWinding = false;
+        dirtyBits &= ~DIRTY_WINDING;
         return winding;
     }
 
+    /**
+     * Returns cached or computed result if whether this {@link Outline}s {@code polyline} is a complex shape.
+     * <p>
+     * A polyline with less than 3 elements is marked a simple shape for simplicity.
+     * </p>
+     * <p>
+     * The result is cached.
+     * </p>
+     */
+    public boolean isComplex() {
+        if( 0 == ( dirtyBits & DIRTY_COMPLEXSHAPE ) ) {
+            return complexShape;
+        }
+        complexShape = !VectorUtil.isConvex1( getVertices(), true );
+        // complexShape = VectorUtil.isSelfIntersecting1( getVertices() );
+        dirtyBits &= ~DIRTY_COMPLEXSHAPE;
+        return complexShape;
+    }
+
     public final int getVertexCount() {
         return vertices.size();
     }
@@ -182,7 +225,7 @@ public class Outline implements Comparable<Outline> {
         if(!dirtyBBox) {
             bbox.resize(vertex.getCoord());
         }
-        dirtyWinding = true;
+        dirtyBits |= DIRTY_WINDING | DIRTY_COMPLEXSHAPE;
     }
 
     /** Replaces the {@link Vertex} element at the given {@code position}.
@@ -199,7 +242,7 @@ public class Outline implements Comparable<Outline> {
         }
         vertices.set(position, vertex);
         dirtyBBox = true;
-        dirtyWinding = true;
+        dirtyBits |= DIRTY_WINDING | DIRTY_COMPLEXSHAPE;
     }
 
     public final Vertex getVertex(final int index){
@@ -218,7 +261,7 @@ public class Outline implements Comparable<Outline> {
      */
     public final Vertex removeVertex(final int position) throws IndexOutOfBoundsException {
         dirtyBBox = true;
-        dirtyWinding = true;
+        dirtyBits |= DIRTY_WINDING | DIRTY_COMPLEXSHAPE;
         return vertices.remove(position);
     }
 
@@ -256,11 +299,11 @@ public class Outline implements Comparable<Outline> {
      * Ensure this outline is closed.
      * <p>
      * Checks whether the last vertex equals to the first.
-     * If not equal, it either appends a clone of the first vertex
-     * or prepends a clone of the last vertex, depending on <code>closeTail</code>.
+     * If not equal, it either appends a copy of the first vertex
+     * or prepends a copy of the last vertex, depending on <code>closeTail</code>.
      * </p>
-     * @param closeTail if true, a clone of the first vertex will be appended,
-     *                  otherwise a clone of the last vertex will be prepended.
+     * @param closeTail if true, a copy of the first vertex will be appended,
+     *                  otherwise a copy of the last vertex will be prepended.
      * @return true if closing performed, otherwise false for NOP
      */
     public final boolean setClosed(final boolean closeTail) {
@@ -270,9 +313,9 @@ public class Outline implements Comparable<Outline> {
             final Vertex last = getLastVertex();
             if( !first.getCoord().isEqual( last.getCoord() ) ) {
                 if( closeTail ) {
-                    vertices.add(first.clone());
+                    vertices.add(first.copy());
                 } else {
-                    vertices.add(0, last.clone());
+                    vertices.add(0, last.copy());
                 }
                 return true;
             }
@@ -318,7 +361,7 @@ public class Outline implements Comparable<Outline> {
     public final int compareTo(final Outline other) {
         final float thisSize = getBounds().getSize();
         final float otherSize = other.getBounds().getSize();
-        if( FloatUtil.isEqual(thisSize, otherSize, FloatUtil.EPSILON) ) {
+        if( FloatUtil.isEqual2(thisSize, otherSize) ) {
             return 0;
         } else if(thisSize < otherSize){
             return -1;
@@ -362,4 +405,13 @@ public class Outline implements Comparable<Outline> {
         // Avoid calling this.hashCode() !
         return getClass().getName() + "@" + Integer.toHexString(super.hashCode());
     }
+
+    public void print(final PrintStream out) {
+        final int vc = getVertexCount();
+        out.printf("Outline: %d, %s%n", vc, getWinding());
+        for(int vi=0; vi < vc; vi++) {
+            final Vertex v = getVertex(vi);
+            out.printf("- OL[%d]: %s%n", vi, v);
+        }
+    }
 }
