@@ -1,6 +1,6 @@
 /*
+ * Copyright (c) 2010-2023 JogAmp Community. All rights reserved.
  * Copyright (c) 2003 Sun Microsystems, Inc. All Rights Reserved.
- * Copyright (c) 2010 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -33,9 +33,6 @@
  * You acknowledge that this software is not designed or intended for use
  * in the design, construction, operation or maintenance of any nuclear
  * facility.
- *
- * Sun gratefully acknowledges that this software was originally authored
- * and developed by Kenneth Bradley Russell and Christopher John Kline.
  */
 
 package com.jogamp.opengl;
@@ -47,20 +44,20 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
+import com.jogamp.common.os.DynamicLibraryBundle;
+import com.jogamp.common.os.Platform;
+import com.jogamp.common.util.Bitfield;
+import com.jogamp.common.util.VersionNumber;
+import com.jogamp.common.util.VersionNumberString;
+import com.jogamp.common.util.locks.LockFactory;
+import com.jogamp.common.util.locks.RecursiveLock;
 import com.jogamp.nativewindow.AbstractGraphicsDevice;
 import com.jogamp.nativewindow.NativeSurface;
 
 import jogamp.opengl.Debug;
 import jogamp.opengl.GLContextImpl;
 import jogamp.opengl.GLContextShareSet;
-
-import com.jogamp.common.os.Platform;
-import com.jogamp.common.util.VersionNumber;
-import com.jogamp.common.util.VersionNumberString;
-import com.jogamp.common.util.locks.LockFactory;
-import com.jogamp.common.util.locks.RecursiveLock;
-import com.jogamp.opengl.GLExtensions;
-import com.jogamp.opengl.GLRendererQuirks;
+import jogamp.opengl.GLDynamicLookupHelper;
 
 /** Abstraction for an OpenGL rendering context. In order to perform
     OpenGL rendering, a context must be "made current" on the current
@@ -106,10 +103,6 @@ public abstract class GLContext {
    */
   public static final boolean PROFILE_ALIASING = !Debug.isPropertyDefined("jogl.debug.GLContext.NoProfileAliasing", true);
 
-  protected static final boolean FORCE_NO_FBO_SUPPORT = Debug.isPropertyDefined("jogl.fbo.force.none", true);
-  protected static final boolean FORCE_MIN_FBO_SUPPORT = Debug.isPropertyDefined("jogl.fbo.force.min", true);
-  protected static final boolean FORCE_NO_COLOR_RENDERBUFFER = Debug.isPropertyDefined("jogl.fbo.force.nocolorrenderbuffer", true);
-
   /** Reflects property jogl.debug.DebugGL. If true, the debug pipeline is enabled at context creation. */
   public static final boolean DEBUG_GL = Debug.isPropertyDefined("jogl.debug.DebugGL", true);
   /** Reflects property jogl.debug.TraceGL. If true, the trace pipeline is enabled at context creation. */
@@ -149,11 +142,15 @@ public abstract class GLContext {
 
   /** Version 3.0. As an OpenGL version, it qualifies for desktop {@link #isGL2()} only, or ES 3.0. Or GLSL 3.00 for ES 3.0. */
   public static final VersionNumber Version3_0 = new VersionNumber(3, 0, 0);
+  /** Version 3.10. GLSL 3.10 for ES 3.1. */
+  public static final VersionNumber Version3_10 = new VersionNumber(3, 10, 0);
+  /** Version 3.20. GLSL 3.20 for ES 3.2. */
+  public static final VersionNumber Version3_20 = new VersionNumber(3, 20, 0);
 
-  /** Version 3.1. As an OpenGL version, it qualifies for {@link #isGL3core()}, {@link #isGL3bc()} and {@link #isGL3()} */
+  /** Version 3.1. As an OpenGL version, it qualifies for {@link #isGL3core()}, {@link #isGL3bc()} and {@link #isGL3()}, or ES 3.1. */
   public static final VersionNumber Version3_1 = new VersionNumber(3, 1, 0);
 
-  /** Version 3.2. As an OpenGL version, it qualifies for geometry shader */
+  /** Version 3.2. As an OpenGL version, it qualifies for geometry shader, , or ES 3.2. */
   public static final VersionNumber Version3_2 = new VersionNumber(3, 2, 0);
 
   /** Version 4.3. As an OpenGL version, it qualifies for <code>GL_ARB_ES3_compatibility</code> */
@@ -235,11 +232,11 @@ public abstract class GLContext {
       resetStates(true);
   }
 
-  protected VersionNumber ctxVersion;
+  protected VersionNumberString ctxVersion;
   protected int ctxOptions;
   protected String ctxVersionString;
   protected VersionNumberString ctxVendorVersion;
-  protected VersionNumber ctxGLSLVersion;
+  protected VersionNumberString ctxGLSLVersion;
   protected GLRendererQuirks glRendererQuirks;
 
   /** Did the drawable association changed ? see {@link GLRendererQuirks#NoSetSwapIntervalPostRetarget} */
@@ -257,7 +254,7 @@ public abstract class GLContext {
       ctxVendorVersion = VersionNumberString.zeroVersion;
       ctxOptions=0;
       ctxVersionString=null;
-      ctxGLSLVersion = VersionNumber.zeroVersion;
+      ctxGLSLVersion = VersionNumberString.zeroVersion;
       attachedObjects.clear();
       contextHandle=0;
       glRendererQuirks = null;
@@ -781,7 +778,8 @@ public abstract class GLContext {
    * Returns this context OpenGL version.
    * @see #getGLSLVersionNumber()
    **/
-  public final VersionNumber getGLVersionNumber() { return ctxVersion; }
+  public final VersionNumberString getGLVersionNumber() { return ctxVersion; }
+
   /**
    * Returns the vendor's version, i.e. version number at the end of <code>GL_VERSION</code> not being the GL version.
    * <p>
@@ -827,7 +825,7 @@ public abstract class GLContext {
    *
    * @see #getGLVersionNumber()
    */
-  public final VersionNumber getGLSLVersionNumber() {
+  public final VersionNumberString getGLSLVersionNumber() {
       return ctxGLSLVersion;
   }
 
@@ -870,30 +868,38 @@ public abstract class GLContext {
       return "#version " + ctxGLSLVersion.getMajor() + ( minor < 10 ? "0"+minor : minor ) + profileOpt + "\n" ;
   }
 
-  protected static final VersionNumber getStaticGLSLVersionNumber(final int glMajorVersion, final int glMinorVersion, final int ctxOptions) {
+  protected static final VersionNumberString getStaticGLSLVersionNumber(final int glMajorVersion, final int glMinorVersion, final int ctxOptions) {
       if( 0 != ( CTX_PROFILE_ES & ctxOptions ) ) {
           if( 3 == glMajorVersion ) {
-              return Version3_0;           // ES 3.0  ->  GLSL 3.00
+              switch ( glMinorVersion ) {
+                  case 0:  return new VersionNumberString(Version3_0, glsl_es_prefix+Version3_0.toString());    // ES 3.0  ->  GLSL 3.00
+                  case 1:  return new VersionNumberString(Version3_10, glsl_es_prefix+Version3_10.toString());  // ES 3.1  ->  GLSL 3.10
+                  default: return new VersionNumberString(Version3_20, glsl_es_prefix+Version3_20.toString());  // ES 3.2  ->  GLSL 3.20
+              }
           } else if( 2 == glMajorVersion ) {
-              return Version1_0;           // ES 2.0  ->  GLSL 1.00
+              return new VersionNumberString(Version1_0, glsl_es_prefix+Version1_0.toString());                 // ES 2.0  ->  GLSL 1.00
           }
       } else if( 1 == glMajorVersion ) {
-          return Version1_10;               // GL 1.x  ->  GLSL 1.10
+          return new VersionNumberString(Version1_10, glsl_prefix+Version1_10.toString());                      // GL 1.x  ->  GLSL 1.10
       } else if( 2 == glMajorVersion ) {
           switch ( glMinorVersion ) {
-              case 0:  return Version1_10;  // GL 2.0  ->  GLSL 1.10
-              default: return Version1_20;  // GL 2.1  ->  GLSL 1.20
+              case 0:  return new VersionNumberString(Version1_10, glsl_prefix+Version1_10.toString());         // GL 2.0  ->  GLSL 1.10
+              default: return new VersionNumberString(Version1_20, glsl_prefix+Version1_20.toString());         // GL 2.1  ->  GLSL 1.20
           }
       } else if( 3 == glMajorVersion && 2 >= glMinorVersion ) {
           switch ( glMinorVersion ) {
-              case 0:  return Version1_30;  // GL 3.0  ->  GLSL 1.30
-              case 1:  return Version1_40;  // GL 3.1  ->  GLSL 1.40
-              default: return Version1_50;  // GL 3.2  ->  GLSL 1.50
+              case 0:  return new VersionNumberString(Version1_30, glsl_prefix+Version1_30.toString());         // GL 3.0  ->  GLSL 1.30
+              case 1:  return new VersionNumberString(Version1_40, glsl_prefix+Version1_40.toString());         // GL 3.1  ->  GLSL 1.40
+              default: return new VersionNumberString(Version1_50, glsl_prefix+Version1_50.toString());         // GL 3.2  ->  GLSL 1.50
           }
       }
-      // The new default: GL >= 3.3, ES >= 3.0
-      return new VersionNumber(glMajorVersion, glMinorVersion * 10, 0); // GL M.N  ->  GLSL M.N
+      // The new default: GL >= 3.x, ES >= 3.x
+      final String prefix = 0 != ( CTX_PROFILE_ES & ctxOptions ) ? glsl_es_prefix : glsl_prefix;
+      final VersionNumber vn = new VersionNumber(glMajorVersion, glMinorVersion * 10, 0); // GL M.N  ->  GLSL M.N
+      return new VersionNumberString(vn, prefix+vn.toString()); // GL M.N  ->  GLSL M.N
   }
+  private static final String glsl_prefix = "OpenGL GLSL ";
+  private static final String glsl_es_prefix = "OpenGL ES GLSL ES ";
 
   /**
    * @return true if this context is an ES2 context or implements
@@ -1191,12 +1197,7 @@ public abstract class GLContext {
    * @see GLProfile#isGLES2()
    */
   public final boolean isGLES2() {
-      if( 0 != ( ctxOptions & CTX_PROFILE_ES ) ) {
-          final int major = ctxVersion.getMajor();
-          return 2 == major || 3 == major;
-      } else {
-          return false;
-      }
+      return 0 != ( ctxOptions & CTX_PROFILE_ES ) && ctxVersion.getMajor() >= 2 ;
   }
 
   /**
@@ -1204,7 +1205,7 @@ public abstract class GLContext {
    * @see GLProfile#isGLES3()
    */
   public final boolean isGLES3() {
-      return 0 != ( ctxOptions & CTX_PROFILE_ES ) && ctxVersion.getMajor() == 3 ;
+      return 0 != ( ctxOptions & CTX_PROFILE_ES ) && ctxVersion.getMajor() >= 3 ;
   }
 
   /**
@@ -1367,6 +1368,30 @@ public abstract class GLContext {
    */
   public abstract int getDefaultReadFramebuffer();
 
+  /**
+   * Returns the default color buffer within the current bound
+   * {@link #getDefaultReadFramebuffer()}, i.e. GL_READ_FRAMEBUFFER​,
+   * which will be used as the target (output) for (fragment shader) draw commands,
+   * settable via {@link GL2ES2#glDrawBuffers(int, int[], int)} or {@link GL2#glDrawBuffer(int)}.
+   * <p>
+   * For offscreen framebuffer objects this is {@link GL#GL_COLOR_ATTACHMENT0},
+   * otherwise this is {@link GL#GL_FRONT} for non-ES profile and single buffer configurations
+   * and {@link GL#GL_BACK} for double buffer configurations or ES profiles.
+   * </p>
+   * <p>
+   * Note-1: Neither ES1 nor ES2 supports selecting the draw buffer at all
+   * and {@link GL#GL_BACK} is the default.
+   * </p>
+   * <p>
+   * Note-2: ES3 only supports {@link GL#GL_BACK}, {@link GL#GL_NONE} or {@link GL#GL_COLOR_ATTACHMENT0}+i
+   * via {@link GL2ES2#glDrawBuffers(int, int[], int)}.
+   * </p>
+   * <p>
+   * Method is only thread-safe while context is {@link #makeCurrent() made current}.
+   * </p>
+   */
+  public abstract int getDefaultDrawBuffer();
+
   /**
    * Returns the default color buffer within the current bound
    * {@link #getDefaultReadFramebuffer()}, i.e. GL_READ_FRAMEBUFFER​,
@@ -1374,8 +1399,8 @@ public abstract class GLContext {
    * like {@link GL#glReadPixels(int, int, int, int, int, int, java.nio.Buffer) glReadPixels} etc.
    * <p>
    * For offscreen framebuffer objects this is {@link GL#GL_COLOR_ATTACHMENT0},
-   * otherwise this is {@link GL#GL_FRONT} for single buffer configurations
-   * and {@link GL#GL_BACK} for double buffer configurations.
+   * otherwise this is {@link GL#GL_FRONT} for non-ES profile and single buffer configurations
+   * and {@link GL#GL_BACK} for double buffer configurations or ES profiles.
    * </p>
    * <p>
    * Note-1: Neither ES1 nor ES2 supports selecting the read buffer via glReadBuffer
@@ -1410,6 +1435,9 @@ public abstract class GLContext {
    */
   public abstract int getDefaultPixelDataFormat();
 
+  /** Returns the DynamicLibraryBundle, matching context. */
+  public abstract DynamicLibraryBundle getDynamicLibraryBundle();
+
   /**
    * @return The extension implementing the GLDebugOutput feature,
    *         either {@link GLExtensions#ARB_debug_output} or {@link GLExtensions#AMD_debug_output}.
@@ -1505,7 +1533,7 @@ public abstract class GLContext {
       /* 1.*/ { 0, 1, 2, 3, 4, 5 },
       /* 2.*/ { 0, 1 },
       /* 3.*/ { 0, 1, 2, 3 },
-      /* 4.*/ { 0, 1, 2, 3, 4, 5 } };
+      /* 4.*/ { 0, 1, 2, 3, 4, 5, 6 } };
 
   public static final int ES_VERSIONS[][] = {
       /* 0.*/ { -1 },
@@ -1533,6 +1561,15 @@ public abstract class GLContext {
   /**
    * Returns true, if the major.minor is not inferior to the lowest
    * valid version and does not exceed the highest known major number by more than one.
+   * Otherwise returns false.
+   * <p>
+   * Returns false if more than one bit of the following list in {@code ctxProfile} is set
+   * <ul>
+   *   <li>{@link GLContext#CTX_PROFILE_ES}</li>
+   *   <li>{@link GLContext#CTX_PROFILE_CORE}</li>
+   *   <li>{@link GLContext#CTX_PROFILE_COMPAT}</li>
+   * </ul>
+   * </p>
    * <p>
    * The minor version number is ignored by the upper limit validation
    * and the major version number may exceed by one.
@@ -1550,6 +1587,9 @@ public abstract class GLContext {
       if( 1>major || 0>minor ) {
           return false;
       }
+      if ( 1 < Bitfield.Util.bitCount( ctxProfile & ( CTX_PROFILE_ES | CTX_PROFILE_CORE | CTX_PROFILE_COMPAT ) ) ) {
+          return false;
+      }
       if( 0 != ( CTX_PROFILE_ES & ctxProfile ) ) {
           if( major >= ES_VERSIONS.length + 1 ) return false;
       } else {
@@ -1638,8 +1678,11 @@ public abstract class GLContext {
       ctp[0]          = ( bits32 & 0x0000FFFF )        ;
       return new VersionNumber(major, minor, 0);
   }
+  protected static int getCTPFromBits(final int bits32) {
+      return ( bits32 & 0x0000FFFF );
+  }
 
-  private static void validateProfileBits(final int bits, final String argName) {
+  protected static void validateProfileBits(final int bits, final String argName) {
     int num = 0;
     if( 0 != ( CTX_PROFILE_COMPAT & bits ) ) { num++; }
     if( 0 != ( CTX_PROFILE_CORE   & bits ) ) { num++; }
@@ -1700,28 +1743,6 @@ public abstract class GLContext {
       return r.intern();
   }
 
-  /**
-   * @deprecated Use {@link GLContextImpl#mapAvailableGLVersion(AbstractGraphicsDevice, int, int, VersionNumber, int)}
-   */
-  protected static Integer mapAvailableGLVersion(final AbstractGraphicsDevice device,
-                                                 final int reqMajor, final int profile, final int resMajor, final int resMinor, int resCtp)
-  {
-    validateProfileBits(profile, "profile");
-    validateProfileBits(resCtp, "resCtp");
-
-    if(FORCE_NO_FBO_SUPPORT) {
-        resCtp &= ~CTX_IMPL_FBO ;
-    }
-    if(DEBUG) {
-        System.err.println(getThreadName() + ": createContextARB-MapGLVersions MAP "+device+": "+reqMajor+" ("+GLContext.getGLProfile(new StringBuilder(), profile).toString()+ ") -> "+getGLVersion(resMajor, resMinor, resCtp, null));
-    }
-    final String objectKey = getDeviceVersionAvailableKey(device, reqMajor, profile);
-    final Integer val = Integer.valueOf(composeBits(resMajor, resMinor, resCtp));
-    synchronized(deviceVersionAvailable) {
-        return deviceVersionAvailable.put( objectKey, val );
-    }
-  }
-
   protected static StringBuilder dumpAvailableGLVersions(StringBuilder sb) {
     if(null == sb) {
         sb = new StringBuilder();
