@@ -382,7 +382,10 @@ public class GLCanvas extends Canvas implements GLAutoDrawable, GLSharedContextS
 
       // Bug 1362 fix or workaround: Seems SWT/GTK3 at least performs lazy initialization
       // Minimal action required: setBackground of the parent canvas before reparenting!
-      setBackground(new Color(parent.getDisplay(), 255, 255, 255));
+      //
+      // SWT 3.110 (Eclipse 4.10?) would require color to be disposed, hence use pre-allocated.
+      // Since at least 'Eclipse 4.26.0 Release Build: 4.26' no more disposal of Color required.
+      setBackground(parent.getDisplay().getSystemColor(SWT.COLOR_WHITE));
 
       final Listener listener = new Listener () {
           @Override
@@ -392,9 +395,15 @@ public class GLCanvas extends Canvas implements GLAutoDrawable, GLSharedContextS
                   displayIfNoAnimatorNoCheck();
                   break;
               case SWT.Resize:
+                  if (DEBUG) { System.err.println(getThreadName()+": SWT.GLCanvas.Resize.0 "+toString()); }
+                  updateSizeCheck();
+                  break;
+              case SWT.ZoomChanged:
+                  if (DEBUG) { System.err.println(getThreadName()+": SWT.GLCanvas.ZoomChanged.0 "+toString()); }
                   updateSizeCheck();
                   break;
               case SWT.Dispose:
+                  if (DEBUG) { System.err.println(getThreadName()+": SWT.GLCanvas.Dispose.0 "+toString()); }
                   GLCanvas.this.dispose();
                   break;
               }
@@ -453,6 +462,11 @@ public class GLCanvas extends Canvas implements GLAutoDrawable, GLSharedContextS
       final Rectangle oClientAreaPixels = clientAreaPixels;
       final Rectangle nClientAreaPixels = SWTAccessor.getClientAreaInPixels(this);
 
+      if(DEBUG) {
+          System.err.println(getThreadName()+": GLCanvas.sizeChanged: clientAreaPixels.o "+getClientArea());
+          System.err.println(getThreadName()+": GLCanvas.sizeChanged: clientAreaPixels.n "+nClientAreaPixels);
+      }
+
       if ( nClientAreaPixels != null &&
            ( nClientAreaPixels.width != oClientAreaPixels.width || nClientAreaPixels.height != oClientAreaPixels.height )
          ) {
