@@ -8,14 +8,15 @@ import java.nio.ShortBuffer;
 import java.util.ArrayList;
 import java.util.Iterator;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.GL2ES1;
-import javax.media.opengl.GL2ES2;
-import javax.media.opengl.GLException;
-import javax.media.opengl.fixedfunc.GLPointerFunc;
+import com.jogamp.opengl.GL;
+import com.jogamp.opengl.GL2ES1;
+import com.jogamp.opengl.GL2ES2;
+import com.jogamp.opengl.GLException;
+import com.jogamp.opengl.fixedfunc.GLPointerFunc;
 
 import jogamp.opengl.Debug;
 
+import com.jogamp.common.ExceptionUtils;
 import com.jogamp.common.nio.Buffers;
 import com.jogamp.common.os.Platform;
 import com.jogamp.common.util.PropertyAccess;
@@ -450,7 +451,7 @@ public class ImmModeSink {
         this.nElems=0;
         this.tElems=0;
 
-        this.pageSize = Platform.getMachineDescription().pageSizeInBytes();
+        this.pageSize = Platform.getMachineDataInfo().pageSizeInBytes();
 
         reallocateBuffer(initialElementCount);
         rewind();
@@ -1376,7 +1377,7 @@ public class ImmModeSink {
 
         if(DEBUG_BUFFER) {
             System.err.println("ImmModeSink.realloc.X: "+this.toString());
-            Thread.dumpStack();
+            ExceptionUtils.dumpStack(System.err);
         }
         return true;
     }
