@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -27,6 +27,7 @@
  */
 package jogamp.graph.curve.opengl;
 
+import java.io.File;
 import java.nio.FloatBuffer;
 
 import com.jogamp.opengl.GL2ES2;
@@ -41,28 +42,35 @@ import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.GLRegion;
 import com.jogamp.graph.curve.opengl.RegionRenderer;
 import com.jogamp.graph.curve.opengl.RenderState;
+import com.jogamp.math.Matrix4f;
+import com.jogamp.math.Recti;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.Frustum;
+import com.jogamp.math.util.SyncMatrices4f16;
 import com.jogamp.opengl.FBObject;
 import com.jogamp.opengl.FBObject.Attachment;
-import com.jogamp.opengl.math.Matrix4f;
-import com.jogamp.opengl.math.Recti;
-import com.jogamp.opengl.math.geom.AABBox;
+import com.jogamp.opengl.FBObject.TextureAttachment;
 import com.jogamp.opengl.util.GLArrayDataServer;
-import com.jogamp.opengl.util.SyncMatrices4f16;
+import com.jogamp.opengl.util.GLReadBufferUtil;
 import com.jogamp.opengl.util.glsl.ShaderProgram;
 import com.jogamp.opengl.util.texture.Texture;
-import com.jogamp.opengl.util.texture.TextureCoords;
 import com.jogamp.opengl.util.texture.TextureSequence;
 
 public final class VBORegion2PMSAAES2  extends GLRegion {
     private static final boolean DEBUG_FBO_1 = false;
     private static final boolean DEBUG_FBO_2 = false;
+    private static final boolean SCREENSHOT_FBO = false;
 
     private final RenderState.ProgramLocal rsLocal;
 
     // Pass-1:
     private final GLUniformData gcu_ColorTexUnit;
-    private final float[] colorTexBBox; // x0, y0, x1, y1
-    private final GLUniformData gcu_ColorTexBBox;
+    private final float[] colorTexBBox; // minX/minY, maxX/maxY, texW/texH
+    private final GLUniformData gcu_ColorTexBBox; // vec2 gcu_ColorTexBBox[3] -> boxMin[2], boxMax[2] and texSize[2]
+    private final float[] colorTexClearCol;
+    private final GLUniformData gcu_ColorTexClearCol; // vec4 gcu_ColorTexClearCol
+    private final float[/* 4*6 */] clipFrustum; // 6 frustum planes, each [n.x, n.y. n.z, d]
+    private final GLUniformData gcu_ClipFrustum; // uniform vec4  gcu_ClipFrustum[6]; // L, R, B, T, N, F
     private ShaderProgram spPass1 = null;
 
     // Pass-2:
@@ -76,6 +84,8 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
     private ShaderProgram spPass2 = null;
 
     private FBObject fbo;
+    private TextureAttachment texA;
+    private GLReadBufferUtil screenshot = SCREENSHOT_FBO ? new GLReadBufferUtil(true, false) : null;
 
     private int fboWidth = 0;
     private int fboHeight = 0;
@@ -97,13 +107,19 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
 
         if( hasColorTexture() ) {
             gcu_ColorTexUnit = new GLUniformData(UniformNames.gcu_ColorTexUnit, colorTexSeq.getTextureUnit());
-            colorTexBBox = new float[4];
-            gcu_ColorTexBBox = new GLUniformData(UniformNames.gcu_ColorTexBBox, 4, FloatBuffer.wrap(colorTexBBox));
+            colorTexBBox = new float[6];
+            gcu_ColorTexBBox = new GLUniformData(UniformNames.gcu_ColorTexBBox, 2, FloatBuffer.wrap(colorTexBBox));
+            colorTexClearCol = new float[4];
+            gcu_ColorTexClearCol = new GLUniformData(UniformNames.gcu_ColorTexClearCol, 4, FloatBuffer.wrap(colorTexClearCol));
         } else {
             gcu_ColorTexUnit = null;
             colorTexBBox = null;
             gcu_ColorTexBBox = null;
+            colorTexClearCol = null;
+            gcu_ColorTexClearCol = null;
         }
+        clipFrustum = new float[4*6];
+        gcu_ClipFrustum = new GLUniformData(UniformNames.gcu_ClipFrustum, 4, FloatBuffer.wrap(clipFrustum));
         gcu_PMVMatrix02 = new GLUniformData(UniformNames.gcu_PMVMatrix02, 4, 4, new SyncMatrices4f16( new Matrix4f[] { matP, matMv } ));
 
         // Pass 2:
@@ -137,8 +153,8 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
     }
 
     @Override
-    protected void updateImpl(final GL2ES2 gl, final int curRenderModes) {
-        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
+    protected void updateImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes) {
+        // final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
         final boolean hasColorTexture = Region.hasColorTexture( curRenderModes );
 
         // seal buffers
@@ -146,31 +162,13 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
         indicesBuffer.enableBuffer(gl, false);
         vpc_ileave.seal(gl, true);
         vpc_ileave.enableBuffer(gl, false);
-
         if( hasColorTexture && null != gcu_ColorTexUnit && colorTexSeq.isTextureAvailable() ) {
-            final TextureSequence.TextureFrame frame = colorTexSeq.getLastTexture();
-            final Texture tex = frame.getTexture();
-            final TextureCoords tc = tex.getImageTexCoords();
-            final float tcSx = 1f / ( tc.right() - tc.left() );
-            colorTexBBox[0] = box.getMinX() * tcSx;
-            colorTexBBox[2] = box.getMaxX() * tcSx;
-            if( tex.getMustFlipVertically() ) {
-                final float tcSy = 1f / ( tc.bottom() - tc.top() );
-                colorTexBBox[1] = box.getMaxY() * tcSy;
-                colorTexBBox[3] = box.getMinY() * tcSy;
+            if( colorTexSeq.useARatioAdjustment() ) {
+                TextureSequence.setTexCoordBBox(colorTexSeq.getLastTexture().getTexture(), box, colorTexSeq.useARatioLetterbox(), colorTexBBox, false);
             } else {
-                final float tcSy = 1f / ( tc.top() - tc.bottom() );
-                colorTexBBox[1] = box.getMinY() * tcSy;
-                colorTexBBox[3] = box.getMaxY() * tcSy;
+                TextureSequence.setTexCoordBBoxSimple(colorTexSeq.getLastTexture().getTexture(), box, colorTexBBox, false);
             }
-        }
-        gca_FboVerticesAttr.seal(gl, false);
-        {
-            final FloatBuffer fb = (FloatBuffer)gca_FboVerticesAttr.getBuffer();
-            fb.put( 2, box.getMinZ());
-            fb.put( 5, box.getMinZ());
-            fb.put( 8, box.getMinZ());
-            fb.put(11, box.getMinZ());
+            colorTexSeq.getARatioLetterboxBackColor().toArray(colorTexClearCol);
         }
         // Pending gca_FboVerticesAttr-seal and fboPMVMatrix-setup, follow fboDirty
 
@@ -190,25 +188,27 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
      *
      * @param gl
      * @param renderer
-     * @param renderModes
      * @param pass1
-     * @param quality
-     * @param sampleCount
+     * @param renderModes
      */
-    public void useShaderProgram(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final boolean pass1, final int quality, final int sampleCount) {
+    public void useShaderProgram(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final boolean pass1) {
         final boolean isTwoPass = Region.isTwoPass( curRenderModes );
         final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
         final boolean hasColorTexture = Region.hasColorTexture( curRenderModes ) && null != colorTexSeq;
 
         final RenderState rs = renderer.getRenderState();
-        final boolean updateLocGlobal = renderer.useShaderProgram(gl, curRenderModes, pass1, quality, sampleCount, colorTexSeq);
+        final boolean hasFrustumClipping = null != rs.getClipFrustum() && ( ( !isTwoPass && pass1 ) || ( isTwoPass && !pass1 ) );
+
+        final boolean updateLocGlobal = renderer.useShaderProgram(gl, curRenderModes, pass1, colorTexSeq);
         final ShaderProgram sp = renderer.getRenderState().getShaderProgram();
         final boolean updateLocLocal;
         if( pass1 ) {
             updateLocLocal = !sp.equals(spPass1);
             spPass1 = sp;
             if( DEBUG ) {
-                System.err.println("XXX changedSP.p1 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal);
+                if( DEBUG_ALL_EVENT || updateLocLocal || updateLocGlobal ) {
+                    System.err.println("XXX changedSP.p1 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal+", sp "+sp.program()+" / "+sp.id());
+                }
             }
             if( updateLocLocal ) {
                 rs.updateAttributeLoc(gl, true, gca_VerticesAttr, true);
@@ -217,27 +217,35 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
                     rs.updateAttributeLoc(gl, true, gca_ColorsAttr, true);
                 }
             }
-            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, true);
             if( isTwoPass ) {
+                rsLocal.update(gl, rs, updateLocLocal, curRenderModes, false, true, true);
                 rs.updateUniformLoc(gl, updateLocLocal, gcu_PMVMatrix02, true);
+            } else {
+                rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, true, true);
             }
             if( hasColorTexture && null != gcu_ColorTexUnit ) {
                 rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexUnit, true);
                 rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexBBox, true);
+                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexClearCol, true);
             }
         } else {
             updateLocLocal = !sp.equals(spPass2);
             spPass2 = sp;
             if( DEBUG ) {
-                System.err.println("XXX changedSP.p2 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal);
+                if( DEBUG_ALL_EVENT || updateLocLocal || updateLocGlobal ) {
+                    System.err.println("XXX changedSP.p2 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal+", sp "+sp.program()+" / "+sp.id());
+                }
             }
             if( updateLocLocal ) {
                 rs.updateAttributeLoc(gl, true, gca_FboVerticesAttr, true);
                 rs.updateAttributeLoc(gl, true, gca_FboTexCoordsAttr, true);
             }
-            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, false, true);
+            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, false, true);
             rs.updateUniformDataLoc(gl, updateLocLocal, false /* updateData */, gcu_FboTexUnit, true); // FIXME always update if changing tex-unit
         }
+        if( hasFrustumClipping && updateLocLocal ) {
+            rs.updateUniformLoc(gl, true, gcu_ClipFrustum, true);
+        }
     }
 
     private final AABBox drawWinBox = new AABBox();
@@ -246,7 +254,7 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
     private static final int border = 2; // surrounding border, i.e. width += 2*border, height +=2*border
 
     @Override
-    protected void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final int[/*1*/] sampleCount) {
+    protected void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes) {
         if( 0 >= indicesBuffer.getElemCount() ) {
             if(DEBUG_INSTANCE) {
                 System.err.printf("VBORegion2PMSAAES2.drawImpl: Empty%n");
@@ -259,16 +267,16 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
             }
             return; // inf
         }
+        final RenderState rs = renderer.getRenderState();
         final int vpWidth = renderer.getWidth();
         final int vpHeight = renderer.getHeight();
-        if(vpWidth <=0 || vpHeight <= 0 || null==sampleCount || sampleCount[0] <= 0) {
-            useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-            renderRegion(gl, curRenderModes);
+        if(vpWidth <=0 || vpHeight <= 0 || rs.getSampleCount() < 0) {
+            useShaderProgram(gl, renderer, curRenderModes, true);
+            renderRegion(gl, rs, curRenderModes);
         } else {
             if(0 > maxTexSize[0]) {
                 gl.glGetIntegerv(GL.GL_MAX_TEXTURE_SIZE, maxTexSize, 0);
             }
-            final RenderState rs = renderer.getRenderState();
             final float winWidth, winHeight;
 
             final float ratioObjWinWidth, ratioObjWinHeight;
@@ -284,7 +292,7 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
                 drawView.setWidth(vpWidth);
                 drawView.setHeight(vpHeight);
 
-                box.mapToWindow(drawWinBox, renderer.getMatrix().getPMvMat(), drawView, true /* useCenterZ */);
+                box.mapToWindow(drawWinBox, renderer.getMatrix().getPMv(), drawView, true /* useCenterZ */);
 
                 winWidth = drawWinBox.getWidth();
                 winHeight = drawWinBox.getHeight();
@@ -313,11 +321,11 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
                             diffObjWidth, diffObjHeight, ratioObjWinWidth, ratioObjWinWidth, diffObjBorderWidth, diffObjBorderHeight);
                     System.err.printf("XXX.MinMax win %s%n", drawWinBox.toString());
                     System.err.printf("XXX.MinMax view[%s] -> win[%.3f, %.3f], i[%d x %d], d[%.3f, %.3f], r[%f, %f]: FBO i[%d x %d], samples %d%n",
-                            drawView, drawView,
-                            winWidth, winHeight, targetWinWidth, targetWinHeight, diffWinWidth,
-                            diffWinHeight, ratioWinWidth, ratioWinHeight,
+                            drawView,
+                            winWidth, winHeight, targetWinWidth, targetWinHeight,
+                            diffWinWidth, diffWinHeight, ratioWinWidth, ratioWinHeight,
                             targetFboWidth, targetFboHeight,
-                            sampleCount[0]);
+                            rs.getSampleCount());
                 }
             }
             if( 0 >= targetFboWidth || 0 >= targetFboHeight ) {
@@ -331,40 +339,47 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
                 System.err.printf("XXX.maxDelta: hasDelta %b: %d / %d,  %.3f, %.3f%n",
                         hasDelta, deltaFboWidth, deltaFboHeight, (float)deltaFboWidth/fboWidth, (float)deltaFboHeight/fboHeight);
                 System.err.printf("XXX.Scale %d * [%f x %f]: %d x %d%n",
-                        sampleCount[0], winWidth, winHeight, targetFboWidth, targetFboHeight);
+                        rs.getSampleCount(), winWidth, winHeight, targetFboWidth, targetFboHeight);
             }
-            if( hasDelta || fboDirty || isShapeDirty() || null == fbo || fbo.getNumSamples() != sampleCount[0] ) {
+            if( hasDelta || fboDirty || isShapeDirty() || null == fbo ) {
                 // FIXME: rescale
                 final float minX = box.getMinX()-diffObjBorderWidth;
                 final float minY = box.getMinY()-diffObjBorderHeight;
                 final float maxX = box.getMaxX()+diffObjBorderWidth+diffObjWidth;
                 final float maxY = box.getMaxY()+diffObjBorderHeight+diffObjHeight;
+                final float minZ = box.getMinZ();
                 gca_FboVerticesAttr.seal(false);
                 {
                     final FloatBuffer fb = (FloatBuffer)gca_FboVerticesAttr.getBuffer();
-                    fb.put(0, minX); fb.put( 1, minY);
-                    fb.put(3, minX); fb.put( 4, maxY);
-                    fb.put(6, maxX); fb.put( 7, maxY);
-                    fb.put(9, maxX); fb.put(10, minY);
+                    fb.put(0, minX); fb.put( 1, minY); fb.put( 2, minZ);
+                    fb.put(3, minX); fb.put( 4, maxY); fb.put( 5, minZ);
+                    fb.put(6, maxX); fb.put( 7, maxY); fb.put( 8, minZ);
+                    fb.put(9, maxX); fb.put(10, minY); fb.put(11, minZ);
                     fb.position(12);
                 }
                 gca_FboVerticesAttr.seal(true);
                 matP.setToOrtho(minX, maxX, minY, maxY, -1, 1);
-                useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-                renderRegion2FBO(gl, rs, curRenderModes, targetFboWidth, targetFboHeight, vpWidth, vpHeight, sampleCount);
+                useShaderProgram(gl, renderer, curRenderModes, true);
+                renderRegion2FBO(gl, rs, curRenderModes,
+                                 // (int)drawWinBox.getMinX(), (int)drawWinBox.getMinY(), targetFboWidth, targetFboHeight,
+                                 0, 0, targetFboWidth, targetFboHeight,
+                                 vpWidth, vpHeight);
             } else if( isStateDirty() ) {
-                useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-                renderRegion2FBO(gl, rs, curRenderModes, targetFboWidth, targetFboHeight, vpWidth, vpHeight, sampleCount);
+                useShaderProgram(gl, renderer, curRenderModes, true);
+                renderRegion2FBO(gl, rs, curRenderModes,
+                                 // (int)drawWinBox.getMinX(), (int)drawWinBox.getMinY(), targetFboWidth, targetFboHeight,
+                                 0, 0, targetFboWidth, targetFboHeight,
+                                 vpWidth, vpHeight);
             }
-            useShaderProgram(gl, renderer, curRenderModes, false, getQuality(), sampleCount[0]);
-            renderFBO(gl, rs, vpWidth, vpHeight, sampleCount[0]);
+            useShaderProgram(gl, renderer, curRenderModes, false);
+            renderFBO(gl, rs, vpWidth, vpHeight);
         }
     }
 
-    private void renderFBO(final GL2ES2 gl, final RenderState rs, final int width, final int height, final int sampleCount) {
+    private void renderFBO(final GL2ES2 gl, final RenderState rs, final int width, final int height) {
         gl.glViewport(0, 0, width, height);
 
-        if( rs.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED | RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED) ) {
+        if( rs.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED | RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED) ) {
             // BITHINT_GLOBAL_DEPTH_TEST_ENABLED path added by commit 45395696c252c215a8a22d05e5da7e98c662d07e (2014-04-10),
             // but not in VBORegion2PVBAA.renderVBO(..) -> investigate if required for working MSAA:
             // - "VBORegion2PMSAAES2 enables/disables GL_DEPTH_TEST, otherwise MSAA is corrupt"
@@ -373,14 +388,22 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
             gl.glBlendFunc(GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
             gl.glEnable(GL.GL_DEPTH_TEST);
 
-        } else if( rs.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED) ) {
+        } else if( rs.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED) ) {
             // RGB is already multiplied w/ alpha via renderRegion2FBO(..)
             gl.glBlendFunc(GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
         }
 
+        {
+            final Frustum f = rs.getClipFrustum();
+            if( null != f ) {
+                f.getPlanes(clipFrustum, 0);
+                gl.glUniform(gcu_ClipFrustum); // Always update, since program maybe used by multiple regions
+            }
+        }
+
         gl.glActiveTexture(GL.GL_TEXTURE0 + gcu_FboTexUnit.intValue());
 
-        fbo.use(gl, fbo.getSamplingSink().getTextureAttachment());
+        fbo.use(gl, texA);
         gca_FboVerticesAttr.enableBuffer(gl, true);
         gca_FboTexCoordsAttr.enableBuffer(gl, true);
         indicesFbo.bindBuffer(gl, true); // keeps VBO binding
@@ -396,44 +419,58 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
     }
 
     private void renderRegion2FBO(final GL2ES2 gl, final RenderState rs, final int curRenderModes,
-                                  final int targetFboWidth, final int targetFboHeight,
-                                  final int vpWidth, final int vpHeight, final int[] sampleCount) {
+                                  final int fboX, final int fboY, final int targetFboWidth, final int targetFboHeight,
+                                  final int vpWidth, final int vpHeight) {
         if( 0 >= targetFboWidth || 0 >= targetFboHeight ) {
-            throw new IllegalArgumentException("fboSize must be greater than 0: "+targetFboWidth+"x"+targetFboHeight);
+            throw new IllegalArgumentException("targetFBOSize "+targetFboWidth+"x"+targetFboHeight+" must be greater than 0");
+        }
+        final boolean blendingEnabled = rs.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED);
+        final int targetFboSamples = rs.getSampleCount() > 1 ? rs.getSampleCount() : 0;
+        final boolean fboSampleTypeMatch;
+        {
+            final int oldSampleCount = null != fbo ? fbo.getNumSamples() : 0;
+            fboSampleTypeMatch = ( oldSampleCount > 1 && targetFboSamples > 1 ) || ( oldSampleCount <= 1 && targetFboSamples <= 1 );
         }
 
-        final boolean blendingEnabled = rs.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED);
-
-        if(null == fbo) {
+        if(null == fbo || !fboSampleTypeMatch) {
+            if( null != fbo ) {
+                fbo.destroy(gl);
+            }
             fboWidth  = targetFboWidth;
             fboHeight  = targetFboHeight;
             fbo = new FBObject();
-            fbo.init(gl, fboWidth, fboHeight, sampleCount[0]);
-            sampleCount[0] = fbo.getNumSamples();
-            fbo.attachColorbuffer(gl, 0, true);
-            if( !blendingEnabled ) {
-                // no depth-buffer w/ blending
-                fbo.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
-            }
-            final FBObject ssink = new FBObject();
-            {
-                ssink.init(gl, fboWidth, fboHeight, 0);
-                // FIXME: shall not use bilinear (GL_LINEAR), due to MSAA ???
-                // ssink.attachTexture2D(gl, 0, true, GL2ES2.GL_LINEAR, GL2ES2.GL_LINEAR, GL2ES2.GL_CLAMP_TO_EDGE, GL2ES2.GL_CLAMP_TO_EDGE);
-                ssink.attachTexture2D(gl, 0, true, GL.GL_NEAREST, GL.GL_NEAREST, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
+            fbo.init(gl, targetFboWidth, targetFboHeight, targetFboSamples);
+            rs.setSampleCount( Math.max(1, fbo.getNumSamples()) );
+            if( 0 == targetFboSamples ) {
+                texA = fbo.attachTexture2D(gl, 0, true, GL.GL_LINEAR, GL.GL_LINEAR, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
                 if( !blendingEnabled ) {
                     // no depth-buffer w/ blending
-                    ssink.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
+                    fbo.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
                 }
+            } else {
+                fbo.attachColorbuffer(gl, 0, true);
+                if( !blendingEnabled ) {
+                    // no depth-buffer w/ blending
+                    fbo.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
+                }
+                final FBObject ssink = new FBObject();
+                {
+                    ssink.init(gl, targetFboWidth, targetFboHeight, 0);
+                    texA = ssink.attachTexture2D(gl, 0, true, GL.GL_NEAREST, GL.GL_NEAREST, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
+                    if( !blendingEnabled ) {
+                        // no depth-buffer w/ blending
+                        ssink.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
+                    }
+                }
+                fbo.setSamplingSink(ssink);
+                fbo.resetSamplingSink(gl); // validate
             }
-            fbo.setSamplingSink(ssink);
-            fbo.resetSamplingSink(gl); // validate
             if( DEBUG_FBO_1 ) {
-                System.err.printf("XXX.createFBO: blending %b, %dx%d%n%s%n", blendingEnabled, fboWidth, fboHeight, fbo.toString());
+                System.err.printf("XXX.createFBO: blending %b, %dx%d%n%s%n", blendingEnabled, targetFboWidth, targetFboHeight, fbo.toString());
             }
-        } else if( targetFboWidth != fboWidth || targetFboHeight != fboHeight || fbo.getNumSamples() != sampleCount[0] ) {
-            fbo.reset(gl, targetFboWidth, targetFboHeight, sampleCount[0]);
-            sampleCount[0] = fbo.getNumSamples();
+        } else if( targetFboWidth != fboWidth || targetFboHeight != fboHeight || fbo.getNumSamples() != targetFboSamples ) {
+            fbo.reset(gl, targetFboWidth, targetFboHeight, targetFboSamples);
+            rs.setSampleCount( Math.max(1, fbo.getNumSamples()) );
             if( DEBUG_FBO_1 ) {
                 System.err.printf("XXX.resetFBO: %dx%d -> %dx%d%n%s%n", fboWidth, fboHeight, targetFboWidth, targetFboHeight, fbo );
             }
@@ -443,7 +480,7 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
         fbo.bind(gl);
 
         //render texture
-        gl.glViewport(0, 0, fboWidth, fboHeight);
+        gl.glViewport(fboX, fboY, targetFboWidth, targetFboHeight);
         if( blendingEnabled ) {
             gl.glClearColor(0f, 0f, 0f, 0.0f);
             gl.glClear(GL.GL_COLOR_BUFFER_BIT); // no depth-buffer w/ blending
@@ -453,24 +490,33 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
             // Multiply RGB w/ Alpha, preserve alpha for renderFBO(..)
             gl.glBlendFuncSeparate(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA, GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
 
-            if( rs.isHintMaskSet(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED) ) {
+            if( rs.hintBitsSet(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED) ) {
                 gl.glDisable(GL.GL_DEPTH_TEST);
             }
         } else {
             gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
         }
 
-        renderRegion(gl, curRenderModes);
+        renderRegion(gl, rs, curRenderModes);
+
+        if( SCREENSHOT_FBO ) {
+            screenshot.setReadBuffer(GL.GL_COLOR_ATTACHMENT0);
+            if(screenshot.readPixels(gl, fboX, fboY, targetFboWidth, targetFboHeight, false)) {
+                final File f = new File("screenshot_vboregion2pmsaa.png");
+                screenshot.write(f);
+            }
+        }
 
         fbo.unbind(gl);
         fboDirty = false;
     }
 
-    private void renderRegion(final GL2ES2 gl, final int curRenderModes) {
-        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
+    private void renderRegion(final GL2ES2 gl, final RenderState rs, final int curRenderModes) {
+        // final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
         final boolean hasColorTexture = Region.hasColorTexture( curRenderModes );
 
         gl.glUniform(gcu_PMVMatrix02);
+
         vpc_ileave.enableBuffer(gl, true);
         indicesBuffer.bindBuffer(gl, true); // keeps VBO binding
         if( hasColorTexture && null != gcu_ColorTexUnit && colorTexSeq.isTextureAvailable() ) {
@@ -482,6 +528,7 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
             gcu_ColorTexUnit.setData(colorTexSeq.getTextureUnit());
             gl.glUniform(gcu_ColorTexUnit); // Always update, since program maybe used by multiple regions
             gl.glUniform(gcu_ColorTexBBox); // Always update, since program maybe used by multiple regions
+            gl.glUniform(gcu_ColorTexClearCol); // Always update, since program maybe used by multiple regions
             gl.glDrawElements(GL.GL_TRIANGLES, indicesBuffer.getElemCount() * indicesBuffer.getCompsPerElem(), glIdxType(), 0);
             tex.disable(gl); // nop on core
         } else {
@@ -500,6 +547,7 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
         if(null != fbo) {
             fbo.destroy(gl);
             fbo = null;
+            texA = null;
         }
         if(null != gca_FboVerticesAttr) {
             gca_FboVerticesAttr.destroy(gl);
@@ -513,6 +561,10 @@ public final class VBORegion2PMSAAES2  extends GLRegion {
             indicesFbo.destroy(gl);
             indicesFbo = null;
         }
+        if( null != screenshot ) {
+            screenshot.dispose(gl);
+            screenshot = null;
+        }
         spPass1 = null; // owned by RegionRenderer
         spPass2 = null; // owned by RegionRenderer
     }
