@@ -1,5 +1,5 @@
 /**
- * Copyright 2010-2023 JogAmp Community. All rights reserved.
+ * Copyright 2010-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -27,6 +27,7 @@
  */
 package jogamp.graph.curve.opengl;
 
+import java.io.File;
 import java.nio.FloatBuffer;
 
 import com.jogamp.opengl.GL2ES2;
@@ -38,64 +39,43 @@ import jogamp.graph.curve.opengl.shader.AttributeNames;
 import jogamp.graph.curve.opengl.shader.UniformNames;
 import jogamp.opengl.Debug;
 
-import com.jogamp.common.util.PropertyAccess;
 import com.jogamp.graph.curve.Region;
 import com.jogamp.graph.curve.opengl.GLRegion;
 import com.jogamp.graph.curve.opengl.RegionRenderer;
 import com.jogamp.graph.curve.opengl.RenderState;
+import com.jogamp.math.Matrix4f;
+import com.jogamp.math.Recti;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.Frustum;
+import com.jogamp.math.util.SyncMatrices4f16;
 import com.jogamp.opengl.FBObject;
 import com.jogamp.opengl.FBObject.Attachment;
 import com.jogamp.opengl.FBObject.TextureAttachment;
-import com.jogamp.opengl.math.Matrix4f;
-import com.jogamp.opengl.math.Recti;
-import com.jogamp.opengl.math.geom.AABBox;
 import com.jogamp.opengl.util.GLArrayDataServer;
-import com.jogamp.opengl.util.SyncMatrices4f16;
+import com.jogamp.opengl.util.GLReadBufferUtil;
 import com.jogamp.opengl.util.glsl.ShaderProgram;
 import com.jogamp.opengl.util.texture.Texture;
-import com.jogamp.opengl.util.texture.TextureCoords;
 import com.jogamp.opengl.util.texture.TextureSequence;
 
 public final class VBORegion2PVBAAES2  extends GLRegion {
     private static final boolean DEBUG_FBO_1 = false;
     private static final boolean DEBUG_FBO_2 = false;
-
-    /**
-     * Boundary triggering FBO resize if
-     * <pre>
-     *      fbo[Width|Height] - targetFbo[Width|Height] > RESIZE_BOUNDARY.
-     * </pre>
-     * <p>
-     * Increasing the FBO will add RESIZE_BOUNDARY/2.
-     * </p>
-     * <p>
-     * Reducing FBO resize to gain performance.
-     * </p>
-     * <p>
-     * Defaults to disabled since:
-     *   - not working properly
-     *   - FBO texture rendered > than desired size
-     *   - FBO resize itself should be fast enough ?!
-     * </p>
-     */
-    private static final int RESIZE_BOUNDARY;
+    private static final boolean SCREENSHOT_FBO = false;
 
     static {
         Debug.initSingleton();
-        final String key = "jogl.debug.graph.curve.vbaa.resizeLowerBoundary";
-        RESIZE_BOUNDARY = Math.max(0, PropertyAccess.getIntProperty(key, true, 0));
-        if( RESIZE_BOUNDARY > 0 ) {
-            System.err.println("key: "+RESIZE_BOUNDARY);
-        }
     }
 
-
     private final RenderState.ProgramLocal rsLocal;
 
     // Pass-1:
     private final GLUniformData gcu_ColorTexUnit;
-    private final float[] colorTexBBox; // x0, y0, x1, y1
-    private final GLUniformData gcu_ColorTexBBox;
+    private final float[] colorTexBBox; // minX/minY, maxX/maxY, texW/texH
+    private final GLUniformData gcu_ColorTexBBox; // vec2 gcu_ColorTexBBox[3] -> boxMin[2], boxMax[2] and texSize[2]
+    private final float[] colorTexClearCol;
+    private final GLUniformData gcu_ColorTexClearCol; // vec4 gcu_ColorTexClearCol
+    private final float[/* 4*6 */] clipFrustum; // 6 frustum planes, each [n.x, n.y. n.z, d]
+    private final GLUniformData gcu_ClipFrustum; // uniform vec4  gcu_ClipFrustum[6]; // L, R, B, T, N, F
     private ShaderProgram spPass1 = null;
 
     // Pass-2:
@@ -111,6 +91,7 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
 
     private FBObject fbo;
     private TextureAttachment texA;
+    private GLReadBufferUtil screenshot = SCREENSHOT_FBO ? new GLReadBufferUtil(true, false) : null;
 
     private int fboWidth = 0;
     private int fboHeight = 0;
@@ -118,65 +99,6 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
 
     final int[] maxTexSize = new int[] { -1 } ;
 
-    /**
-     * <p>
-     * Since multiple {@link Region}s may share one
-     * {@link ShaderProgram} managed and owned by {@link RegionRendered}, the uniform data must always be updated.
-     * </p>
-     *
-     * @param gl
-     * @param renderer
-     * @param curRenderModes
-     * @param pass1
-     * @param quality
-     * @param sampleCount
-     */
-    public void useShaderProgram(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final boolean pass1, final int quality, final int sampleCount) {
-        final boolean isTwoPass = Region.isTwoPass( curRenderModes );
-        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
-        final boolean hasColorTexture = Region.hasColorTexture( curRenderModes ) && null != colorTexSeq;
-
-        final RenderState rs = renderer.getRenderState();
-        final boolean updateLocGlobal = renderer.useShaderProgram(gl, curRenderModes, pass1, quality, sampleCount, colorTexSeq);
-        final ShaderProgram sp = renderer.getRenderState().getShaderProgram();
-        final boolean updateLocLocal;
-        if( pass1 ) {
-            updateLocLocal = !sp.equals(spPass1);
-            spPass1 = sp;
-            if( DEBUG ) {
-                System.err.println("XXX changedSP.p1 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal);
-            }
-            if( updateLocLocal ) {
-                rs.updateAttributeLoc(gl, true, gca_VerticesAttr, true);
-                rs.updateAttributeLoc(gl, true, gca_CurveParamsAttr, true);
-                if( hasColorChannel && null != gca_ColorsAttr ) {
-                    rs.updateAttributeLoc(gl, true, gca_ColorsAttr, true);
-                }
-            }
-            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, true);
-            if( isTwoPass ) {
-                rs.updateUniformLoc(gl, updateLocLocal, gcu_PMVMatrix02, true);
-            }
-            if( hasColorTexture && null != gcu_ColorTexUnit ) {
-                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexUnit, true);
-                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexBBox, true);
-            }
-        } else {
-            updateLocLocal = !sp.equals(spPass2);
-            spPass2 = sp;
-            if( DEBUG ) {
-                System.err.println("XXX changedSP.p2 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal);
-            }
-            if( updateLocLocal ) {
-                rs.updateAttributeLoc(gl, true, gca_FboVerticesAttr, true);
-                rs.updateAttributeLoc(gl, true, gca_FboTexCoordsAttr, true);
-            }
-            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, false, true);
-            rs.updateUniformDataLoc(gl, updateLocLocal, false /* updateData */, gcu_FboTexUnit, true); // FIXME always update if changing tex-unit
-            rs.updateUniformLoc(gl, updateLocLocal, gcu_FboTexSize, sampleCount > 1); // maybe optimized away for sampleCount <= 1
-        }
-    }
-
     public VBORegion2PVBAAES2(final GLProfile glp, final int renderModes, final TextureSequence colorTexSeq, final int pass2TexUnit,
                               final int initialVerticesCount, final int initialIndicesCount)
     {
@@ -189,13 +111,19 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
 
         if( hasColorTexture() ) {
             gcu_ColorTexUnit = new GLUniformData(UniformNames.gcu_ColorTexUnit, colorTexSeq.getTextureUnit());
-            colorTexBBox = new float[4];
-            gcu_ColorTexBBox = new GLUniformData(UniformNames.gcu_ColorTexBBox, 4, FloatBuffer.wrap(colorTexBBox));
+            colorTexBBox = new float[6];
+            gcu_ColorTexBBox = new GLUniformData(UniformNames.gcu_ColorTexBBox, 2, FloatBuffer.wrap(colorTexBBox));
+            colorTexClearCol = new float[4];
+            gcu_ColorTexClearCol = new GLUniformData(UniformNames.gcu_ColorTexClearCol, 4, FloatBuffer.wrap(colorTexClearCol));
         } else {
             gcu_ColorTexUnit = null;
             colorTexBBox = null;
             gcu_ColorTexBBox = null;
+            colorTexClearCol = null;
+            gcu_ColorTexClearCol = null;
         }
+        clipFrustum = new float[4*6];
+        gcu_ClipFrustum = new GLUniformData(UniformNames.gcu_ClipFrustum, 4, FloatBuffer.wrap(clipFrustum));
         gcu_PMVMatrix02 = new GLUniformData(UniformNames.gcu_PMVMatrix02, 4, 4, new SyncMatrices4f16( new Matrix4f[] { matP, matMv } ));
 
         // Pass 2:
@@ -219,6 +147,75 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
                                                            false, 4, GL.GL_STATIC_DRAW);
     }
 
+    /**
+     * <p>
+     * Since multiple {@link Region}s may share one
+     * {@link ShaderProgram} managed and owned by {@link RegionRendered}, the uniform data must always be updated.
+     * </p>
+     *
+     * @param gl
+     * @param renderer
+     * @param curRenderModes
+     * @param pass1
+     */
+    public void useShaderProgram(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final boolean pass1) {
+        final boolean isTwoPass = Region.isTwoPass( curRenderModes );
+        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
+        final boolean hasColorTexture = Region.hasColorTexture( curRenderModes ) && null != colorTexSeq;
+
+        final RenderState rs = renderer.getRenderState();
+        final boolean hasFrustumClipping = null != rs.getClipFrustum() && ( ( !isTwoPass && pass1 ) || ( isTwoPass && !pass1 ) );
+
+        final boolean updateLocGlobal = renderer.useShaderProgram(gl, curRenderModes, pass1, colorTexSeq);
+        final ShaderProgram sp = renderer.getRenderState().getShaderProgram();
+        final boolean updateLocLocal;
+        if( pass1 ) {
+            updateLocLocal = !sp.equals(spPass1);
+            spPass1 = sp;
+            if( DEBUG ) {
+                if( DEBUG_ALL_EVENT || updateLocLocal || updateLocGlobal ) {
+                    System.err.println("XXX changedSP.p1 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal+", sp "+sp.program()+" / "+sp.id());
+                }
+            }
+            if( updateLocLocal ) {
+                rs.updateAttributeLoc(gl, true, gca_VerticesAttr, true);
+                rs.updateAttributeLoc(gl, true, gca_CurveParamsAttr, true);
+                if( hasColorChannel && null != gca_ColorsAttr ) {
+                    rs.updateAttributeLoc(gl, true, gca_ColorsAttr, true);
+                }
+            }
+            if( isTwoPass ) {
+                rsLocal.update(gl, rs, updateLocLocal, curRenderModes, false, true, true);
+                rs.updateUniformLoc(gl, updateLocLocal, gcu_PMVMatrix02, true);
+            } else {
+                rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, true, true);
+            }
+            if( hasColorTexture && null != gcu_ColorTexUnit ) {
+                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexUnit, true);
+                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexBBox, true);
+                rs.updateUniformLoc(gl, updateLocLocal, gcu_ColorTexClearCol, true);
+            }
+        } else {
+            updateLocLocal = !sp.equals(spPass2);
+            spPass2 = sp;
+            if( DEBUG ) {
+                if( DEBUG_ALL_EVENT || updateLocLocal || updateLocGlobal ) {
+                    System.err.println("XXX changedSP.p2 updateLocation loc "+updateLocLocal+" / glob "+updateLocGlobal+", sp "+sp.program()+" / "+sp.id());
+                }
+            }
+            if( updateLocLocal ) {
+                rs.updateAttributeLoc(gl, true, gca_FboVerticesAttr, true);
+                rs.updateAttributeLoc(gl, true, gca_FboTexCoordsAttr, true);
+            }
+            rsLocal.update(gl, rs, updateLocLocal, curRenderModes, true, false, true);
+            rs.updateUniformDataLoc(gl, updateLocLocal, false /* updateData */, gcu_FboTexUnit, true); // FIXME always update if changing tex-unit
+            rs.updateUniformLoc(gl, updateLocLocal, gcu_FboTexSize, rs.getSampleCount() > 1); // maybe optimized away for sampleCount <= 1
+        }
+        if( hasFrustumClipping && updateLocLocal ) {
+            rs.updateUniformLoc(gl, true, gcu_ClipFrustum, true);
+        }
+    }
+
     @Override
     public void setTextureUnit(final int pass2TexUnit) {
         gcu_FboTexUnit.setData(pass2TexUnit);
@@ -230,8 +227,8 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
     }
 
     @Override
-    protected void updateImpl(final GL2ES2 gl, final int curRenderModes) {
-        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
+    protected void updateImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes) {
+        // final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
         final boolean hasColorTexture = Region.hasColorTexture( curRenderModes );
 
         // seal buffers
@@ -240,29 +237,12 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
         vpc_ileave.seal(gl, true);
         vpc_ileave.enableBuffer(gl, false);
         if( hasColorTexture && null != gcu_ColorTexUnit && colorTexSeq.isTextureAvailable() ) {
-            final TextureSequence.TextureFrame frame = colorTexSeq.getLastTexture();
-            final Texture tex = frame.getTexture();
-            final TextureCoords tc = tex.getImageTexCoords();
-            final float tcSx = 1f / ( tc.right() - tc.left() );
-            colorTexBBox[0] = box.getMinX() * tcSx;
-            colorTexBBox[2] = box.getMaxX() * tcSx;
-            if( tex.getMustFlipVertically() ) {
-                final float tcSy = 1f / ( tc.bottom() - tc.top() );
-                colorTexBBox[1] = box.getMaxY() * tcSy;
-                colorTexBBox[3] = box.getMinY() * tcSy;
+            if( colorTexSeq.useARatioAdjustment() ) {
+                TextureSequence.setTexCoordBBox(colorTexSeq.getLastTexture().getTexture(), box, colorTexSeq.useARatioLetterbox(), colorTexBBox, false);
             } else {
-                final float tcSy = 1f / ( tc.top() - tc.bottom() );
-                colorTexBBox[1] = box.getMinY() * tcSy;
-                colorTexBBox[3] = box.getMaxY() * tcSy;
+                TextureSequence.setTexCoordBBoxSimple(colorTexSeq.getLastTexture().getTexture(), box, colorTexBBox, false);
             }
-        }
-        gca_FboVerticesAttr.seal(gl, false);
-        {
-            final FloatBuffer fb = (FloatBuffer)gca_FboVerticesAttr.getBuffer();
-            fb.put( 2, box.getMinZ());
-            fb.put( 5, box.getMinZ());
-            fb.put( 8, box.getMinZ());
-            fb.put(11, box.getMinZ());
+            colorTexSeq.getARatioLetterboxBackColor().toArray(colorTexClearCol);
         }
         // Pending gca_FboVerticesAttr-seal and fboPMVMatrix-setup, follow fboDirty
 
@@ -280,7 +260,7 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
     private static final int border = 2; // surrounding border, i.e. width += 2*border, height +=2*border
 
     @Override
-    protected void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes, final int[/*1*/] sampleCount) {
+    protected void drawImpl(final GL2ES2 gl, final RegionRenderer renderer, final int curRenderModes) {
         if( 0 >= indicesBuffer.getElemCount() ) {
             if(DEBUG_INSTANCE) {
                 System.err.printf("VBORegion2PVBAAES2.drawImpl: Empty%n");
@@ -293,16 +273,17 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
             }
             return; // inf
         }
+        final RenderState rs = renderer.getRenderState();
         final int vpWidth = renderer.getWidth();
         final int vpHeight = renderer.getHeight();
-        if(vpWidth <=0 || vpHeight <= 0 || null==sampleCount || sampleCount[0] <= 0) {
-            useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-            renderRegion(gl, curRenderModes);
+        int pass2SampleCount = rs.getSampleCount();
+        if(vpWidth <=0 || vpHeight <= 0 || pass2SampleCount < 0) {
+            useShaderProgram(gl, renderer, curRenderModes, true);
+            renderRegion(gl, rs, curRenderModes);
         } else {
             if(0 > maxTexSize[0]) {
                 gl.glGetIntegerv(GL.GL_MAX_TEXTURE_SIZE, maxTexSize, 0);
             }
-            final RenderState rs = renderer.getRenderState();
             final float winWidth, winHeight;
 
             final float ratioObjWinWidth, ratioObjWinHeight;
@@ -318,7 +299,7 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
                 drawView.setWidth(vpWidth);
                 drawView.setHeight(vpHeight);
 
-                box.mapToWindow(drawWinBox, renderer.getMatrix().getPMvMat(), drawView, true /* useCenterZ */);
+                box.mapToWindow(drawWinBox, renderer.getMatrix().getPMv(), drawView, true /* useCenterZ */);
 
                 winWidth = drawWinBox.getWidth();
                 winHeight = drawWinBox.getHeight();
@@ -334,16 +315,16 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
                 diffObjBorderWidth = border * ratioObjWinWidth;
                 diffObjBorderHeight = border * ratioObjWinHeight;
 
-                targetFboWidth = (targetWinWidth+2*border)*sampleCount[0];
-                targetFboHeight = (targetWinHeight+2*border)*sampleCount[0];
+                targetFboWidth = (targetWinWidth+2*border)*pass2SampleCount;
+                targetFboHeight = (targetWinHeight+2*border)*pass2SampleCount;
 
                 if( DEBUG_FBO_2 ) {
                     final float ratioWinWidth, ratioWinHeight;
                     ratioWinWidth = winWidth/targetWinWidth;
                     ratioWinHeight = winHeight/targetWinHeight;
                     final float renderFboWidth, renderFboHeight;
-                    renderFboWidth = (winWidth+2*border)*sampleCount[0];
-                    renderFboHeight = (winHeight+2*border)*sampleCount[0];
+                    renderFboWidth = (winWidth+2*border)*pass2SampleCount;
+                    renderFboHeight = (winHeight+2*border)*pass2SampleCount;
                     final float ratioFboWidth, ratioFboHeight;
                     ratioFboWidth = renderFboWidth/targetFboWidth;
                     ratioFboHeight = renderFboHeight/targetFboHeight;
@@ -357,11 +338,11 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
                     System.err.printf("XXX.MinMax win %s%n", drawWinBox.toString());
                     System.err.printf("XXX.MinMax view[%s] -> win[%.3f, %.3f], i[%d x %d], d[%.3f, %.3f], r[%f, %f]: FBO f[%.3f, %.3f], i[%d x %d], d[%.3f, %.3f], r[%f, %f], samples %d%n",
                             drawView,
-                            winWidth, winHeight, targetWinWidth, targetWinHeight, diffWinWidth,
-                            diffWinHeight, ratioWinWidth, ratioWinHeight,
+                            winWidth, winHeight, targetWinWidth, targetWinHeight,
+                            diffWinWidth, diffWinHeight, ratioWinWidth, ratioWinHeight,
                             renderFboWidth, renderFboHeight, targetFboWidth, targetFboHeight,
                             diffFboWidth, diffFboHeight, ratioFboWidth, ratioFboHeight,
-                            sampleCount[0]);
+                            pass2SampleCount);
                 }
             }
             if( 0 >= targetFboWidth || 0 >= targetFboHeight ) {
@@ -375,98 +356,64 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
                 System.err.printf("XXX.maxDelta: hasDelta %b: %d / %d,  %.3f, %.3f%n",
                         hasDelta, deltaFboWidth, deltaFboHeight, (float)deltaFboWidth/fboWidth, (float)deltaFboHeight/fboHeight);
                 System.err.printf("XXX.Scale %d * [%f x %f]: %d x %d%n",
-                        sampleCount[0], winWidth, winHeight, targetFboWidth, targetFboHeight);
+                        pass2SampleCount, winWidth, winHeight, targetFboWidth, targetFboHeight);
             }
             if( hasDelta || fboDirty || isShapeDirty() || null == fbo ) {
                 final int maxLength = Math.max(targetFboWidth, targetFboHeight);
                 if( maxLength > maxTexSize[0] ) {
                     if( targetFboWidth > targetFboHeight ) {
-                        sampleCount[0] = (int)Math.floor(maxTexSize[0] / (winWidth+2*border));
+                        pass2SampleCount = (int)Math.floor(maxTexSize[0] / (winWidth+2*border));
                     } else {
-                        sampleCount[0] = (int)Math.floor(maxTexSize[0] / (winHeight+2*border));
+                        pass2SampleCount = (int)Math.floor(maxTexSize[0] / (winHeight+2*border));
                     }
+                    rs.setSampleCount(pass2SampleCount);
                     final float renderFboWidth, renderFboHeight;
-                    renderFboWidth = (winWidth+2*border)*sampleCount[0];
-                    renderFboHeight = (winWidth+2*border)*sampleCount[0];
+                    renderFboWidth = (winWidth+2*border)*pass2SampleCount;
+                    renderFboHeight = (winHeight+2*border)*pass2SampleCount;
                     targetFboWidth = (int)Math.ceil(renderFboWidth);
                     targetFboHeight = (int)Math.ceil(renderFboHeight);
                     if( DEBUG_FBO_1 ) {
                         System.err.printf("XXX.Rescale (MAX): win[%.3f, %.3f]: FBO f[%.3f, %.3f], i[%d x %d], msaa %d%n",
                                 winWidth, winHeight,
-                                renderFboWidth, renderFboHeight, targetFboWidth, targetFboHeight, sampleCount[0]);
+                                renderFboWidth, renderFboHeight, targetFboWidth, targetFboHeight, pass2SampleCount);
                     }
-                    if( sampleCount[0] <= 0 ) {
+                    if( pass2SampleCount <= 0 ) {
                         // Last way out!
-                        renderRegion(gl, curRenderModes);
+                        renderRegion(gl, rs, curRenderModes);
                         return;
                     }
                 }
 
-                final int newFboWidth, newFboHeight, resizeCase;
-                if( 0 >= RESIZE_BOUNDARY ) {
-                    // Resize w/o optimization
-                    newFboWidth = targetFboWidth;
-                    newFboHeight = targetFboHeight;
-                    resizeCase = 0;
-                } else {
-                    if( 0 >= fboWidth || 0 >= fboHeight || null == fbo ) {
-                        // Case: New FBO
-                        newFboWidth = targetFboWidth;
-                        newFboHeight = targetFboHeight;
-                        resizeCase = 1;
-                    } else if( targetFboWidth > fboWidth || targetFboHeight > fboHeight ) {
-                        // Case: Inscrease FBO Size, add boundary/2 if avail
-                        newFboWidth = ( targetFboWidth + RESIZE_BOUNDARY/2 < maxTexSize[0] ) ? targetFboWidth + RESIZE_BOUNDARY/2 : targetFboWidth;
-                        newFboHeight = ( targetFboHeight+ RESIZE_BOUNDARY/2 < maxTexSize[0] ) ? targetFboHeight + RESIZE_BOUNDARY/2 : targetFboHeight;
-                        resizeCase = 2;
-                    } else if( targetFboWidth < fboWidth && targetFboHeight < fboHeight &&
-                               fboWidth - targetFboWidth < RESIZE_BOUNDARY &&
-                               fboHeight - targetFboHeight < RESIZE_BOUNDARY ) {
-                        // Case: Decreased FBO Size Request within boundary
-                        newFboWidth = fboWidth;
-                        newFboHeight = fboHeight;
-                        resizeCase = 3;
-                    } else {
-                        // Case: Decreased-Size-Beyond-Boundary or No-Resize
-                        newFboWidth = targetFboWidth;
-                        newFboHeight = targetFboHeight;
-                        resizeCase = 4;
-                    }
-                }
-                final int dResizeWidth = newFboWidth - targetFboWidth;
-                final int dResizeHeight = newFboHeight - targetFboHeight;
-                final float diffObjResizeWidth = dResizeWidth*ratioObjWinWidth;
-                final float diffObjResizeHeight = dResizeHeight*ratioObjWinHeight;
-                if( DEBUG_FBO_1 ) {
-                    System.err.printf("XXX.resizeFBO: case %d, has %dx%d > target %dx%d, resize: i[%d x %d], f[%.3f x %.3f] -> %dx%d%n",
-                            resizeCase, fboWidth, fboHeight, targetFboWidth, targetFboHeight,
-                            dResizeWidth, dResizeHeight, diffObjResizeWidth, diffObjResizeHeight,
-                            newFboWidth, newFboHeight);
-                }
-
                 final float minX = box.getMinX()-diffObjBorderWidth;
                 final float minY = box.getMinY()-diffObjBorderHeight;
-                final float maxX = box.getMaxX()+diffObjBorderWidth+diffObjWidth+diffObjResizeWidth;
-                final float maxY = box.getMaxY()+diffObjBorderHeight+diffObjHeight+diffObjResizeHeight;
+                final float maxX = box.getMaxX()+diffObjBorderWidth+diffObjWidth;
+                final float maxY = box.getMaxY()+diffObjBorderHeight+diffObjHeight;
+                final float minZ = box.getMinZ();
                 gca_FboVerticesAttr.seal(false);
                 {
                     final FloatBuffer fb = (FloatBuffer)gca_FboVerticesAttr.getBuffer();
-                    fb.put(0, minX); fb.put( 1, minY);
-                    fb.put(3, minX); fb.put( 4, maxY);
-                    fb.put(6, maxX); fb.put( 7, maxY);
-                    fb.put(9, maxX); fb.put(10, minY);
+                    fb.put(0, minX); fb.put( 1, minY); fb.put( 2, minZ);
+                    fb.put(3, minX); fb.put( 4, maxY); fb.put( 5, minZ);
+                    fb.put(6, maxX); fb.put( 7, maxY); fb.put( 8, minZ);
+                    fb.put(9, maxX); fb.put(10, minY); fb.put(11, minZ);
                     fb.position(12);
                 }
                 gca_FboVerticesAttr.seal(true);
                 matP.setToOrtho(minX, maxX, minY, maxY, -1, 1);
-                useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-                renderRegion2FBO(gl, rs, curRenderModes, targetFboWidth, targetFboHeight, newFboWidth, newFboHeight, vpWidth, vpHeight, sampleCount[0]);
+                useShaderProgram(gl, renderer, curRenderModes, true);
+                renderRegion2FBO(gl, rs, curRenderModes,
+                                 // (int)drawWinBox.getMinX(), (int)drawWinBox.getMinY(), targetFboWidth, targetFboHeight,
+                                 0, 0, targetFboWidth, targetFboHeight,
+                                 vpWidth, vpHeight, pass2SampleCount);
             } else if( isStateDirty() ) {
-                useShaderProgram(gl, renderer, curRenderModes, true, getQuality(), sampleCount[0]);
-                renderRegion2FBO(gl, rs, curRenderModes, targetFboWidth, targetFboHeight, fboWidth, fboHeight, vpWidth, vpHeight, sampleCount[0]);
+                useShaderProgram(gl, renderer, curRenderModes, true);
+                renderRegion2FBO(gl, rs, curRenderModes,
+                                 // (int)drawWinBox.getMinX(), (int)drawWinBox.getMinY(), targetFboWidth, targetFboHeight,
+                                 0, 0, targetFboWidth, targetFboHeight,
+                                 vpWidth, vpHeight, pass2SampleCount);
             }
-            useShaderProgram(gl, renderer, curRenderModes, false, getQuality(), sampleCount[0]);
-            renderFBO(gl, rs, targetFboWidth, targetFboHeight, vpWidth, vpHeight, sampleCount[0]);
+            useShaderProgram(gl, renderer, curRenderModes, false);
+            renderFBO(gl, rs, targetFboWidth, targetFboHeight, vpWidth, vpHeight, pass2SampleCount);
         }
     }
 
@@ -479,12 +426,19 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
         // but not here -> investigate if required for working MSAA:
         // - "VBORegion2PMSAAES2 enables/disables GL_DEPTH_TEST, otherwise MSAA is corrupt"
         //
-        if( rs.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED) ) {
+        if( rs.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED) ) {
             // RGB is already multiplied w/ alpha via renderRegion2FBO(..)
             gl.glBlendFunc(GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
         }
 
         gl.glUniform(gcu_FboTexSize);
+        {
+            final Frustum f = rs.getClipFrustum();
+            if( null != f ) {
+                f.getPlanes(clipFrustum, 0);
+                gl.glUniform(gcu_ClipFrustum); // Always update, since program maybe used by multiple regions
+            }
+        }
 
         gl.glActiveTexture(GL.GL_TEXTURE0 + gcu_FboTexUnit.intValue());
 
@@ -504,54 +458,56 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
     }
 
     private void renderRegion2FBO(final GL2ES2 gl, final RenderState rs, final int curRenderModes,
-                                  final int targetFboWidth, final int targetFboHeight, final int newFboWidth, final int newFboHeight,
+                                  final int fboX, final int fboY, final int targetFboWidth, final int targetFboHeight,
                                   final int vpWidth, final int vpHeight, final int sampleCount) {
         if( 0 >= targetFboWidth || 0 >= targetFboHeight ) {
-            throw new IllegalArgumentException("fboSize must be greater than 0: "+targetFboWidth+"x"+targetFboHeight);
+            throw new IllegalArgumentException("targetFBOSize "+targetFboWidth+"x"+targetFboHeight+" must be greater than 0");
         }
-
-        final boolean blendingEnabled = rs.isHintMaskSet(RenderState.BITHINT_BLENDING_ENABLED);
+        final boolean blendingEnabled = rs.hintBitsSet(RenderState.BITHINT_BLENDING_ENABLED);
 
         if(null == fbo) {
-            fboWidth  = newFboWidth;
-            fboHeight  = newFboHeight;
+            fboWidth  = targetFboWidth;
+            fboHeight  = targetFboHeight;
             final FloatBuffer fboTexSize = (FloatBuffer) gcu_FboTexSize.getBuffer();
             {
-                fboTexSize.put(0, fboWidth);
-                fboTexSize.put(1, fboHeight);
+                fboTexSize.put(0, targetFboWidth);
+                fboTexSize.put(1, targetFboHeight);
             }
             fbo = new FBObject();
-            fbo.init(gl, fboWidth, fboHeight, 0);
-            // Shall not use bilinear (GL_LINEAR), due to own VBAA. Result is smooth w/o it now!
-            // FIXME: FXAA requires bilinear filtering!
-            // texA = fbo.attachTexture2D(gl, 0, true, GL.GL_LINEAR, GL.GL_LINEAR, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
-            texA = fbo.attachTexture2D(gl, 0, true, GL.GL_NEAREST, GL.GL_NEAREST, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
+            fbo.init(gl, targetFboWidth, targetFboHeight, 0);
+            if( sampleCount > 1 ) {
+                // Shall not use bilinear (GL_LINEAR), due to own VBAA. Result is smooth w/o it now!
+                // FIXME: FXAA requires bilinear filtering!
+                texA = fbo.attachTexture2D(gl, 0, true, GL.GL_NEAREST, GL.GL_NEAREST, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
+            } else {
+                texA = fbo.attachTexture2D(gl, 0, true, GL.GL_LINEAR, GL.GL_LINEAR, GL.GL_CLAMP_TO_EDGE, GL.GL_CLAMP_TO_EDGE);
+            }
             if( !blendingEnabled ) {
                 // no depth-buffer w/ blending
                 fbo.attachRenderbuffer(gl, Attachment.Type.DEPTH, FBObject.DEFAULT_BITS);
             }
             if( DEBUG_FBO_1 ) {
-                System.err.printf("XXX.createFBO: %dx%d%n%s%n", fboWidth, fboHeight, fbo.toString());
+                System.err.printf("XXX.createFBO: %dx%d%n%s%n", targetFboWidth, targetFboHeight, fbo.toString());
             }
-        } else if( newFboWidth != fboWidth || newFboHeight != fboHeight ) {
-            fbo.reset(gl, newFboWidth, newFboHeight, 0);
+        } else if( targetFboWidth != fboWidth || targetFboHeight != fboHeight ) {
+            fbo.reset(gl, targetFboWidth, targetFboHeight, 0);
             fbo.bind(gl);
             if( DEBUG_FBO_1 ) {
-                System.err.printf("XXX.resetFBO: %dx%d -> %dx%d, target %dx%d%n", fboWidth, fboHeight, newFboWidth, newFboHeight, targetFboWidth, targetFboHeight);
+                System.err.printf("XXX.resetFBO: %dx%d -> %dx%d%n%s%n", fboWidth, fboHeight, targetFboWidth, targetFboHeight, fbo.toString());
             }
-            fboWidth  = newFboWidth;
-            fboHeight  = newFboHeight;
+            fboWidth  = targetFboWidth;
+            fboHeight  = targetFboHeight;
             final FloatBuffer fboTexSize = (FloatBuffer) gcu_FboTexSize.getBuffer();
             {
-                fboTexSize.put(0, fboWidth);
-                fboTexSize.put(1, fboHeight);
+                fboTexSize.put(0, targetFboWidth);
+                fboTexSize.put(1, targetFboHeight);
             }
         } else {
             fbo.bind(gl);
         }
 
         //render texture
-        gl.glViewport(0, 0, fboWidth, fboHeight);
+        gl.glViewport(fboX, fboY, targetFboWidth, targetFboHeight);
         if( blendingEnabled ) {
             gl.glClearColor(0f, 0f, 0f, 0.0f);
             gl.glClear(GL.GL_COLOR_BUFFER_BIT); // no depth-buffer w/ blending
@@ -564,14 +520,22 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
             gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
         }
 
-        renderRegion(gl, curRenderModes);
+        renderRegion(gl, rs, curRenderModes);
+
+        if( SCREENSHOT_FBO ) {
+            screenshot.setReadBuffer(GL.GL_COLOR_ATTACHMENT0);
+            if(screenshot.readPixels(gl, fboX, fboY, targetFboWidth, targetFboHeight, false)) {
+                final File f = new File("screenshot_vboregion2pvbaa.png");
+                screenshot.write(f);
+            }
+        }
 
         fbo.unbind(gl);
         fboDirty = false;
     }
 
-    private void renderRegion(final GL2ES2 gl, final int curRenderModes) {
-        final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
+    private void renderRegion(final GL2ES2 gl, final RenderState rs, final int curRenderModes) {
+        // final boolean hasColorChannel = Region.hasColorChannel( curRenderModes );
         final boolean hasColorTexture = Region.hasColorTexture( curRenderModes );
 
         gl.glUniform(gcu_PMVMatrix02);
@@ -587,6 +551,7 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
             gcu_ColorTexUnit.setData(colorTexSeq.getTextureUnit());
             gl.glUniform(gcu_ColorTexUnit); // Always update, since program maybe used by multiple regions
             gl.glUniform(gcu_ColorTexBBox); // Always update, since program maybe used by multiple regions
+            gl.glUniform(gcu_ColorTexClearCol); // Always update, since program maybe used by multiple regions
             gl.glDrawElements(GL.GL_TRIANGLES, indicesBuffer.getElemCount() * indicesBuffer.getCompsPerElem(), glIdxType(), 0);
             tex.disable(gl); // nop on core
         } else {
@@ -621,6 +586,10 @@ public final class VBORegion2PVBAAES2  extends GLRegion {
             indicesFbo.destroy(gl);
             indicesFbo = null;
         }
+        if( null != screenshot ) {
+            screenshot.dispose(gl);
+            screenshot = null;
+        }
         spPass1 = null; // owned by RegionRenderer
         spPass2 = null; // owned by RegionRenderer
     }
