@@ -29,7 +29,7 @@ package jogamp.graph.font.typecast;
 
 import com.jogamp.graph.curve.OutlineShape;
 import com.jogamp.graph.font.Font;
-import com.jogamp.opengl.math.geom.AABBox;
+import com.jogamp.math.geom.AABBox;
 
 import jogamp.graph.font.typecast.ot.table.KernSubtable;
 import jogamp.graph.font.typecast.ot.table.KerningPair;
@@ -39,6 +39,25 @@ public final class TypecastGlyph implements Font.Glyph {
 
     public static final short INVALID_ID    = (short)((1 << 16) - 1);
     public static final short MAX_ID        = (short)((1 << 16) - 2);
+    /* pp */ static final String dot_undef_NAME = ".notdef";
+    private static final String NULL_NAME = "NULL";
+    private static final String null_NAME = "null";
+    private static final String dot_null_NAME = ".null";
+
+    /* pp */ static final boolean isUndefName(final String name) {
+        if( null != name ) {
+            if( TypecastGlyph.dot_undef_NAME.equals(name) ) {
+                return true;
+            } else if( TypecastGlyph.NULL_NAME.equals(name) ) {
+                return true;
+            } else if( TypecastGlyph.null_NAME.equals(name) ) {
+                return true;
+            } else if( TypecastGlyph.dot_null_NAME.equals(name) ) {
+                return true;
+            }
+        }
+        return false;
+    }
 
     private static int[][] growPairArray(final int[][] src) {
         final int length = src.length;
@@ -64,9 +83,11 @@ public final class TypecastGlyph implements Font.Glyph {
         return dst;
     }
 
+    private final char codepoint;
     private final int id;
     private final String name;
-    private final boolean isWhiteSpace;
+    private final boolean isUndefined;
+    private final boolean isWhitespace;
 
     private final TypecastFont font;
     private final AABBox bbox; // in font-units
@@ -81,19 +102,23 @@ public final class TypecastGlyph implements Font.Glyph {
     /**
      *
      * @param font
-     * @param name from `post` table
+     * @param codepoint TODO
      * @param id
+     * @param name from `post` table
      * @param bbox in font-units
      * @param advance from hmtx in font-units
      * @param leftSideBearings from hmtx in font-units
      * @param shape
      */
-    protected TypecastGlyph(final TypecastFont font, final int id, final String name,
-                            final AABBox bbox, final int advance, final int leftSideBearings,
-                            final KernSubtable kernSub, final OutlineShape shape, final boolean isWhiteSpace) {
+    protected TypecastGlyph(final TypecastFont font, final char codepoint, final int id,
+                            final String name, final AABBox bbox, final int advance,
+                            final int leftSideBearings, final KernSubtable kernSub,
+                            final OutlineShape shape, final boolean isUndefined, final boolean isWhiteSpace) {
+        this.codepoint = codepoint;
         this.id = id;
         this.name = name;
-        this.isWhiteSpace = isWhiteSpace;
+        this.isUndefined = isUndefined;
+        this.isWhitespace = isWhiteSpace;
         this.font = font;
         this.bbox = bbox;
         this.advance = advance;
@@ -132,6 +157,9 @@ public final class TypecastGlyph implements Font.Glyph {
         return font;
     }
 
+    @Override
+    public char getCodepoint() { return codepoint; }
+
     @Override
     public final int getID() { return id; }
 
@@ -139,10 +167,13 @@ public final class TypecastGlyph implements Font.Glyph {
     public final String getName() { return name; }
 
     @Override
-    public final boolean isWhiteSpace() { return this.isWhiteSpace; }
+    public final boolean isWhitespace() { return this.isWhitespace; }
 
     @Override
-    public final boolean isUndefined() { return name == ".notdef"; }
+    public final boolean isUndefined() { return this.isUndefined; }
+
+    @Override
+    public final boolean isNonContour() { return isUndefined() || isWhitespace(); }
 
     @Override
     public final AABBox getBoundsFU() { return bbox; }
@@ -162,10 +193,10 @@ public final class TypecastGlyph implements Font.Glyph {
     }
 
     @Override
-    public final int getAdvanceFU() { return advance; }
+    public final int getAdvanceWidthFU() { return advance; }
 
     @Override
-    public float getAdvance() { return font.getMetrics().getScale( advance ); }
+    public float getAdvanceWidth() { return font.getMetrics().getScale( advance ); }
 
     @Override
     public final int getLeftSideBearingsFU() { return leftSideBearings; }
@@ -232,22 +263,44 @@ public final class TypecastGlyph implements Font.Glyph {
     @Override
     public String toString() {
         final StringBuilder sb = new StringBuilder();
-        final String ws_s = isWhiteSpace() ? ", ws" : "";
-        sb.append("Glyph[id ").append(id).append(" '").append(name).append("'").append(ws_s)
-          .append(", advance ").append(getAdvanceFU())
+        final String contour_s;
+        if( isNonContour() ) {
+            final String ws_s = isWhitespace() ? "whitespace" : "";
+            final String undef_s = isUndefined() ? "undefined" : "";
+            contour_s = "non-cont("+ws_s+undef_s+")";
+        } else {
+            contour_s = "contour";
+        }
+        final String name_s = null != name ? name : "";
+        final String shape_s = null != shape ? "shape["+shape.getVertexCount()+"v, "+(shape.isComplex()?"complex":"simple")+"]" : "shape null";
+        sb.append("Glyph[id 0x").append(Integer.toHexString(id)).append(", cp 0x").append(Integer.toHexString(codepoint))
+          .append(", name '").append(name_s).append("', ").append(contour_s)
+          .append(", ").append(shape_s)
+          .append(", advance ").append(getAdvanceWidthFU())
           .append(", leftSideBearings ").append(getLeftSideBearingsFU())
           .append(", kerning[size ").append(kerning.length).append(", horiz ").append(this.isKerningHorizontal()).append(", cross ").append(this.isKerningCrossstream()).append("]")
-          .append(", shape ").append(null != shape).append("]");
+          .append("]");
         return sb.toString();
     }
 
     @Override
     public String fullString() {
         final PostTable post = font.getPostTable();
-        final String glyph_name = null != post ? post.getGlyphName(id) : "n/a";
         final StringBuilder sb = new StringBuilder();
-        sb.append("Glyph id ").append(id).append(" '").append(glyph_name).append("'")
-          .append(", advance ").append(getAdvanceFU())
+        final String contour_s;
+        if( isNonContour() ) {
+            final String ws_s = isWhitespace() ? "whitespace" : "";
+            final String undef_s = isUndefined() ? "undefined" : "";
+            contour_s = "non-cont("+ws_s+undef_s+")";
+        } else {
+            contour_s = "contour";
+        }
+        final String name_s = null != name ? name : "";
+        final String shape_s = null != shape ? "shape["+shape.getVertexCount()+"v, "+(shape.isComplex()?"complex":"simple")+"]" : "shape null";
+        sb.append("Glyph[id 0x").append(Integer.toHexString(id)).append(", cp 0x").append(Integer.toHexString(codepoint))
+          .append(" name '").append(name_s).append("', ").append(contour_s)
+          .append(", shape ").append(shape_s)
+          .append(", advance ").append(getAdvanceWidthFU())
           .append(", leftSideBearings ").append(getLeftSideBearingsFU())
           .append(", ").append(getBoundsFU());
 
