@@ -20,6 +20,7 @@ package jogamp.graph.font.typecast.ot;
 
 import java.io.DataInputStream;
 import java.io.IOException;
+import java.io.Writer;
 
 import jogamp.graph.font.typecast.ot.table.CmapTable;
 import jogamp.graph.font.typecast.ot.table.GsubTable;
@@ -35,7 +36,6 @@ import jogamp.graph.font.typecast.ot.table.Table;
 import jogamp.graph.font.typecast.ot.table.TableDirectory;
 import jogamp.graph.font.typecast.ot.table.VheaTable;
 
-
 /**
  * The TrueType font.
  * @author <a href="mailto:david.schweinsberg@gmail.com">David Schweinsberg</a>
@@ -52,15 +52,23 @@ public abstract class OTFont {
     private final PostTable _post;
     private final VheaTable _vhea;
     private final GsubTable _gsub;
+    private final TableDirectory _tableDirectory;
 
     /**
-     *
      * @param dis input stream marked at start with read-ahead set to known stream length
-     * @param tableDirectory
-     * @param tablesOrigin
-     * @throws IOException
+     * @param directoryOffset The Table Directory offset within the file.  For a
+     * regular TTF/OTF file this will be zero, but for a TTC (Font Collection)
+     * the offset is retrieved from the TTC header.  For a Mac font resource,
+     * offset is retrieved from the resource headers.
+     * @param tablesOrigin The point the table offsets are calculated from.
+     * Once again, in a regular TTF file, this will be zero.  In a TTC is is
+     * also zero, but within a Mac resource, it is the beginning of the
+     * individual font resource data.
+     * @throws java.io.IOException
      */
     OTFont(final DataInputStream dis, final TableDirectory tableDirectory, final int tablesOrigin) throws IOException {
+        _tableDirectory = tableDirectory;
+
         // Load some prerequisite tables
         // (These are tables that are referenced by other tables, so we need to load
         // them first)
@@ -100,6 +108,13 @@ public abstract class OTFont {
         _gsub = null; // FIXME: delete?
     }
 
+    /**
+     * {@link TableDirectory} with all font tables.
+     */
+    public TableDirectory getTableDirectory() {
+        return _tableDirectory;
+    }
+
     public Os2Table getOS2Table() {
         return _os2;
     }
@@ -195,4 +210,36 @@ public abstract class OTFont {
     public String toString() {
         return _head.toString();
     }
+
+    /**
+     * Dumps information of all tables to the given {@link Writer}.
+     */
+    public void dumpTo(final Writer out) throws IOException {
+        out.write(getTableDirectory().toString());
+        out.write("\n");
+
+        dump(out, getHeadTable());
+        dump(out, getOS2Table());
+        dump(out, getCmapTable());
+        dump(out, getHheaTable());
+        dump(out, getHmtxTable());
+        dump(out, getMaxpTable());
+        dump(out, getNameTable());
+        dump(out, getPostTable());
+        dump(out, getVheaTable());
+        dump(out, getGsubTable());
+    }
+
+    /**
+     * Writes the toString() representation of the given table to the given {@link Writer}.
+     */
+    protected static void dump(final Writer out, final Table table) throws IOException {
+        if (table != null) {
+            table.dump(out);
+            out.write("\n");
+            out.write("\n");
+        }
+    }
+
+
 }
