@@ -21,16 +21,35 @@ package jogamp.graph.font.typecast.ot.table;
 
 import java.io.DataInput;
 import java.io.IOException;
+import java.util.Arrays;
 
 /**
+ * Format 0: Byte encoding table
+ * 
+ * <p>
  * Simple Macintosh cmap table, mapping only the ASCII character set to glyphs.
+ * </p>
+ * 
+ * @see "https://docs.microsoft.com/en-us/typography/opentype/spec/cmap#format-0-byte-encoding-table"
  *
  * @author <a href="mailto:david.schweinsberg@gmail.com">David Schweinsberg</a>
  */
 public class CmapFormat0 extends CmapFormat {
 
+    /**
+     * uint16   
+     * 
+     * @see #getLength()
+     */
     private final int _length;
+    
+    /**
+     * uint16 
+     * 
+     * @see #getLanguage()
+     */
     private final int _language;
+    
     private final int[] _glyphIdArray = new int[256];
 
     CmapFormat0(DataInput di) throws IOException {
@@ -77,4 +96,12 @@ public class CmapFormat0 extends CmapFormat {
             return 0;
         }
     }
+    
+    @Override
+    public String toString() {
+        return super.toString() +
+            "    format:         " + getFormat() + "\n" +
+            "    language:       " + getLanguage() + "\n" +
+            "    glyphIdArray:   " + Arrays.toString(_glyphIdArray) + "\n";
+    }
 }
