@@ -8,8 +8,8 @@
 
 package jogamp.graph.font.typecast.ot.table;
 
-import java.io.IOException;
 import java.io.DataInput;
+import java.io.IOException;
 
 /**
  *
@@ -38,6 +38,11 @@ class DsigTable implements Table {
         }
     }
 
+    @Override
+    public int getType() {
+        return DSIG;
+    }
+
     public String toString() {
         StringBuilder sb = new StringBuilder().append("DSIG\n");
         for (int i = 0; i < numSigs; i++) {
