@@ -87,6 +87,11 @@ public class HdmxTable implements Table {
         return _records[i];
     }
 
+    @Override
+    public int getType() {
+        return hdmx;
+    }
+
     @Override
     public String toString() {
         final StringBuilder sb = new StringBuilder();
