@@ -28,6 +28,9 @@
 
 package jogamp.opengl;
 
+import java.util.Arrays;
+import java.util.List;
+
 import com.jogamp.common.os.DynamicLibraryBundle;
 import com.jogamp.common.os.DynamicLibraryBundleInfo;
 import com.jogamp.common.util.RunnableExecutor;
@@ -36,6 +39,9 @@ public abstract class GLDynamicLibraryBundleInfo implements DynamicLibraryBundle
     protected GLDynamicLibraryBundleInfo() {
     }
 
+    @Override
+    public List<String> getSymbolForToolLibPath() { return Arrays.asList("glClear"); }
+
     /**
      * Returns <code>true</code>,
      * since we might load a desktop GL library and allow symbol access to subsequent libs.
