@@ -28,15 +28,19 @@
 package jogamp.opengl.android.av;
 
 import java.io.IOException;
+import java.io.PrintStream;
 import java.util.List;
 
 import com.jogamp.opengl.GL;
 import com.jogamp.opengl.GLES2;
 import com.jogamp.opengl.GLException;
 import com.jogamp.common.os.AndroidVersion;
+import com.jogamp.common.os.Clock;
 import com.jogamp.common.os.Platform;
+import com.jogamp.common.av.PTS;
 import com.jogamp.common.av.TimeFrameI;
 import com.jogamp.opengl.util.av.GLMediaPlayer;
+import com.jogamp.opengl.util.av.GLMediaPlayer.State;
 import com.jogamp.opengl.util.texture.Texture;
 import com.jogamp.opengl.util.texture.TextureSequence;
 
@@ -114,6 +118,11 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
         this.setTextureTarget(GLES2.GL_TEXTURE_EXTERNAL_OES);
     }
 
+    @Override
+    public final void printNativeInfo(final PrintStream out) {
+        out.println("AndroidGLMediaPlayerAPI14: available "+available);
+    }
+
     @Override
     protected final boolean setPlaySpeedImpl(final float rate) {
         // FIXME
@@ -137,7 +146,7 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
 
     @Override
     protected final boolean resumeImpl() {
-        playStart = Platform.currentTimeMillis();
+        playStart = Platform.currentMillis();
         if(null != mp) {
             try {
                 mp.start();
@@ -209,7 +218,21 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
     }
 
     @Override
-    protected final int getAudioPTSImpl() { return null != mp ? mp.getCurrentPosition() : 0; }
+    protected PTS getAudioPTSImpl() { return audio_pts; }
+    @Override
+    protected PTS getUpdatedAudioPTS() {
+        if( null != mp ) {
+            audio_pts.set(Clock.currentMillis(), mp.getCurrentPosition());
+        } else {
+            audio_pts.set(Clock.currentMillis(), 0);
+        }
+        return audio_pts;
+    }
+    @Override
+    protected int getAudioQueuedDuration() { return 0; }
+    @Override
+    protected int getLastBufferedAudioPTS() { return audio_pts.getLast(); }
+    private final PTS audio_pts = new PTS( () -> { return State.Playing == getState() ? getPlaySpeed() : 0f; } );
 
     @Override
     protected final void destroyImpl() {
@@ -258,7 +281,7 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
     }
 
     @Override
-    protected final void initStreamImpl(final int vid, final int aid) throws IOException {
+    protected final void initStreamImpl(final int vid, String alang, final int aid, String slang, final int sid) throws IOException {
         if( null == getUri() ) {
             return;
         }
@@ -300,12 +323,25 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
             } catch (final IOException ioe) {
                 throw new IOException("MediaPlayer failed to process stream <"+getUri().toString()+">: "+ioe.getMessage(), ioe);
             }
-            final int r_aid = GLMediaPlayer.STREAM_ID_NONE == aid ? GLMediaPlayer.STREAM_ID_NONE : 1 /* fake */;
+            final int r_aid;
+            final int[] r_aids;
+            final String[] r_alangs;
+            if( GLMediaPlayer.STREAM_ID_NONE == aid ) {
+                r_aid = GLMediaPlayer.STREAM_ID_NONE;
+                r_aids = new int[0];
+                r_alangs = new String[0];
+            } else {
+                r_aid = 1; // fake
+                r_aids = new int[] { 1 }; // fake
+                r_alangs = new String[] { "n/a" };
+            }
             final String icodec = "android";
-            updateAttributes(0 /* fake */, r_aid,
-                             mp.getVideoWidth(), mp.getVideoHeight(), 0,
-                             0, 0, 0f,
-                             0, 0, mp.getDuration(), icodec, icodec);
+            updateAttributes(null,
+                             new int[] { 0 }, new String[] { "und" }, 0 /* fake */,
+                             r_aids, r_alangs, r_aid,
+                             new int[0], new String[0], GLMediaPlayer.STREAM_ID_NONE,
+                             mp.getVideoWidth(), mp.getVideoHeight(), 0, 0, 0, 0f, 0, 0, mp.getDuration(),
+                             icodec, icodec, null, -1, -1, -1);
             /**
                 mp.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
                     @Override
@@ -338,11 +374,12 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
                     }
                 }
             }
-            updateAttributes(0 /* fake */, GLMediaPlayer.STREAM_ID_NONE,
-                             size.width, size.height,
-                             0, 0, 0,
-                             fpsRange[1]/1000f,
-                             0, 0, 0, icodec, icodec);
+            updateAttributes(null,
+                             new int[]{0}, new String[] { "und" }, 0 /* fake */,
+                             new int[0], new String[0], GLMediaPlayer.STREAM_ID_NONE,
+                             new int[0], new String[0], GLMediaPlayer.STREAM_ID_NONE,
+                             size.width, size.height, 0, 0, 0, fpsRange[1]/1000f, 0, 0, 0,
+                             icodec, icodec, null, -1, -1, -1);
         }
     }
     private static String camSz2Str(final Camera.Size csize) {
@@ -369,10 +406,10 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
     }
 
     @Override
-    protected final int getNextTextureImpl(final GL gl, final TextureFrame nextFrame) throws InterruptedException {
+    protected final int getNextTextureImpl(final GL gl, final TextureFrame vFrame, Texture sTex, boolean[] sTexUsed) throws InterruptedException {
         int pts = TimeFrameI.INVALID_PTS;
         if(null != mp || null != cam) {
-            final SurfaceTextureFrame sTexFrame = null != nextFrame ? (SurfaceTextureFrame) nextFrame : singleSTexFrame;
+            final SurfaceTextureFrame sTexFrame = null != vFrame ? (SurfaceTextureFrame) vFrame : singleSTexFrame;
             final SurfaceTexture surfTex = sTexFrame.surfaceTex;
             if( !sTexFrameAttached ) {
                 sTexFrameAttached = true;
@@ -416,7 +453,7 @@ public class AndroidGLMediaPlayerAPI14 extends GLMediaPlayerImpl {
                     if( null != mp ) {
                         pts = mp.getCurrentPosition();
                     } else {
-                        pts = (int) ( Platform.currentTimeMillis() - playStart );
+                        pts = (int) ( Platform.currentMillis() - playStart );
                     }
                     // stex.getTransformMatrix(atex.getSTMatrix());
                 }
