@@ -44,14 +44,14 @@
 
 package jogamp.opengl.glu.mipmap;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.GL2;
-import javax.media.opengl.GL2ES2;
-import javax.media.opengl.GL2ES3;
-import javax.media.opengl.GL2GL3;
-import javax.media.opengl.GLContext;
-import javax.media.opengl.glu.GLU;
-import javax.media.opengl.GLException;
+import com.jogamp.opengl.GL;
+import com.jogamp.opengl.GL2;
+import com.jogamp.opengl.GL2ES2;
+import com.jogamp.opengl.GL2ES3;
+import com.jogamp.opengl.GL2GL3;
+import com.jogamp.opengl.GLContext;
+import com.jogamp.opengl.glu.GLU;
+import com.jogamp.opengl.GLException;
 
 import java.nio.*;
 
@@ -257,7 +257,7 @@ public class Mipmap {
   public static void closestFit( final GL gl, final int target, final int width, final int height, final int internalFormat,
                                 final int format, final int type, final int[] newWidth, final int[] newHeight ) {
     // Use proxy textures if OpenGL GL2/GL3 version >= 1.1
-    if( gl.isGL2GL3() && gl.getContext().getGLVersionNumber().compareTo(GLContext.Version110) >= 0 ) {
+    if( gl.isGL2GL3() && gl.getContext().getGLVersionNumber().compareTo(GLContext.Version1_1) >= 0 ) {
       int widthPowerOf2 = nearestPower( width );
       int heightPowerOf2 = nearestPower( height );
       final int[] proxyWidth = new int[1];
