@@ -44,9 +44,9 @@
 
 package jogamp.opengl.glu.mipmap;
 
-import javax.media.opengl.GL;
-import javax.media.opengl.GL2;
-import javax.media.opengl.glu.GLU;
+import com.jogamp.opengl.GL;
+import com.jogamp.opengl.GL2;
+import com.jogamp.opengl.glu.GLU;
 import java.nio.*;
 import com.jogamp.common.nio.Buffers;
 
