@@ -1,5 +1,5 @@
 /**
- * Copyright 2012 JogAmp Community. All rights reserved.
+ * Copyright 2012-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -29,11 +29,12 @@
 package jogamp.opengl.util.av.impl;
 
 import java.io.IOException;
-import java.nio.ByteBuffer;
+import java.io.PrintStream;
 import java.security.PrivilegedAction;
 
 import com.jogamp.opengl.GL;
 import com.jogamp.opengl.GL2ES2;
+import com.jogamp.opengl.GLES2;
 import com.jogamp.opengl.GLException;
 import com.jogamp.common.av.AudioFormat;
 import com.jogamp.common.av.AudioSink;
@@ -42,17 +43,17 @@ import com.jogamp.common.av.TimeFrameI;
 import com.jogamp.common.util.IOUtil;
 import com.jogamp.common.util.PropertyAccess;
 import com.jogamp.common.util.SecurityUtil;
-import com.jogamp.common.util.VersionNumber;
 import com.jogamp.gluegen.runtime.ProcAddressTable;
 import com.jogamp.opengl.util.GLPixelStorageModes;
 import com.jogamp.opengl.util.av.GLMediaPlayer;
+import com.jogamp.opengl.util.av.VideoPixelFormat;
 import com.jogamp.opengl.util.texture.Texture;
 
 import jogamp.common.os.PlatformPropsImpl;
 import jogamp.opengl.GLContextImpl;
 import jogamp.opengl.util.av.AudioSampleFormat;
 import jogamp.opengl.util.av.GLMediaPlayerImpl;
-import jogamp.opengl.util.av.VideoPixelFormat;
+import jogamp.opengl.util.av.impl.FFMPEGDynamicLibraryBundleInfo.VersionedLib;
 
 /***
  * Implementation utilizes <a href="http://ffmpeg.org/">FFmpeg</a> which is ubiquitous
@@ -94,6 +95,7 @@ import jogamp.opengl.util.av.VideoPixelFormat;
  *   <li>avutil</li>
  *   <li>avdevice (optional for video input devices)</li>
  *   <li>swresample</li>
+ *   <li>swscale (optional for bitmap'ed subtitles)</li>
  * </ul>
  * </p>
  *
@@ -101,10 +103,10 @@ import jogamp.opengl.util.av.VideoPixelFormat;
  * <p>
  * Currently we are binary compatible with the following major versions:
  * <table border="1">
- * <tr><th>ffmpeg</th><th>avcodec</th><th>avformat</th><th>avdevice</th><th>avutil</th><th>swresample</th>  <th>FFMPEG* class</th></tr>
- * <tr><td>4</td>     <td>58</td>     <td>58</td>      <td>58</td>      <td>56</td>    <td>03</td>          <td>FFMPEGv0400</td></tr>
- * <tr><td>5</td>     <td>59</td>     <td>59</td>      <td>59</td>      <td>57</td>    <td>04</td>          <td>FFMPEGv0500</td></tr>
- * <tr><td>6</td>     <td>60</td>     <td>60</td>      <td>60</td>      <td>58</td>    <td>04</td>          <td>FFMPEGv0600</td></tr>
+ * <tr><th>ffmpeg</th><th>avcodec</th><th>avformat</th><th>avdevice</th><th>avutil</th><th>swresample</th><th>swscale</th>  <th>FFMPEG* class</th></tr>
+ * <tr><td>4</td>     <td>58</td>     <td>58</td>      <td>58</td>      <td>56</td>    <td>03</td>        <td>05</td>       <td>FFMPEGv0400</td></tr>
+ * <tr><td>5</td>     <td>59</td>     <td>59</td>      <td>59</td>      <td>57</td>    <td>04</td>        <td>06</td>       <td>FFMPEGv0500</td></tr>
+ * <tr><td>6</td>     <td>60</td>     <td>60</td>      <td>60</td>      <td>58</td>    <td>04</td>        <td>07</td>       <td>FFMPEGv0600</td></tr>
  * </table>
  * </p>
  * <p>
@@ -199,6 +201,7 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
     private static final int avCodecMajorVersionCC;
     private static final int avDeviceMajorVersionCC;
     private static final int swResampleMajorVersionCC;
+    private static final int swScaleMajorVersionCC;
     private static final boolean available;
 
     static {
@@ -216,40 +219,40 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                 avUtilMajorVersionCC = natives.getAvUtilMajorVersionCC0();
                 avDeviceMajorVersionCC = natives.getAvDeviceMajorVersionCC0();
                 swResampleMajorVersionCC = natives.getSwResampleMajorVersionCC0();
+                swScaleMajorVersionCC = natives.getSwScaleMajorVersionCC0();
             } else {
                 avUtilMajorVersionCC = 0;
                 avFormatMajorVersionCC = 0;
                 avCodecMajorVersionCC = 0;
                 avDeviceMajorVersionCC = 0;
                 swResampleMajorVersionCC = 0;
+                swScaleMajorVersionCC = 0;
             }
-            final VersionNumber avCodecVersion = FFMPEGDynamicLibraryBundleInfo.avCodecVersion;
-            final VersionNumber avFormatVersion = FFMPEGDynamicLibraryBundleInfo.avFormatVersion;
-            final VersionNumber avUtilVersion = FFMPEGDynamicLibraryBundleInfo.avUtilVersion;
-            final VersionNumber avDeviceVersion = FFMPEGDynamicLibraryBundleInfo.avDeviceVersion;
-            final VersionNumber swResampleVersion = FFMPEGDynamicLibraryBundleInfo.swResampleVersion;
-            final boolean avDeviceLoaded = FFMPEGDynamicLibraryBundleInfo.avDeviceLoaded();
-            final boolean swResampleLoaded = FFMPEGDynamicLibraryBundleInfo.swResampleLoaded();
-            final int avCodecMajor = avCodecVersion.getMajor();
-            final int avFormatMajor = avFormatVersion.getMajor();
-            final int avUtilMajor = avUtilVersion.getMajor();
-            final int avDeviceMajor = avDeviceVersion.getMajor();
-            final int swResampleMajor = swResampleVersion.getMajor();
+            final VersionedLib avCodec = FFMPEGDynamicLibraryBundleInfo.avCodec;
+            final VersionedLib avFormat = FFMPEGDynamicLibraryBundleInfo.avFormat;
+            final VersionedLib avUtil = FFMPEGDynamicLibraryBundleInfo.avUtil;
+            final VersionedLib avDevice = FFMPEGDynamicLibraryBundleInfo.avDevice;
+            final VersionedLib swResample = FFMPEGDynamicLibraryBundleInfo.swResample;
+            final VersionedLib swScale = FFMPEGDynamicLibraryBundleInfo.swScale;
+            // final boolean avDeviceLoaded = FFMPEGDynamicLibraryBundleInfo.avDeviceLoaded();
+            // final boolean swResampleLoaded = FFMPEGDynamicLibraryBundleInfo.swResampleLoaded();
+            final int avCodecMajor = avCodec.version.getMajor();
+            final int avFormatMajor = avFormat.version.getMajor();
+            final int avUtilMajor = avUtil.version.getMajor();
+            final int avDeviceMajor = avDevice.version.getMajor();
+            final int swResampleMajor = swResample.version.getMajor();
+            final int swScaleMajor = swScale.version.getMajor();
             libAVVersionGood = avCodecMajorVersionCC  == avCodecMajor &&
                                avFormatMajorVersionCC == avFormatMajor &&
                                avUtilMajorVersionCC == avUtilMajor &&
                                ( avDeviceMajorVersionCC == avDeviceMajor || 0 == avDeviceMajor ) &&
-                               swResampleMajorVersionCC == swResampleMajor;
+                               swResampleMajorVersionCC == swResampleMajor &&
+                               ( swScaleMajorVersionCC == swScaleMajor || 0 == swScaleMajor );
             if( !libAVVersionGood ) {
                 System.err.println("FFmpeg Not Matching Compile-Time / Runtime Major-Version");
             }
             if( !libAVVersionGood || DEBUG ) {
-                System.err.println("FFmpeg Codec   : "+avCodecVersion+" [cc "+avCodecMajorVersionCC+"]");
-                System.err.println("FFmpeg Format  : "+avFormatVersion+" [cc "+avFormatMajorVersionCC+"]");
-                System.err.println("FFmpeg Util    : "+avUtilVersion+" [cc "+avUtilMajorVersionCC+"]");
-                System.err.println("FFmpeg Device  : "+avDeviceVersion+" [cc "+avDeviceMajorVersionCC+", loaded "+avDeviceLoaded+"]");
-                System.err.println("FFmpeg Resample: "+swResampleVersion+" [cc "+swResampleMajorVersionCC+", loaded "+swResampleLoaded+"]");
-                System.err.println("FFmpeg Class   : "+(null!= natives ? natives.getClass().getSimpleName() : "n/a"));
+                printNativeInfoImpl(System.err);
             }
         } else {
             natives = null;
@@ -258,6 +261,7 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
             avCodecMajorVersionCC = 0;
             avDeviceMajorVersionCC = 0;
             swResampleMajorVersionCC = 0;
+            swScaleMajorVersionCC = 0;
             libAVVersionGood = false;
         }
         available = libAVGood && libAVVersionGood && null != natives;
@@ -265,22 +269,37 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
 
     public static final boolean isAvailable() { return available; }
 
+    private static final void printNativeInfoImpl(final PrintStream out) {
+        out.println("FFmpeg Codec   : "+FFMPEGDynamicLibraryBundleInfo.avCodec+" [cc "+avCodecMajorVersionCC+"]");
+        out.println("FFmpeg Format  : "+FFMPEGDynamicLibraryBundleInfo.avFormat+" [cc "+avFormatMajorVersionCC+"]");
+        out.println("FFmpeg Util    : "+FFMPEGDynamicLibraryBundleInfo.avUtil+" [cc "+avUtilMajorVersionCC+"]");
+        out.println("FFmpeg Device  : "+FFMPEGDynamicLibraryBundleInfo.avDevice+" [cc "+avDeviceMajorVersionCC+", loaded "+FFMPEGDynamicLibraryBundleInfo.avDeviceLoaded()+"]");
+        out.println("FFmpeg Resample: "+FFMPEGDynamicLibraryBundleInfo.swResample+" [cc "+swResampleMajorVersionCC+", loaded "+FFMPEGDynamicLibraryBundleInfo.swResampleLoaded()+"]");
+        out.println("FFmpeg Scale   : "+FFMPEGDynamicLibraryBundleInfo.swScale+" [cc "+swScaleMajorVersionCC+", loaded "+FFMPEGDynamicLibraryBundleInfo.swScaleLoaded()+"]");
+        out.println("FFmpeg Class   : "+(null!= natives ? natives.getClass().getSimpleName() : "n/a"));
+    }
+    @Override
+    public final void printNativeInfo(final PrintStream out) {
+        printNativeInfoImpl(out);
+    }
+
     //
     // General
     //
 
+    private final Object moviePtrLock = new Object();
     private long moviePtr = 0;
 
     //
     // Video
     //
 
-    private boolean usesTexLookupShader = false;
-    private VideoPixelFormat vPixelFmt = null;
+    private VideoPixelFormat vPixelFmt = VideoPixelFormat.RGBA;
     private int vPlanes = 0;
     private int vBitsPerPixel = 0;
     private int vBytesPerPixelPerPlane = 0;
-    private int texWidth, texHeight; // overall (stuffing planes in one texture)
+    private int vWidth = 0, vHeight = 0;
+    private int texWidth = 0, texHeight = 0; // overall (stuffing planes in one texture)
     private String singleTexComp = "r";
     private final GLPixelStorageModes psm;
 
@@ -308,9 +327,11 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
 
     @Override
     protected final void destroyImpl() {
-        if (moviePtr != 0) {
-            natives.destroyInstance0(moviePtr);
-            moviePtr = 0;
+        synchronized( moviePtrLock ) {
+            if (moviePtr != 0) {
+                natives.destroyInstance0(moviePtr);
+                moviePtr = 0;
+            }
         }
         destroyAudioSink();
     }
@@ -331,99 +352,127 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
     public static final String dev_video_linux = "/dev/video";
 
     @Override
-    protected final void initStreamImpl(final int vid, final int aid) throws IOException {
-        if(0==moviePtr) {
-            throw new GLException("FFMPEG native instance null");
-        }
-        if(DEBUG) {
-            System.err.println("initStream: p1 "+this);
-        }
+    protected final void initStreamImpl(final int vid, final String alang, final int aid, final String slang, final int sid) throws IOException {
+        synchronized( moviePtrLock ) {
+            if(0==moviePtr) {
+                throw new GLException("FFMPEG native instance null");
+            }
+            if(DEBUG) {
+                System.err.println("initStream: p1 "+this);
+            }
 
-        final String streamLocS = IOUtil.getUriFilePathOrASCII(getUri());
-        destroyAudioSink();
-        if( GLMediaPlayer.STREAM_ID_NONE == aid ) {
-            audioSink = AudioSinkFactory.createNull();
-        } else {
-            audioSink = AudioSinkFactory.createDefault(FFMPEGMediaPlayer.class.getClassLoader());
-        }
-        {
-            final int audioChannelLimit = getAudioChannelLimit();
-            if( audioChannelLimit >= 1 ) {
-                audioSink.setChannelLimit(audioChannelLimit);
+            final String streamLocS = IOUtil.getUriFilePathOrASCII(getUri());
+            destroyAudioSink();
+            if( GLMediaPlayer.STREAM_ID_NONE == aid ) {
+                audioSink = AudioSinkFactory.createNull();
+            } else {
+                // audioSink = new jogamp.common.av.JavaSoundAudioSink();
+                audioSink = AudioSinkFactory.createDefault(FFMPEGMediaPlayer.class.getClassLoader());
+            }
+            {
+                final int audioChannelLimit = getAudioChannelLimit();
+                if( audioChannelLimit >= 1 ) {
+                    audioSink.setChannelLimit(audioChannelLimit);
+                }
+            }
+            final AudioFormat preferredAudioFormat = audioSink.getPreferredFormat();
+            if(DEBUG) {
+                System.err.println("initStream: p2 aid "+aid+"/"+alang+", preferred "+preferredAudioFormat+" on "+audioSink+", "+this);
             }
-        }
-        final AudioFormat preferredAudioFormat = audioSink.getPreferredFormat();
-        if(DEBUG) {
-            System.err.println("initStream: p2 aid "+aid+", preferred "+preferredAudioFormat+" on "+audioSink+", "+this);
-        }
 
-        final boolean isCameraInput = null != cameraPath;
-        final String resStreamLocS;
-        // int rw=640, rh=480, rr=15;
-        int rw=-1, rh=-1, rr=-1;
-        String sizes = null;
-        if( isCameraInput ) {
-            switch(PlatformPropsImpl.OS_TYPE) {
-                case ANDROID:
-                    // ??
-                case FREEBSD:
-                case HPUX:
-                case LINUX:
-                case SUNOS:
-                    resStreamLocS = dev_video_linux + cameraPath.decode();
-                    break;
-                case WINDOWS:
-                case MACOS:
-                case OPENKODE:
-                default:
-                    resStreamLocS = cameraPath.decode();
-                    break;
+            final boolean isCameraInput = null != cameraPath;
+            final String resStreamLocS;
+            // int rw=640, rh=480, rr=15;
+            int rw=-1, rh=-1, rr=-1;
+            String sizes = null;
+            if( isCameraInput ) {
+                switch(PlatformPropsImpl.OS_TYPE) {
+                    case ANDROID:
+                        // ??
+                    case FREEBSD:
+                    case HPUX:
+                    case LINUX:
+                    case SUNOS:
+                        resStreamLocS = dev_video_linux + cameraPath.decode();
+                        break;
+                    case WINDOWS:
+                    case MACOS:
+                    case OPENKODE:
+                    default:
+                        resStreamLocS = cameraPath.decode();
+                        break;
+                }
+                if( null != cameraProps ) {
+                    sizes = cameraProps.get(CameraPropSizeS);
+                    int v = getPropIntVal(cameraProps, CameraPropWidth);
+                    if( v > 0 ) { rw = v; }
+                    v = getPropIntVal(cameraProps, CameraPropHeight);
+                    if( v > 0 ) { rh = v; }
+                    v = getPropIntVal(cameraProps, CameraPropRate);
+                    if( v > 0 ) { rr = v; }
+                }
+            } else {
+                resStreamLocS = streamLocS;
             }
-            if( null != cameraProps ) {
-                sizes = cameraProps.get(CameraPropSizeS);
-                int v = getPropIntVal(cameraProps, CameraPropWidth);
-                if( v > 0 ) { rw = v; }
-                v = getPropIntVal(cameraProps, CameraPropHeight);
-                if( v > 0 ) { rh = v; }
-                v = getPropIntVal(cameraProps, CameraPropRate);
-                if( v > 0 ) { rr = v; }
+            final int aMaxChannelCount = preferredAudioFormat.channelCount;
+            final int aPrefSampleRate = preferredAudioFormat.sampleRate;
+             // setStream(..) issues updateAttributes*(..), and defines avChosenAudioFormat, vid, aid, .. etc
+            if(DEBUG) {
+                System.err.println("initStream: p3 cameraPath "+cameraPath+", isCameraInput "+isCameraInput);
+                System.err.println("initStream: p3 stream "+getUri()+" -> "+streamLocS+" -> "+resStreamLocS);
+                System.err.println("initStream: p3 vid "+vid+", sizes "+sizes+", reqVideo "+rw+"x"+rh+"@"+rr+", aid "+aid+", aMaxChannelCount "+aMaxChannelCount+", aPrefSampleRate "+aPrefSampleRate);
             }
-        } else {
-            resStreamLocS = streamLocS;
+            natives.setStream0(moviePtr, resStreamLocS, isCameraInput, vid, sizes, rw, rh, rr, alang, aid, aMaxChannelCount, aPrefSampleRate, slang, sid);
         }
-        final int aMaxChannelCount = preferredAudioFormat.channelCount;
-        final int aPrefSampleRate = preferredAudioFormat.sampleRate;
-         // setStream(..) issues updateAttributes*(..), and defines avChosenAudioFormat, vid, aid, .. etc
-        if(DEBUG) {
-            System.err.println("initStream: p3 cameraPath "+cameraPath+", isCameraInput "+isCameraInput);
-            System.err.println("initStream: p3 stream "+getUri()+" -> "+streamLocS+" -> "+resStreamLocS);
-            System.err.println("initStream: p3 vid "+vid+", sizes "+sizes+", reqVideo "+rw+"x"+rh+"@"+rr+", aid "+aid+", aMaxChannelCount "+aMaxChannelCount+", aPrefSampleRate "+aPrefSampleRate);
-        }
-        natives.setStream0(moviePtr, resStreamLocS, isCameraInput, vid, sizes, rw, rh, rr, aid, aMaxChannelCount, aPrefSampleRate);
     }
 
+    @Override
+    protected void updateMetadata() {
+        final Chapter[] chapters = new Chapter[natives.getChapterCount0(moviePtr)];
+        for(int i=0; i<chapters.length; ++i) {
+            chapters[i] = new Chapter(natives.getChapterID0(moviePtr, i),
+                                      natives.getChapterStartPTS0(moviePtr, i), natives.getChapterEndPTS0(moviePtr, i),
+                                      natives.getChapterTitle0(moviePtr, i));
+        }
+        this.chapters = chapters;
+    }
+    private volatile Chapter[] chapters = new Chapter[0];
+
+    @Override
+    public Chapter[] getChapters() { return chapters; }
+
     @Override
     protected final void initGLImpl(final GL gl) throws IOException, GLException {
         if(0==moviePtr) {
             throw new GLException("FFMPEG native instance null");
         }
-        final int audioQueueLimit;
+        final int audioQueueSize;
         if( null != gl && STREAM_ID_NONE != getVID() ) {
             final GLContextImpl ctx = (GLContextImpl)gl.getContext();
             SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
                 @Override
                 public Object run() {
                     final ProcAddressTable pt = ctx.getGLProcAddressTable();
+                    final long procAddrGLTexImage2D = pt.getAddressFor("glTexImage2D");
                     final long procAddrGLTexSubImage2D = pt.getAddressFor("glTexSubImage2D");
                     final long procAddrGLGetError = pt.getAddressFor("glGetError");
                     final long procAddrGLFlush = pt.getAddressFor("glFlush");
                     final long procAddrGLFinish = pt.getAddressFor("glFinish");
-                    natives.setGLFuncs0(moviePtr, procAddrGLTexSubImage2D, procAddrGLGetError, procAddrGLFlush, procAddrGLFinish);
+                    final long procAddrGLEnable;
+                    if( !gl.isGLcore() && GLES2.GL_TEXTURE_EXTERNAL_OES != getTextureTarget() ) {
+                        procAddrGLEnable = pt.getAddressFor("glEnable");
+                    } else {
+                        procAddrGLEnable = 0;
+                    }
+                    final long procAddrGLBindTexture = pt.getAddressFor("glBindTexture");
+                    natives.setGLFuncs0(moviePtr, procAddrGLTexImage2D, procAddrGLTexSubImage2D,
+                                        procAddrGLGetError, procAddrGLFlush, procAddrGLFinish,
+                                        procAddrGLEnable, procAddrGLBindTexture, gl.isNPOTTextureAvailable());
                     return null;
             } } );
-            audioQueueLimit = AudioSink.DefaultQueueLimitWithVideo;
+            audioQueueSize = AudioSink.DefaultQueueSizeWithVideo;
         } else {
-            audioQueueLimit = AudioSink.DefaultQueueLimitAudioOnly;
+            audioQueueSize = AudioSink.DefaultQueueSize;
         }
         if(DEBUG) {
             System.err.println("initGL: p3 aid "+getAID()+", avChosen "+avChosenAudioFormat+" on "+audioSink);
@@ -434,7 +483,7 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                 audioSink.destroy();
             }
             audioSink = AudioSinkFactory.createNull();
-            audioSink.init(AudioSink.DefaultFormat, 0, AudioSink.DefaultInitialQueueSize, AudioSink.DefaultQueueGrowAmount, audioQueueLimit);
+            audioSink.init(AudioSink.DefaultFormat, 0, audioQueueSize);
         } else {
             final int frameDuration;
             if( audioSamplesPerFrameAndChannel > 0 ) {
@@ -442,12 +491,12 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
             } else {
                 frameDuration = AudioSink.DefaultFrameDuration;
             }
-            final boolean audioSinkOK = audioSink.init(avChosenAudioFormat, frameDuration, AudioSink.DefaultInitialQueueSize, AudioSink.DefaultQueueGrowAmount, audioQueueLimit);
+            final boolean audioSinkOK = audioSink.init(avChosenAudioFormat, frameDuration, audioQueueSize);
             if( !audioSinkOK ) {
                 System.err.println("AudioSink "+audioSink.getClass().getName()+" does not support "+avChosenAudioFormat+", using Null");
                 audioSink.destroy();
                 audioSink = AudioSinkFactory.createNull();
-                audioSink.init(avChosenAudioFormat, 0, AudioSink.DefaultInitialQueueSize, AudioSink.DefaultQueueGrowAmount, audioQueueLimit);
+                audioSink.init(avChosenAudioFormat, 0, audioQueueSize);
             }
         }
         if(DEBUG) {
@@ -458,39 +507,50 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
         if( null != gl && STREAM_ID_NONE != getVID() ) {
             int tf, tif=GL.GL_RGBA; // texture format and internal format
             final int tt = GL.GL_UNSIGNED_BYTE;
+            final int texBytesPerPixel;
             switch(vBytesPerPixelPerPlane) {
-                case 1:
-                    if( gl.isGL3ES3() ) {
-                        // RED is supported on ES3 and >= GL3 [core]; ALPHA is deprecated on core
-                        tf = GL2ES2.GL_RED;   tif=GL2ES2.GL_RED; singleTexComp = "r";
-                    } else {
-                        // ALPHA is supported on ES2 and GL2, i.e. <= GL3 [core] or compatibility
-                        tf = GL.GL_ALPHA; tif=GL.GL_ALPHA; singleTexComp = "a";
-                    }
-                    break;
+                case 1: if( gl.isGL3ES3() ) {
+                            // RED is supported on ES3 and >= GL3 [core]; ALPHA is deprecated on core
+                            tf = GL2ES2.GL_RED;   tif=GL2ES2.GL_RED; singleTexComp = "r";
+                        } else {
+                            // ALPHA is supported on ES2 and GL2, i.e. <= GL3 [core] or compatibility
+                            tf = GL.GL_ALPHA; tif=GL.GL_ALPHA; singleTexComp = "a";
+                        }
+                        texBytesPerPixel = 1;
+                        break;
 
                 case 2: if( vPixelFmt == VideoPixelFormat.YUYV422 || vPixelFmt == VideoPixelFormat.UYVY422 ) {
                             // YUYV422: // < packed YUV 4:2:2, 2x 16bpp, Y0 Cb Y1 Cr
                             // UYVY422: // < packed YUV 4:2:2, 2x 16bpp, Cb Y0 Cr Y1
                             // Both stuffed into RGBA half width texture
-                            tf = GL.GL_RGBA; tif=GL.GL_RGBA; break;
+                            tf = GL.GL_RGBA; tif=GL.GL_RGBA;
+                            texBytesPerPixel = 4;
                         } else {
-                            tf = GL2ES2.GL_RG;   tif=GL2ES2.GL_RG; break;
+                            tf = GL2ES2.GL_RG;   tif=GL2ES2.GL_RG;
+                            texBytesPerPixel = 2;
                         }
-                case 3: tf = GL.GL_RGB;   tif=GL.GL_RGB;   break;
+                        break;
+
+                case 3: tf = GL.GL_RGB;   tif=GL.GL_RGB; texBytesPerPixel = 3; break;
+
                 case 4: if( vPixelFmt == VideoPixelFormat.BGRA ) {
-                            tf = GL.GL_BGRA;  tif=GL.GL_RGBA;  break;
+                            tf = GL.GL_BGRA;  tif=GL.GL_RGBA;
                         } else {
-                            tf = GL.GL_RGBA;  tif=GL.GL_RGBA;  break;
+                            tf = GL.GL_RGBA;  tif=GL.GL_RGBA;
                         }
+                        texBytesPerPixel = 4;
+                        break;
+
                 default: throw new RuntimeException("Unsupported bytes-per-pixel / plane "+vBytesPerPixelPerPlane);
             }
             setTextureFormat(tif, tf);
             setTextureType(tt);
             setIsGLOriented(false);
-            if(DEBUG) {
-                System.err.println("initGL: p5: video "+vPixelFmt+", planes "+vPlanes+", bpp "+vBitsPerPixel+"/"+vBytesPerPixelPerPlane+
-                                   ", tex "+texWidth+"x"+texHeight+", usesTexLookupShader "+usesTexLookupShader);
+            if( DEBUG ) {
+                final float texSizeMB = ( texWidth * texHeight * (float)texBytesPerPixel ) / 1000000f;
+                System.err.printf("initGL: p5: video %s, bpp %d, %d x %d, %d b/pp, %d planes, tex %d x %d x %d -> %.2fMB%n",
+                        vPixelFmt.toString(), vBitsPerPixel, vWidth, vHeight, vBytesPerPixelPerPlane, vPlanes,
+                        texWidth, texHeight, texBytesPerPixel, texSizeMB);
             }
         }
     }
@@ -598,11 +658,11 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                           final int aid, final int audioSampleFmt, final int audioSampleRate,
                           final int audioChannels, final int audioSamplesPerFrameAndChannel) {
         // defaults ..
-        vPixelFmt = null;
+        vPixelFmt = VideoPixelFormat.RGBA;
         vPlanes = 0;
         vBitsPerPixel = 0;
         vBytesPerPixelPerPlane = 0;
-        usesTexLookupShader = false;
+        vWidth = 0; vHeight = 0;
         texWidth = 0; texHeight = 0;
 
         final int[] vTexWidth = { 0, 0, 0 }; // per plane
@@ -612,12 +672,12 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
             vPlanes = planes;
             vBitsPerPixel = bitsPerPixel;
             vBytesPerPixelPerPlane = bytesPerPixelPerPlane;
+            vWidth = vW; vHeight = vH;
             vTexWidth[0] = tWd0; vTexWidth[1] = tWd1; vTexWidth[2] = tWd2;
 
             switch(vPixelFmt) {
                 case YUVJ420P:
                 case YUV420P: // < planar YUV 4:2:0, 12bpp, (1 Cr & Cb sample per 2x2 Y samples)
-                    usesTexLookupShader = true;
                     // YUV420P: Adding U+V on right side of fixed height texture,
                     //          since width is already aligned by decoder.
                     //          Splitting texture to 4 quadrants:
@@ -631,7 +691,6 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                     break;
                 case YUVJ422P:
                 case YUV422P:
-                    usesTexLookupShader = true;
                     // YUV422P: Adding U+V on right side of fixed height texture,
                     //          since width is already aligned by decoder.
                     //          Splitting texture to 4 columns
@@ -643,7 +702,6 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                 case YUYV422: // < packed YUV 4:2:2, 2x 16bpp, Y0 Cb Y1 Cr - stuffed into RGBA half width texture
                 case UYVY422: // < packed YUV 4:2:2, 2x 16bpp, Cb Y0 Cr Y1 - stuffed into RGBA half width texture
                 case BGR24:
-                    usesTexLookupShader = true;
                     texWidth = vTexWidth[0]; texHeight = vH;
                     break;
 
@@ -652,7 +710,6 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
                 case RGBA:
                 case ABGR:
                 case BGRA:
-                    usesTexLookupShader = false;
                     texWidth = vTexWidth[0]; texHeight = vH;
                     break;
                 default: // FIXME: Add more formats !
@@ -675,7 +732,8 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
 
         if(DEBUG) {
             System.err.println("audio: id "+aid+", fmt "+aSampleFmt+", "+avChosenAudioFormat+", aFrameSize/fc "+audioSamplesPerFrameAndChannel);
-            System.err.println("video: id "+vid+", fmt "+vW+"x"+vH+", "+vPixelFmt+", planes "+vPlanes+", bpp "+vBitsPerPixel+"/"+vBytesPerPixelPerPlane+", usesTexLookupShader "+usesTexLookupShader);
+            System.err.printf("video: id %d, %s, bpp %d, %d x %d, %d b/pp, %d planes, tex %d x %d%n",
+                    vid, vPixelFmt.toString(), vBitsPerPixel, vWidth, vHeight, vBytesPerPixelPerPlane, vPlanes, texWidth, texHeight);
             for(int i=0; i<3; i++) {
                 System.err.println("video: p["+i+"]: "+vTexWidth[i]);
             }
@@ -708,15 +766,16 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
      */
     @Override
     public String setTextureLookupFunctionName(final String texLookupFuncName) throws IllegalStateException {
-        if( usesTexLookupShader ) {
-            if(null != texLookupFuncName && texLookupFuncName.length()>0) {
-                textureLookupFunctionName = texLookupFuncName;
-            } else {
-                textureLookupFunctionName = "ffmpegTexture2D";
+        if(null != texLookupFuncName && texLookupFuncName.length()>0) {
+            if( texLookupFuncName.equals("texture2D") ) {
+                throw new IllegalArgumentException("Build in 'texture2D' lookup-func-name not allowed!");
             }
-            return textureLookupFunctionName;
+            textureLookupFunctionName = texLookupFuncName;
+        } else {
+            textureLookupFunctionName = "ffmpegTexture2D";
         }
-        return super.getTextureLookupFunctionName();
+        resetTextureFragmentShaderHashCode();
+        return textureLookupFunctionName;
     }
 
     /**
@@ -727,15 +786,17 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
      */
     @Override
     public final String getTextureLookupFragmentShaderImpl() {
-      if( !usesTexLookupShader ) {
-          return super.getTextureLookupFragmentShaderImpl();
-      }
       final float tc_w_1 = (float)getWidth() / (float)texWidth;
+      final String texLookupFuncName = getTextureLookupFunctionName();
+      if( texLookupFuncName.equals("texture2D") ) {
+          throw new IllegalArgumentException("Build in 'texture2D' lookup-func-name not allowed!");
+      }
       switch(vPixelFmt) {
         case YUVJ420P:
         case YUV420P: // < planar YUV 4:2:0, 12bpp, (1 Cr & Cb sample per 2x2 Y samples)
           return
-              "vec4 "+getTextureLookupFunctionName()+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "// YUV420P: planar YUV 4:2:0, 12bpp, (1 Cr & Cb sample per 2x2 Y samples)\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
               "  const vec2 u_off = vec2("+tc_w_1+", 0.0);\n"+
               "  const vec2 v_off = vec2("+tc_w_1+", 0.5);\n"+
               "  vec2 tc_half = texCoord*0.5;\n"+
@@ -754,9 +815,10 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
           ;
 
         case YUVJ422P:
-        case YUV422P: ///< planar YUV 4:2:2, 16bpp, (1 Cr & Cb sample per 2x1 Y samples)
+        case YUV422P: // < planar YUV 4:2:2, 16bpp, (1 Cr & Cb sample per 2x1 Y samples)
           return
-              "vec4 "+getTextureLookupFunctionName()+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "// YUV422P: planar YUV 4:2:2, 16bpp, (1 Cr & Cb sample per 2x1 Y samples)\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
               "  const vec2 u_off = vec2("+tc_w_1+"      , 0.0);\n"+
               "  const vec2 v_off = vec2("+tc_w_1+" * 1.5, 0.0);\n"+
               "  vec2 tc_halfw = vec2(texCoord.x*0.5, texCoord.y);\n"+
@@ -777,7 +839,8 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
         case YUYV422: // < packed YUV 4:2:2, 2 x 16bpp, [Y0 Cb] [Y1 Cr]
                       // Stuffed into RGBA half width texture
           return
-              "vec4 "+getTextureLookupFunctionName()+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "// YUYV422: packed YUV 4:2:2, 2 x 16bpp, [Y0 Cb] [Y1 Cr]\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
               "  "+
               "  float y1,u,y2,v,y,r,g,b;\n"+
               "  vec2 tc_halfw = vec2(texCoord.x*0.5, texCoord.y);\n"+
@@ -799,7 +862,8 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
         case UYVY422: // < packed YUV 4:2:2, 2 x 16bpp, Cb Y0 Cr Y1
                       // Stuffed into RGBA half width texture
           return
-              "vec4 "+getTextureLookupFunctionName()+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "// UYVY422: packed YUV 4:2:2, 2 x 16bpp, Cb Y0 Cr Y1\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
               "  "+
               "  float y1,u,y2,v,y,r,g,b;\n"+
               "  vec2 tc_halfw = vec2(texCoord.x*0.5, texCoord.y);\n"+
@@ -821,7 +885,52 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
 
         case BGR24:
           return
-              "vec4 "+getTextureLookupFunctionName()+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "// BGR24\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "  "+
+              "  vec3 bgr = texture2D(image, texCoord).rgb;\n"+
+              "  return vec4(bgr.b, bgr.g, bgr.r, 1);\n"+ /* just swizzle */
+              "}\n"
+          ;
+        case RGB24:
+          return
+              "// RGB24\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "  "+
+              "  vec3 t = texture2D(image, texCoord).rgb;\n"+
+              "  return vec4(t.rgb, 1);\n"+
+              "}\n"
+          ;
+        case ARGB:
+          return
+              "// ARGB\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "  "+
+              "  vec4 t = texture2D(image, texCoord);\n"+
+              "  return vec4(t.g, t.b, t.a, t.r);\n"+ /* just swizzle */
+              "}\n"
+          ;
+        case RGBA:
+          return
+              "// RGBA\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "  "+
+              "  return texture2D(image, texCoord);\n"+
+              "}\n"
+          ;
+        case ABGR:
+          return
+              "// ABGR\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
+              "  "+
+              "  vec4 t = texture2D(image, texCoord);\n"+
+              "  return vec4(t.a, t.b, t.g, t.r);\n"+ /* just swizzle */
+              "}\n"
+          ;
+        case BGRA:
+          return
+              "// BGR24\n"+
+              "vec4 "+texLookupFuncName+"(in "+getTextureSampler2DType()+" image, in vec2 texCoord) {\n"+
               "  "+
               "  vec3 bgr = texture2D(image, texCoord).rgb;\n"+
               "  return vec4(bgr.b, bgr.g, bgr.r, 1);\n"+ /* just swizzle */
@@ -829,10 +938,16 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
           ;
 
         default: // FIXME: Add more formats !
-          throw new InternalError("Add proper mapping of: vPixelFmt "+vPixelFmt+", usesTexLookupShader "+usesTexLookupShader);
+          throw new InternalError("Add proper mapping of: vPixelFmt "+vPixelFmt);
       }
     }
 
+    @Override
+    public final String getTextureFragmentShaderHashID() {
+        // return getTextureSampler2DType()+";"+getTextureLookupFunctionName()+";"+getTextureLookupFragmentShaderImpl();
+        return getTextureLookupFragmentShaderImpl();
+    }
+
     @Override
     public final boolean resumeImpl() {
         if(0==moviePtr) {
@@ -877,33 +992,45 @@ public class FFMPEGMediaPlayer extends GLMediaPlayerImpl {
     }
 
     @Override
-    protected final int getNextTextureImpl(final GL gl, final TextureFrame nextFrame) {
+    protected final int getNextTextureImpl(final GL gl, final TextureFrame vFrame, final Texture sTex, final boolean[] sTexUsed) {
         if(0==moviePtr) {
             throw new GLException("FFMPEG native instance null");
         }
         int vPTS = TimeFrameI.INVALID_PTS;
+        int vTexID = 0; // invalid
         if( null != gl ) {
-            final Texture tex = nextFrame.getTexture();
-            tex.enable(gl);
-            tex.bind(gl);
+            // glEnable() and glBindTexture() are performed in native readNextPacket0()
+            // final Texture tex = nextFrame.getTexture();
+            // tex.enable(gl);
+            // tex.bind(gl);
+            vTexID = vFrame.getTexture().getTextureObject();
         }
 
         /** Try decode up to 10 packets to find one containing video. */
         for(int i=0; TimeFrameI.INVALID_PTS == vPTS && 10 > i; i++) {
-           vPTS = natives.readNextPacket0(moviePtr, getTextureTarget(), getTextureFormat(), getTextureType());
+            int sTexID = 0; // invalid
+            int sTexWidth = 0;
+            int sTexHeight = 0;
+            if( null != gl && !sTexUsed[0] ) {
+                // glEnable() and glBindTexture() are performed in native readNextPacket0()
+                // final Texture tex = nextFrame.getTexture();
+                // tex.enable(gl);
+                // tex.bind(gl);
+                vTexID = vFrame.getTexture().getTextureObject();
+                if( null != sTex ) {
+                    sTexID = sTex.getTextureObject();
+                    // FIXME: Disabled in native code, buggy on AMD GPU corrupting texture content
+                    sTexWidth = sTex.getWidth();
+                    sTexHeight = sTex.getHeight();
+                }
+            }
+            vPTS = natives.readNextPacket0(moviePtr, getTextureTarget(), vTexID, getTextureFormat(), getTextureType(),
+                    GL.GL_TEXTURE_2D, sTexID, sTexWidth, sTexHeight, sTex, sTexUsed);
         }
-        if( null != nextFrame ) {
-            nextFrame.setPTS(vPTS);
+        if( null != vFrame ) {
+            vFrame.setPTS(vPTS);
         }
         return vPTS;
     }
-
-    final void pushSound(final ByteBuffer sampleData, final int data_size, final int audio_pts) {
-        setFirstAudioPTS2SCR( audio_pts );
-        if( 1.0f == getPlaySpeed() || audioSinkPlaySpeedSet ) {
-            audioSink.enqueueData( audio_pts, sampleData, data_size);
-        }
-    }
-
 }
 
