@@ -317,7 +317,7 @@ public class JPEGDecoder {
             this.precision = precision;
             this.scanLines = scanLines;
             this.samplesPerLine = samplesPerLine;
-            compIDs = new ArrayHashSet<Integer>(componentsCount);
+            compIDs = new ArrayHashSet<Integer>(false, componentsCount, ArrayHashSet.DEFAULT_LOAD_FACTOR);
             comps = new ComponentIn[componentsCount];
             this.compCount = componentsCount;
             this.qtt = qtt;
@@ -470,11 +470,11 @@ public class JPEGDecoder {
     }
 
     private final int readUInt8() throws IOException {
-        return bstream.readUInt8(true /* msbFirst */);
+        return bstream.readUInt8();
     }
 
     private final int readUInt16() throws IOException {
-        return bstream.readUInt16(true /* msbFirst */, true /* bigEndian */);
+        return bstream.readUInt16(true /* bigEndian */);
     }
 
     private final int readNumber() throws IOException {
