@@ -163,6 +163,10 @@ public abstract class ProxySurfaceImpl implements ProxySurface {
 
     @Override
     public boolean surfaceSwap() {
+        final NativeSurface upstreamSurface = upstream.getUpstreamSurface();
+        if( null != upstreamSurface ) {
+            return upstreamSurface.surfaceSwap();
+        }
         return false;
     }
 
@@ -186,6 +190,11 @@ public abstract class ProxySurfaceImpl implements ProxySurface {
         surfaceUpdatedHelper.surfaceUpdated(updater, ns, when);
     }
 
+    @Override
+    public RecursiveLock getLock() {
+        return surfaceLock;
+    }
+
     @Override
     public int lockSurface() throws NativeWindowException, RuntimeException  {
         surfaceLock.lock();
