@@ -7,6 +7,8 @@ import com.jogamp.nativewindow.UpstreamSurfaceHook;
 
 import com.jogamp.nativewindow.UpstreamSurfaceHookMutableSize;
 
+import jogamp.nativewindow.macosx.OSXUtil.WinAndView;
+
 public class OSXDummyUpstreamSurfaceHook extends UpstreamSurfaceHookMutableSize {
     long nsWindow;
 
@@ -26,11 +28,12 @@ public class OSXDummyUpstreamSurfaceHook extends UpstreamSurfaceHookMutableSize
     @Override
     public final void create(final ProxySurface s) {
         if(0 == nsWindow && 0 == s.getSurfaceHandle()) {
-            nsWindow = OSXUtil.CreateNSWindow(0, 0, 64, 64);
+            final WinAndView wv = OSXUtil.CreateNSWindow2(0, 0, 64, 64);
+            nsWindow = wv.win;
             if(0 == nsWindow) {
                 throw new NativeWindowException("Error NS window 0");
             }
-            final long nsView = OSXUtil.GetNSView(nsWindow);
+            final long nsView = wv.view;
             if(0 == nsView) {
                 throw new NativeWindowException("Error NS view 0");
             }
@@ -46,10 +49,15 @@ public class OSXDummyUpstreamSurfaceHook extends UpstreamSurfaceHookMutableSize
             if( 0 == nsWindow || 0 == s.getSurfaceHandle() ) {
                 throw new InternalError("Owns upstream surface, but no OSX view/window: "+s+", nsWindow 0x"+Long.toHexString(nsWindow));
             }
-            OSXUtil.DestroyNSWindow(nsWindow);
+            final long _nsWindow = nsWindow;
             nsWindow = 0;
             s.setSurfaceHandle(0);
             s.clearUpstreamOptionBits( ProxySurface.OPT_PROXY_OWNS_UPSTREAM_SURFACE );
+            OSXUtil.RunOnMainThread(false /* wait */, false, new Runnable() {
+                    @Override
+                    public void run() {
+                        OSXUtil.DestroyNSWindow(_nsWindow);
+                    } } );
         }
     }
 
