@@ -34,7 +34,7 @@
 
 package com.jogamp.newt.event;
 
-import com.jogamp.common.util.IntBitfield;
+import com.jogamp.common.util.Bitfield;
 
 /**
  * <a name="eventDelivery"><h5>KeyEvent Delivery</h5></a>
@@ -141,7 +141,7 @@ public class KeyEvent extends InputEvent
             // Validate flags
             //
             final int pma_bits = flags & ( F_PRINTABLE_MASK | F_MODIFIER_MASK | F_ACTION_MASK ) ;
-            final int pma_count = IntBitfield.getBitCount(pma_bits);
+            final int pma_count = Bitfield.Util.bitCount(pma_bits);
             if ( 1 != pma_count ) {
                 throw new InternalError("Key must be either of type printable, modifier or action - but it is of "+pma_count+" types: "+this);
             }
@@ -213,8 +213,8 @@ public class KeyEvent extends InputEvent
 
     public static String getEventTypeString(final short type) {
         switch(type) {
-        case EVENT_KEY_PRESSED: return "EVENT_KEY_PRESSED";
-        case EVENT_KEY_RELEASED: return "EVENT_KEY_RELEASED";
+        case EVENT_KEY_PRESSED: return "PRESSED";
+        case EVENT_KEY_RELEASED: return "RELEASED";
         default: return "unknown (" + type + ")";
         }
     }
