@@ -77,11 +77,11 @@ public class ScreenDriver extends ScreenImpl {
     private static MonitorMode getModeProps(final Cache cache, final DisplayMode mode) {
         int rate = mode.getRefreshRate();
         if( DisplayMode.REFRESH_RATE_UNKNOWN == rate ) {
-            rate = ScreenImpl.default_sm_rate;
+            rate = MonitorDevice.DEFAULT_MODE_REFRESH;
         }
         int bpp = mode.getBitDepth();
         if( DisplayMode.BIT_DEPTH_MULTI == bpp ) {
-            bpp= ScreenImpl.default_sm_bpp;
+            bpp = MonitorDevice.DEFAULT_MODE_BPP;
         }
         final int[] props = new int[ MonitorModeProps.NUM_MONITOR_MODE_PROPERTIES_ALL ];
         int i = 0;
@@ -112,13 +112,8 @@ public class ScreenDriver extends ScreenImpl {
         props[i++] = crt_id;
         props[i++] = 0; // is-clone
         props[i++] = 1; // is-primary
-        if( null != usrMonitorMMSize ) {
-            props[i++] = usrMonitorMMSize.getWidth();
-            props[i++] = usrMonitorMMSize.getHeight();
-        } else {
-            props[i++] = ScreenImpl.default_sm_widthmm; // FIXME
-            props[i++] = ScreenImpl.default_sm_heightmm; // FIXME
-        }
+        props[i++] = MonitorDevice.DEFAULT_SCREEN_MM_SIZE.getWidth();
+        props[i++] = MonitorDevice.DEFAULT_SCREEN_MM_SIZE.getHeight();
         props[i++] = 0; // rotated viewport x pixel-units
         props[i++] = 0; // rotated viewport y pixel-units
         props[i++] = currentMode.getRotatedWidth(); // rotated viewport width pixel-units
