@@ -29,6 +29,7 @@
 package jogamp.newt.driver.ios;
 
 import com.jogamp.common.util.InterruptSource;
+import com.jogamp.math.FloatUtil;
 import com.jogamp.nativewindow.AbstractGraphicsConfiguration;
 import com.jogamp.nativewindow.GraphicsConfigurationFactory;
 import com.jogamp.nativewindow.NativeWindow;
@@ -51,7 +52,6 @@ import com.jogamp.newt.event.InputEvent;
 import com.jogamp.newt.event.KeyEvent;
 import com.jogamp.newt.event.MonitorEvent;
 import com.jogamp.newt.event.MouseEvent;
-import com.jogamp.opengl.math.FloatUtil;
 
 public class WindowDriver extends WindowImpl implements MutableSurface, DriverClearFocus, DriverUpdatePosition {
 
@@ -66,10 +66,10 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
                                      final float newPixelScaleRaw, final float maxPixelScaleRaw) {
         final float[] newPixelScale = new float[2];
         {
-            final float _newPixelScale = FloatUtil.isZero(newPixelScaleRaw, FloatUtil.EPSILON) ? ScalableSurface.IDENTITY_PIXELSCALE : newPixelScaleRaw;
+            final float _newPixelScale = FloatUtil.isZero(newPixelScaleRaw) ? ScalableSurface.IDENTITY_PIXELSCALE : newPixelScaleRaw;
             newPixelScale[0]= _newPixelScale;
             newPixelScale[1]= _newPixelScale;
-            final float _maxPixelScale = FloatUtil.isZero(maxPixelScaleRaw, FloatUtil.EPSILON) ? ScalableSurface.IDENTITY_PIXELSCALE : maxPixelScaleRaw;
+            final float _maxPixelScale = FloatUtil.isZero(maxPixelScaleRaw) ? ScalableSurface.IDENTITY_PIXELSCALE : maxPixelScaleRaw;
             maxPixelScale[0]= _maxPixelScale;
             maxPixelScale[1]= _maxPixelScale;
         }
@@ -526,15 +526,16 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
     }
 
     /** Callback for native screen position change event of the client area. */
-    protected void screenPositionChanged(final boolean defer, final int newX, final int newY) {
+    protected boolean screenPositionChanged(final boolean defer, final int newX, final int newY) {
         // passed coordinates are in screen position of the client area
         if( isNativeValid() ) {
+            final boolean[] res = { true };
             final NativeWindow parent = getParent();
             if( !useParent(parent) || isOffscreenInstance ) {
                 if(DEBUG_IMPLEMENTATION) {
                     System.err.println("MacWindow.positionChanged.0 (Screen Pos - TOP): ("+getThreadName()+"): (defer: "+defer+") "+getX()+"/"+getY()+" -> "+newX+"/"+newY);
                 }
-                positionChanged(defer, true, newX, newY);
+                res[0] = positionChanged(defer, true, newX, newY);
             } else {
                 final Runnable action = new Runnable() {
                     @Override
@@ -547,18 +548,19 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
                         if(DEBUG_IMPLEMENTATION) {
                             System.err.println("MacWindow.positionChanged.1 (Screen Pos - CHILD): ("+getThreadName()+"): (defer: "+defer+") "+getX()+"/"+getY()+" -> absPos "+newX+"/"+newY+", parentOnScreen "+parentOnScreen+" -> "+absPos);
                         }
-                        positionChanged(false, true, absPos.getX(), absPos.getY());
+                        res[0] = positionChanged(false, true, absPos.getX(), absPos.getY());
                     } };
                 if( defer ) {
                     new InterruptSource.Thread(null, action).start();
                 } else {
                     action.run();
                 }
-
             }
+            return res[0];
         } else if(DEBUG_IMPLEMENTATION) {
             System.err.println("MacWindow.positionChanged.2 (Screen Pos - IGN): ("+getThreadName()+"): (defer: "+defer+") "+getX()+"/"+getY()+" -> "+newX+"/"+newY);
         }
+        return false;
     }
 
     @Override
@@ -609,25 +611,26 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
     //
 
     /** Triggered by implementation's WM events to update the client-area position, size and insets. */
-    protected void sizeScreenPosInsetsChanged(final boolean defer,
-                                              final int newX, final int newY,
-                                              final int newWidth, final int newHeight,
-                                              final int left, final int right, final int top, final int bottom,
-                                              final boolean force,
-                                              final boolean withinLiveResize) {
+    protected boolean sizeScreenPosInsetsChanged(final boolean defer,
+                                                 final int newX, final int newY,
+                                                 final int newWidth, final int newHeight,
+                                                 final int left, final int right, final int top, final int bottom,
+                                                 final boolean force,
+                                                 final boolean withinLiveResize) {
         final LifecycleHook lh = getLifecycleHook();
         if( withinLiveResize && !resizeAnimatorPaused && null!=lh ) {
             resizeAnimatorPaused = lh.pauseRenderingAction();
         }
-        sizeChanged(defer, false, newWidth, newHeight, force);
-        screenPositionChanged(defer, newX, newY);
-        insetsChanged(false, left, right, top, bottom);
-        if( !withinLiveResize && resizeAnimatorPaused ) {
+        boolean res = sizeChanged(defer, false, newWidth, newHeight, force);
+        res = res && screenPositionChanged(defer, newX, newY);
+        res = res && insetsChanged(false, left, right, top, bottom);
+        if( !withinLiveResize && resizeAnimatorPaused && res ) {
             resizeAnimatorPaused = false;
             if( null!=lh ) {
                 lh.resumeRenderingAction();
             }
         }
+        return res;
     }
 
     @Override
@@ -638,9 +641,9 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
                            SurfaceScaleUtils.scale(y, getPixelScaleY()), button, rotationXYZ, rotationScale);
     }
 
-    public final void sendTouchScreenEvent(final short eventType, final int modifiers,
-                                           final int[] pActionIdx, final short[] pNames,
-                                           final int[] pTypesI, final int[] pX, final int[] pY, final float[] pPressure, final float maxPressure) {
+    public final boolean sendTouchScreenEvent(final short eventType, final int modifiers,
+                                              final int[] pActionIdx, final short[] pNames,
+                                              final int[] pTypesI, final int[] pX, final int[] pY, final float[] pPressure, final float maxPressure) {
         final int pCount = pNames.length;
         final MouseEvent.PointerType[] pTypes = new MouseEvent.PointerType[pCount];
         for(int i=0; i<pCount; i++) {
@@ -651,19 +654,20 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
                            pTypes, eventType, modifiers, pActionIdx[i], true /*normalPNames*/, pNames,
                            pX, pY, pPressure, maxPressure, new float[] { 0f, 0f, 0f} /*rotationXYZ*/, 1f/*rotationScale*/);
         }
+        return isNativeValid();
     }
 
     @Override
-    public final void sendKeyEvent(final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
+    public final boolean sendKeyEvent(final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
         throw new InternalError("XXX: Adapt Java Code to Native Code Changes");
     }
 
     @Override
-    public final void enqueueKeyEvent(final boolean wait, final short eventType, final int modifiers, final short _keyCode, final short _keySym, final char keyChar) {
+    public final boolean enqueueKeyEvent(final boolean wait, final short eventType, final int modifiers, final short _keyCode, final short _keySym, final char keyChar) {
         throw new InternalError("XXX: Adapt Java Code to Native Code Changes");
     }
 
-    protected final void enqueueKeyEvent(final boolean wait, final short eventType, int modifiers, final short _keyCode, final char keyChar, final char keySymChar) {
+    protected final boolean enqueueKeyEvent(final boolean wait, final short eventType, int modifiers, final short _keyCode, final char keyChar, final char keySymChar) {
         // Note that we send the key char for the key code on this
         // platform -- we do not get any useful key codes out of the system
         final short keyCode = MacKeyUtil.validateKeyCode(_keyCode, keyChar);
@@ -685,6 +689,7 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
 
         // OSX delivery order is PRESSED (t0), RELEASED (t1) and TYPED (t2) -> NEWT order: PRESSED (t0) and RELEASED (t1)
         // Auto-Repeat: OSX delivers only PRESSED, inject auto-repeat RELEASE key _before_ PRESSED
+        boolean res = true;
         switch(eventType) {
             case KeyEvent.EVENT_KEY_RELEASED:
                 if( isKeyCodeTracked(keyCode) ) {
@@ -696,12 +701,12 @@ public class WindowDriver extends WindowImpl implements MutableSurface, DriverCl
                     if( setKeyPressed(keyCode, true) ) {
                         // key was already pressed
                         modifiers |= InputEvent.AUTOREPEAT_MASK;
-                        super.enqueueKeyEvent(wait, KeyEvent.EVENT_KEY_RELEASED, modifiers, keyCode, keySym, keyChar); // RELEASED
+                        res = super.enqueueKeyEvent(wait, KeyEvent.EVENT_KEY_RELEASED, modifiers, keyCode, keySym, keyChar); // RELEASED
                     }
                 }
                 break;
         }
-        super.enqueueKeyEvent(wait, eventType, modifiers, keyCode, keySym, keyChar);
+        return res && super.enqueueKeyEvent(wait, eventType, modifiers, keyCode, keySym, keyChar);
     }
 
     protected int getDisplayID() {
