@@ -74,12 +74,12 @@ public class WindowDriver extends WindowImpl {
     /**
      * Essentially updates {@code hasPixelScale}
      */
-    private boolean updatePixelScaleByMonitor(final long crt_handle, final int[] move_diff, final boolean sendEvent, final boolean defer) {
+    private boolean updatePixelScaleByMonitor(final long crt_handle, final int[] move_diff, final boolean setNativeWindow) {
         boolean res = false;
-        if( 0 != crt_handle ) {
+        if( !hasSetPixelScale() && 0 != crt_handle ) {
             final float newPixelScaleRaw[] = { 0, 0 };
             if( GDIUtil.GetMonitorPixelScale(crt_handle, newPixelScaleRaw) ) {
-                res = applySoftPixelScale(move_diff, sendEvent, defer, newPixelScaleRaw);
+                res = applySoftPixelScale(move_diff, newPixelScaleRaw, setNativeWindow);
             }
         }
         return res;
@@ -138,7 +138,7 @@ public class WindowDriver extends WindowImpl {
     @Override
     protected void monitorModeChanged(final MonitorEvent me, final boolean success) {
         if( hmon == me.getMonitor().getHandle() ) {
-            updatePixelScaleByMonitor(me.getMonitor().getHandle(), null, false /* sendEvent*/, false /* defer */); // send reshape event itself
+            updatePixelScaleByMonitor(me.getMonitor().getHandle(), null, true /* setNativeWindow */);
         }
     }
 
@@ -148,7 +148,7 @@ public class WindowDriver extends WindowImpl {
 
         boolean changed = false;
         if( isNativeValid() ) {
-            changed = applySoftPixelScale(null, true /* sendEvent */, false /* defer */, reqPixelScale);
+            changed = applySoftPixelScale(null, reqPixelScale, true /* setNativeWindow */);
         }
         if( DEBUG_IMPLEMENTATION ) {
             System.err.println("WindowDriver.setPixelScale: min["+minPixelScale[0]+", "+minPixelScale[1]+"], max["+
@@ -180,6 +180,13 @@ public class WindowDriver extends WindowImpl {
             flags |= CHANGE_MASK_MAXIMIZED_VERT;
             maxCount++;
         }
+        if( !hasSetPixelScale() ) {
+            final int[] xy_win = getWindowPosI();
+            final int[] sz_win = getWindowSizeI();
+            final long hmon0 = GDIUtil.GetMonitorFromRect(xy_win[0], xy_win[1], sz_win[0], sz_win[1]);
+            updatePixelScaleByMonitor(hmon0, null, false /* setNativeWindow */);
+        }
+
         final int[] xy_pix = getPixelPosI();
         final int[] sz_pix = getPixelSizeI();
 
@@ -194,20 +201,16 @@ public class WindowDriver extends WindowImpl {
         if( !cfg.getChosenCapabilities().isBackgroundOpaque() ) {
             GDIUtil.DwmSetupTranslucency(_windowHandle, true);
         }
-        InitWindow0(_windowHandle, flags);
         setWindowHandle(_windowHandle);
         windowHandleClose = _windowHandle;
+        InitWindow0(_windowHandle, flags);
 
         if( 0 == ( STATE_MASK_CHILDWIN & flags ) && 1 <= maxCount ) {
             reconfigureWindowImpl(xy_pix[0], xy_pix[1], sz_pix[0], sz_pix[1], flags);
         }
 
         hmon = GDIUtil.GetMonitorFromWindow(_windowHandle);
-        boolean changedPixelScale = applySoftPixelScale(null, true /* sendEvent */, false /* defer */, reqPixelScale);
-        if( !changedPixelScale ) {
-            changedPixelScale = updatePixelScaleByMonitor(hmon, null, true /* sendEvent */, false /* defer */);
-        }
-        positionModified[0] = changedPixelScale;
+        positionModified[0] = hasSetPixelScale() && applySoftPixelScale(null, reqPixelScale, true /* setNativeWindow */);
 
         if(DEBUG_IMPLEMENTATION) {
             final Exception e = new Exception("Info: Window new window handle "+Thread.currentThread().getName()+
@@ -328,7 +331,10 @@ public class WindowDriver extends WindowImpl {
                                            " - "+Thread.currentThread().getName());
                     }
                     hmon = _hmon;
-                    updatePixelScaleByMonitor(_hmon, move_diff, true /* sendEvent */, defer);
+                    updatePixelScaleByMonitor(_hmon, move_diff, true /* setNativeWindow */);
+                } else {
+                    // always check on native sizePosInsetsFocusVisibleChanged
+                    updatePixelScaleByMonitor(_hmon, null, true /* setNativeWindow */);
                 }
             }
         }
@@ -411,15 +417,16 @@ public class WindowDriver extends WindowImpl {
      * for details.
      * </p>
      */
-    public final void sendTouchScreenEvent(final short eventType, final int modifiers,
-                                           final int pActionIdx, final short[] pNames,
-                                           final int[] pX, final int[] pY, final float[] pPressure, final float maxPressure) {
+    public final boolean sendTouchScreenEvent(final short eventType, final int modifiers,
+                                              final int pActionIdx, final short[] pNames,
+                                              final int[] pX, final int[] pY, final float[] pPressure, final float maxPressure) {
         final int pCount = pNames.length;
         final MouseEvent.PointerType[] pTypes = new MouseEvent.PointerType[pCount];
         for(int i=pCount-1; i>=0; i--) { pTypes[i] = PointerType.TouchScreen; }
         doPointerEvent(false /*enqueue*/, false /*wait*/,
                        pTypes, eventType, modifiers, pActionIdx, false /*normalPNames*/, pNames,
                        pX, pY, pPressure, maxPressure, new float[] { 0f, 0f, 0f} /*rotationXYZ*/, 1f/*rotationScale*/);
+        return isNativeValid();
     }
 
     //
@@ -447,35 +454,37 @@ public class WindowDriver extends WindowImpl {
     }
 
     @Override
-    public final void sendKeyEvent(final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
+    public final boolean sendKeyEvent(final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
         final boolean isModifierKey = KeyEvent.isModifierKey(keySym);
         // System.err.println("*** sendKeyEvent: event "+KeyEvent.getEventTypeString(eventType)+", keyCode "+toHexString(keyCode)+", keyChar <"+keyChar+">, mods "+toHexString(modifiers)+
         //                   ", isKeyCodeTracked "+isKeyCodeTracked(keyCode)+", was: pressed "+isKeyPressed(keyCode)+", printableKey "+KeyEvent.isPrintableKey(keyCode, false)+" [modifierKey "+isModifierKey+"] - "+System.currentTimeMillis());
 
         // Reorder: WINDOWS delivery order is PRESSED (t0), TYPED (t0) and RELEASED (t1) -> NEWT order: PRESSED (t0) and RELEASED (t1)
         // Auto-Repeat: WINDOWS delivers only PRESSED (t0) and TYPED (t0).
+        boolean res = true;
         switch(eventType) {
             case KeyEvent.EVENT_KEY_RELEASED:
                 if( isKeyCodeTracked(keyCode) ) {
                     if( repeatedKey == keyCode && !isModifierKey ) {
                         // AR out - send out missing PRESSED
-                        super.sendKeyEvent(KeyEvent.EVENT_KEY_PRESSED, modifiers | InputEvent.AUTOREPEAT_MASK, keyCode, keySym, keyChar);
+                        res = super.sendKeyEvent(KeyEvent.EVENT_KEY_PRESSED, modifiers | InputEvent.AUTOREPEAT_MASK, keyCode, keySym, keyChar);
                     }
                     setKeyPressed(keyCode, false);
                     repeatedKey = KeyEvent.VK_UNDEFINED;
                 }
-                super.sendKeyEvent(KeyEvent.EVENT_KEY_RELEASED, modifiers, keyCode, keySym, keyChar);
+                res = res && super.sendKeyEvent(KeyEvent.EVENT_KEY_RELEASED, modifiers, keyCode, keySym, keyChar);
                 break;
             case KeyEvent.EVENT_KEY_PRESSED:
                 if( !handlePressTypedAutoRepeat(isModifierKey, modifiers, keyCode, keySym, keyChar) ) {
-                    super.sendKeyEvent(KeyEvent.EVENT_KEY_PRESSED, modifiers, keyCode, keySym, keyChar);
+                    res = super.sendKeyEvent(KeyEvent.EVENT_KEY_PRESSED, modifiers, keyCode, keySym, keyChar);
                 }
                 break;
         }
+        return res;
     }
 
     @Override
-    public final void enqueueKeyEvent(final boolean wait, final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
+    public final boolean enqueueKeyEvent(final boolean wait, final short eventType, final int modifiers, final short keyCode, final short keySym, final char keyChar) {
         throw new InternalError("XXX: Adapt Java Code to Native Code Changes");
     }
 
