@@ -79,6 +79,11 @@ static void dumpOutput(const char *prefix, Display *dpy, int screen_idx, XRRScre
         isPrim = 1;
     }
     XRROutputInfo * xrrOutputInfo = XRRGetOutputInfo (dpy, resources, output);
+    if(NULL ==  xrrOutputInfo) {
+        fprintf(stderr, "%s: Output[%d]: id %#lx, info not available, primary %d\n", 
+            prefix, outputIdx, output, isPrim);
+        return;
+    }
     fprintf(stderr, "%s: Output[%d]: id %#lx, crtx 0x%lX, name %s (%d), %lux%lu, ncrtc %d, nclone %d, nmode %d (preferred %d), primary %d\n", 
         prefix, outputIdx, output, xrrOutputInfo->crtc, SAFE_STRING(xrrOutputInfo->name), xrrOutputInfo->nameLen, 
         xrrOutputInfo->mm_width, xrrOutputInfo->mm_height,
@@ -458,7 +463,7 @@ JNIEXPORT jintArray JNICALL Java_jogamp_newt_driver_x11_RandR13_getMonitorDevice
 {
     Display * dpy = (Display *) (intptr_t) display;
     XRRScreenResources *resources = (XRRScreenResources *) (intptr_t) screenResources;
-    RRCrtc crtc = findRRCrtc( resources, (RRCrtc)(intptr_t)crt_id );
+    RRCrtc crtc = findRRCrtc( resources, (RRCrtc)(intptr_t)crt_id ); // just re-validation
     if( 0 == crtc ) {
         // n/a
         return NULL;
@@ -482,6 +487,9 @@ JNIEXPORT jintArray JNICALL Java_jogamp_newt_driver_x11_RandR13_getMonitorDevice
         isPrimary = 1;
     }
     XRROutputInfo * xrrOutputInfo = XRRGetOutputInfo (dpy, resources, output);
+    if(NULL ==  xrrOutputInfo) {
+        return NULL; // n/a
+    }
     int numModes = xrrOutputInfo->nmode;
 
     jsize propCount = MIN_MONITOR_DEVICE_PROPERTIES - 1 + numModes;
@@ -520,6 +528,48 @@ JNIEXPORT jintArray JNICALL Java_jogamp_newt_driver_x11_RandR13_getMonitorDevice
     return properties;
 }
 
+/*
+ * Class:     jogamp_newt_driver_x11_RandR13
+ * Method:    getMonitorName0
+ * Signature: (JJJJ)Ljava/lang/String;
+ */
+JNIEXPORT jstring JNICALL Java_jogamp_newt_driver_x11_RandR13_getMonitorName0
+  (JNIEnv *env, jclass clazz, jlong display, jlong screenResources, jlong monitorInfo, jint crt_id)
+{
+    Display * dpy = (Display *) (intptr_t) display;
+    XRRScreenResources *resources = (XRRScreenResources *) (intptr_t) screenResources;
+    RRCrtc crtc = findRRCrtc( resources, (RRCrtc)(intptr_t)crt_id ); // just re-validation
+    if( 0 == crtc ) {
+        // n/a
+        return NULL;
+    }
+    XRRCrtcInfo *xrrCrtcInfo = (XRRCrtcInfo *) (intptr_t) monitorInfo;
+    if( NULL == xrrCrtcInfo ) {
+        // n/a
+        return NULL;
+    }
+
+    RROutput output = xrrCrtcInfo->outputs[0];
+    XRROutputInfo * xrrOutputInfo = XRRGetOutputInfo (dpy, resources, output);
+    if(NULL ==  xrrOutputInfo) {
+        return NULL; // n/a
+    }
+    int name_len = xrrOutputInfo->nameLen;
+    char* name = xrrOutputInfo->name;
+    if( NULL == name || 0 == name_len ) {
+        // n/a
+        return NULL;
+    }
+    char * name_copy = strndup(name, name_len);
+    XRRFreeOutputInfo (xrrOutputInfo);
+    if( NULL == name_copy ) {
+        return NULL;
+    }
+    jstring res = (*env)->NewStringUTF(env, name_copy);
+    free(name_copy);
+    return res;
+}
+
 /*
  * Class:     jogamp_newt_driver_x11_RandR13
  * Method:    setMonitorMode0
@@ -534,7 +584,7 @@ JNIEXPORT jboolean JNICALL Java_jogamp_newt_driver_x11_RandR13_setMonitorMode0
     Display * dpy = (Display *) (intptr_t) display;
     Window root = RootWindow(dpy, (int)screen_idx);
     XRRScreenResources *resources = (XRRScreenResources *) (intptr_t) screenResources;
-    RRCrtc crtc = findRRCrtc( resources, (RRCrtc)(intptr_t)crt_id );
+    RRCrtc crtc = findRRCrtc( resources, (RRCrtc)(intptr_t)crt_id ); // just re-validation
     if( 0 == crtc ) {
         // n/a
         DBG_PRINT("RandR13_setMonitorMode0.0: n/a: resources %p (%d), crt_id %#lx \n", 
