@@ -43,6 +43,7 @@ import java.util.*;
     private static final List<String> glueLibNames;
     static {
         SecurityUtil.doPrivileged(new PrivilegedAction<Object>() {
+            @Override
             public Object run() {
                 Platform.initSingleton();
 
@@ -99,6 +100,9 @@ import java.util.*;
         return new ArrayList<List<String>>(); // None
     }
 
+    @Override
+    public List<String> getSymbolForToolLibPath() { return null; }
+
     @Override
     public final List<String> getToolGetProcAddressFuncNameList() {
         return null;
