@@ -27,6 +27,9 @@
  */
 package jogamp.opengl.oculusvr;
 
+import com.jogamp.math.FovHVHalves;
+import com.jogamp.math.Vec3f;
+import com.jogamp.math.geom.Frustum;
 import com.jogamp.nativewindow.util.Dimension;
 import com.jogamp.nativewindow.util.DimensionImmutable;
 import com.jogamp.nativewindow.util.PointImmutable;
@@ -39,9 +42,6 @@ import com.jogamp.oculusvr.ovrFovPort;
 import com.jogamp.oculusvr.ovrHmdDesc;
 import com.jogamp.oculusvr.ovrSizei;
 import com.jogamp.oculusvr.ovrTrackingState;
-import com.jogamp.opengl.math.FovHVHalves;
-import com.jogamp.opengl.math.Vec3f;
-import com.jogamp.opengl.math.geom.Frustum;
 import com.jogamp.opengl.util.stereo.LocationSensorParameter;
 import com.jogamp.opengl.util.stereo.StereoDevice;
 import com.jogamp.opengl.util.stereo.StereoDeviceFactory;
@@ -87,13 +87,13 @@ public class OVRStereoDevice implements StereoDevice {
         this.deviceIndex = deviceIndex;
         this.hmdDesc = hmdDesc;
 
-        final ovrFovPort[] defaultOVREyeFov = hmdDesc.getDefaultEyeFov(0, new ovrFovPort[ovrHmdDesc.getEyeRenderOrderArrayLength()]);
+        final ovrFovPort[] defaultOVREyeFov = hmdDesc.getDefaultEyeFov(0, new ovrFovPort[ovrHmdDesc.getEyeRenderOrderElemCount()], 0, ovrHmdDesc.getEyeRenderOrderElemCount());
         defaultEyeFov = new FovHVHalves[defaultOVREyeFov.length];
         for(int i=0; i<defaultEyeFov.length; i++) {
             defaultEyeFov[i] = OVRUtil.getFovHV(defaultOVREyeFov[i]);
         }
-        eyeRenderOrder = new int[ovrHmdDesc.getEyeRenderOrderArrayLength()];
-        hmdDesc.getEyeRenderOrder(0, eyeRenderOrder);
+        eyeRenderOrder = new int[ovrHmdDesc.getEyeRenderOrderElemCount()];
+        hmdDesc.getEyeRenderOrder(0, eyeRenderOrder, 0, eyeRenderOrder.length);
         supportedDistortionBits = OVRUtil.ovrDistCaps2DistBits(hmdDesc.getDistortionCaps());
         recommendedDistortionBits = supportedDistortionBits; //  & ~StereoDeviceRenderer.DISTORTION_TIMEWARP;
         minimumDistortionBits = StereoDeviceRenderer.DISTORTION_BARREL;
