@@ -20,6 +20,7 @@ import com.jogamp.opengl.GLCapabilities;
 import com.jogamp.opengl.GLEventListener;
 import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.awt.GLCanvas;
+import com.jogamp.common.os.Clock;
 import com.jogamp.common.util.InterruptSource;
 import com.jogamp.junit.util.JunitTracer;
 import com.jogamp.newt.awt.NewtCanvasAWT;
@@ -73,7 +74,8 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
   private final long frameRatePeriod = 1000000000L / TARGET_FPS;
   private int frameCount;
 
-  public void init() {
+  @Override
+public void init() {
     setSize(APPLET_WIDTH, APPLET_HEIGHT);
     setPreferredSize(new Dimension(APPLET_WIDTH, APPLET_HEIGHT));
     width = APPLET_WIDTH;
@@ -81,27 +83,30 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
     initGL();
   }
 
-  public void start() {
+  @Override
+public void start() {
     initDraw();
     thread = new InterruptSource.Thread(null, this, "Animation Thread");
     thread.start();
   }
 
-  public void run() {
+  @Override
+public void run() {
     int noDelays = 0;
     // Number of frames with a delay of 0 ms before the
     // animation thread yields to other running threads.
     final int NO_DELAYS_PER_YIELD = 15;
     final int TIMEOUT_SECONDS = 2;
 
-    long beforeTime = System.nanoTime();
+    long beforeTime = Clock.currentNanos();
     long overSleepTime = 0L;
 
     frameCount = 1;
     while (Thread.currentThread() == thread) {
       if (frameCount == 1) {
         EventQueue.invokeLater(new Runnable() {
-          public void run() {
+          @Override
+        public void run() {
             requestFocusInWindow();
           }
         });
@@ -117,7 +122,7 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
         e.printStackTrace();
       }
 
-      final long afterTime = System.nanoTime();
+      final long afterTime = Clock.currentNanos();
       final long timeDiff = afterTime - beforeTime;
       final long sleepTime = (frameRatePeriod - timeDiff) - overSleepTime;
       if (sleepTime > 0) {  // some time left in this cycle
@@ -125,7 +130,7 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
           Thread.sleep(sleepTime / 1000000L, (int) (sleepTime % 1000000L));
           noDelays = 0;  // Got some sleep, not delaying anymore
         } catch (final InterruptedException ex) { }
-        overSleepTime = (System.nanoTime() - afterTime) - sleepTime;
+        overSleepTime = (Clock.currentNanos() - afterTime) - sleepTime;
       } else {    // sleepTime <= 0; the frame took longer than the period
         overSleepTime = 0L;
         noDelays++;
@@ -134,7 +139,7 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
           noDelays = 0;
         }
       }
-      beforeTime = System.nanoTime();
+      beforeTime = Clock.currentNanos();
     }
   }
 
@@ -262,7 +267,8 @@ public class Bug735Inv2AppletAWT extends Applet implements Runnable {
 
     // This allows to close the frame.
     frame.addWindowListener(new WindowAdapter() {
-      public void windowClosing(final WindowEvent e) {
+      @Override
+    public void windowClosing(final WindowEvent e) {
         System.exit(0);
       }
     });
