@@ -1,5 +1,5 @@
 /**
- * Copyright 2011-2023 JogAmp Community. All rights reserved.
+ * Copyright 2011-2024 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -42,7 +42,6 @@ import com.jogamp.opengl.GLDrawable;
 import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLProfile;
 import com.jogamp.opengl.JoglVersion;
-import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
 
 import com.jogamp.common.os.Clock;
 import com.jogamp.common.util.IOUtil;
@@ -54,13 +53,13 @@ import com.jogamp.graph.curve.opengl.RegionRenderer;
 import com.jogamp.graph.curve.opengl.TextRegionUtil;
 import com.jogamp.graph.font.Font;
 import com.jogamp.graph.font.FontFactory;
-import com.jogamp.graph.geom.plane.AffineTransform;
-import com.jogamp.opengl.math.Vec4f;
-import com.jogamp.opengl.math.geom.AABBox;
+import com.jogamp.math.Vec4f;
+import com.jogamp.math.geom.AABBox;
+import com.jogamp.math.geom.plane.AffineTransform;
+import com.jogamp.math.util.PMVMatrix4f;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
 import com.jogamp.opengl.test.junit.util.NEWTGLContext;
 import com.jogamp.opengl.util.GLReadBufferUtil;
-import com.jogamp.opengl.util.PMVMatrix;
 
 
 /**
@@ -242,7 +241,9 @@ public class PerfTextRendererNEWT00 {
         final GLReadBufferUtil screenshot = new GLReadBufferUtil(false, false);
 
         final RegionRenderer renderer = RegionRenderer.create(RegionRenderer.defaultBlendEnable, RegionRenderer.defaultBlendDisable);
-        renderer.setHintMask(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED);
+        renderer.setHintBits(RenderState.BITHINT_GLOBAL_DEPTH_TEST_ENABLED);
+        renderer.setAAQuality(Region.DEFAULT_AA_QUALITY);
+        renderer.setSampleCount(sampleCount);
 
         final GLRegion region = GLRegion.create(gl.getGLProfile(), renderModes, null, font, text);
         System.err.println("Region post ctor w/ pre-calculated buffer size");
@@ -277,7 +278,6 @@ public class PerfTextRendererNEWT00 {
             renderer.reshapeOrtho(drawable.getSurfaceWidth(), drawable.getSurfaceHeight(), 0.1f, 1000.0f);
             final int z0 = -1000;
 
-            final int[] sampleCountIO = { sampleCount };
             // display
             gl.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT);
             region.clear(gl);
@@ -305,12 +305,11 @@ public class PerfTextRendererNEWT00 {
             final float dx = 0;
             final float dy = drawable.getSurfaceHeight() - 2 * fontScale * font.getLineHeight();
 
-            final PMVMatrix pmv = renderer.getMatrix();
-            pmv.glMatrixMode(GLMatrixFunc.GL_MODELVIEW);
-            pmv.glLoadIdentity();
-            pmv.glTranslatef(dx, dy, z0);
-            pmv.glScalef(fontScale, fontScale, 1f);
-            region.draw(gl, renderer, sampleCountIO);
+            final PMVMatrix4f pmv = renderer.getMatrix();
+            pmv.loadMvIdentity();
+            pmv.translateMv(dx, dy, z0);
+            pmv.scaleMv(fontScale, fontScale, 1f);
+            region.draw(gl, renderer);
             final long t5 = Clock.currentNanos(); // text added to region
             if( null != perf ) {
                 final long td_graph = t3 - t2;
