@@ -39,7 +39,9 @@ import com.jogamp.opengl.awt.GLCanvas;
 
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.GLTestUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 
@@ -106,6 +108,8 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
         final Frame f1 = new Frame();
         final Animator animator = new Animator();
         final GearsES2 g1 = new GearsES2(0);
+        // g1.setUseMappedBuffers(useMappedBuffers);
+        g1.setValidateBuffers(true);
         final GLCanvas c1 = createGLCanvas(f1, 0, 0, g1);
         animator.add(c1);
 
@@ -135,19 +139,19 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
 
         Thread.sleep(1000/60*10); // wait ~10 frames giving a chance to create (blocking until master share is valid)
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         final GLContext ctx1 = c1.getContext();
@@ -223,9 +227,9 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
                 }
             }});
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c3, false, null));
     }
 
     @Test
@@ -242,6 +246,9 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
         final Frame f1 = new Frame();
         final Animator a1 = new Animator();
         final GearsES2 g1 = new GearsES2(0);
+        g1.setSyncObjects(g1); // this is master, since rendered we must use it as sync
+        // g1.setUseMappedBuffers(useMappedBuffers);
+        g1.setValidateBuffers(true);
         final GLCanvas c1 = createGLCanvas(f1, 0, 0, g1);
         a1.add(c1);
         a1.start();
@@ -282,19 +289,19 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
 
         Thread.sleep(1000/60*10); // wait ~10 frames giving a chance to create (blocking until master share is valid)
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c1, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c1, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c1, true, null));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c2, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c2, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c2, true, null));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true));
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c3, true, null));
+        Assert.assertTrue(AWTRobotUtil.waitForVisible(c3, true, null));
+        Assert.assertTrue(GLTestUtil.waitForContextCreated(c3, true, null));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         final GLContext ctx1 = c1.getContext();
@@ -374,9 +381,9 @@ public class TestSharedContextVBOES2AWT3 extends UITestCase {
                 }
             }});
 
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c1, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c2, false));
-        Assert.assertTrue(AWTRobotUtil.waitForRealized(c3, false));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c1, false, null));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c2, false, null));
+        Assert.assertTrue(GLTestUtil.waitForRealized(c3, false, null));
     }
 
     static long duration = 1000; // ms
