@@ -37,8 +37,9 @@ import com.jogamp.opengl.GLProfile;
 import com.jogamp.nativewindow.swt.SWTAccessor;
 import com.jogamp.opengl.util.Animator;
 import com.jogamp.opengl.swt.GLCanvas;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.GLTestUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.SWTTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 
@@ -70,6 +71,28 @@ import org.junit.runners.MethodSorters;
  * to initialize all in order, since otherwise the <i>test main thread</i>
  * itself blocks SWT GLCanvas creation ..
  * </p>
+ * <p>
+ * On MacOS 12+ and SWT 4.26 while not using AWT (-Djava.awt.headless=true, -XstartOnFirstThread),
+ * we recently get the following Exception from SWT (suppressed):
+ * <pre>
+java.lang.NullPointerException: Cannot invoke "org.eclipse.swt.internal.cocoa.NSGraphicsContext.saveGraphicsState()" because "context" is null
+        at org.eclipse.swt.widgets.Widget.drawRect(Widget.java:764)
+        at org.eclipse.swt.widgets.Canvas.drawRect(Canvas.java:170)
+        at org.eclipse.swt.widgets.Display.windowProc(Display.java:6287)
+        at org.eclipse.swt.internal.cocoa.OS.objc_msgSendSuper(Native Method)
+        at org.eclipse.swt.widgets.Display.applicationNextEventMatchingMask(Display.java:5565)
+        at org.eclipse.swt.widgets.Display.applicationProc(Display.java:5965)
+        at org.eclipse.swt.internal.cocoa.OS.objc_msgSend(Native Method)
+        at org.eclipse.swt.internal.cocoa.NSApplication.nextEventMatchingMask(NSApplication.java:92)
+        at org.eclipse.swt.widgets.Display.readAndDispatch(Display.java:3983)
+        at com.jogamp.opengl.test.junit.util.SWTTestUtil$WaitAction$1.run(SWTTestUtil.java:52)
+        at org.eclipse.swt.widgets.Synchronizer.syncExec(Synchronizer.java:183)
+        at org.eclipse.swt.widgets.Display.syncExec(Display.java:5250)
+        at com.jogamp.opengl.test.junit.util.SWTTestUtil$WaitAction.run(SWTTestUtil.java:63)
+        at com.jogamp.opengl.test.junit.jogl.acore.TestSharedContextVBOES2SWT3.test02AsyncEachAnimator(TestSharedContextVBOES2SWT3.java:376)
+ * </pre>
+ * This is not observed if running using AWT (-Djava.awt.headless=false).
+ * </p>
  */
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class TestSharedContextVBOES2SWT3 extends UITestCase {
@@ -101,12 +124,14 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
 
     @Before
     public void init() {
-        SWTAccessor.invoke(true, new Runnable() {
+        SWTAccessor.invokeOnOSTKThread(true, new Runnable() {
+            @Override
             public void run() {
                 display = new Display();
                 Assert.assertNotNull( display );
             }});
         display.syncExec(new Runnable() {
+            @Override
             public void run() {
                 shell1 = new Shell( display );
                 shell1.setLayout( new FillLayout() );
@@ -136,18 +161,20 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         Assert.assertNotNull( composite3 );
         try {
             display.syncExec(new Runnable() {
-               public void run() {
-                composite3.dispose();
-                shell3.dispose();
-                composite2.dispose();
-                shell2.dispose();
-                composite1.dispose();
-                shell1.dispose();
-               }});
-            SWTAccessor.invoke(true, new Runnable() {
-               public void run() {
-                display.dispose();
-               }});
+                @Override
+                public void run() {
+                    composite3.dispose();
+                    shell3.dispose();
+                    composite2.dispose();
+                    shell2.dispose();
+                    composite1.dispose();
+                    shell1.dispose();
+                }});
+            SWTAccessor.invokeOnOSTKThread(true, new Runnable() {
+                @Override
+                public void run() {
+                    display.dispose();
+                }});
         }
         catch( final Throwable throwable ) {
             throwable.printStackTrace();
@@ -167,11 +194,12 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         Assert.assertNotNull( glCanvas );
         glCanvas.addGLEventListener(gears);
         display.syncExec(new Runnable() {
-           public void run() {
-            shell.setText("SWT GLCanvas Shared Gears Test");
-            shell.setSize( width, height);
-            shell.setLocation(x, y);
-           } } );
+            @Override
+            public void run() {
+                shell.setText("SWT GLCanvas Shared Gears Test");
+                shell.setSize( width, height);
+                shell.setLocation(x, y);
+            } } );
         return glCanvas;
     }
 
@@ -179,6 +207,8 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
     public void test01SyncedOneAnimator() throws InterruptedException {
         final Animator animator = new Animator();
         final GearsES2 g1 = new GearsES2(0);
+        // g1.setUseMappedBuffers(useMappedBuffers);
+        g1.setValidateBuffers(true);
         final GLCanvas c1 = createGLCanvas(shell1, composite1, 0, 0, g1);
         animator.add(c1);
 
@@ -195,22 +225,26 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         animator.add(c3);
 
         display.syncExec(new Runnable() {
-           public void run() {
-            shell1.open();  // master ..
-            shell2.open();  // shall wait until f1 is ready
-            shell3.open();  // shall wait until f1 is ready
-           } } );
+            @Override
+            public void run() {
+                shell1.open();  // master ..
+                shell2.open();  // shall wait until f1 is ready
+                shell3.open();  // shall wait until f1 is ready
+            } } );
+        final long t0 = System.currentTimeMillis();
         animator.start(); // kicks off GLContext .. and hence gears of f2 + f3 completion
 
-        Thread.sleep(1000/60*10); // wait ~10 frames giving a chance to create (blocking until master share is valid)
-
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        final SWTTestUtil.WaitAction waitAction = new SWTTestUtil.WaitAction(display, true, 200);
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c1, true, waitAction));
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c1, true, waitAction));
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c2, true, waitAction));
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c2, true, waitAction));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c3, true, waitAction));
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c3, true, waitAction));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
         final GLContext ctx1 = c1.getContext();
@@ -236,42 +270,50 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         Assert.assertTrue("Gears2 is not shared", g2.usesSharedGears());
         Assert.assertTrue("Gears3 is not shared", g3.usesSharedGears());
 
-        try {
-            Thread.sleep(duration);
-        } catch(final Exception e) {
-            e.printStackTrace();
+        while(animator.isAnimating() && System.currentTimeMillis()-t0<duration) {
+            waitAction.run();
         }
+
         // Stopped animator allows native windowing system 'repaint' event
         // to trigger GLAD 'display'
         animator.stop();
         Assert.assertEquals(false, animator.isAnimating());
 
         display.syncExec(new Runnable() {
-           public void run() {
-            c3.dispose();
-            c2.dispose();
-            c1.dispose();
-           } } );
+            @Override
+            public void run() {
+                c3.dispose();
+                c2.dispose();
+                c1.dispose();
+            } } );
     }
 
     @Test
     public void test02AsyncEachAnimator() throws InterruptedException {
         final Animator a1 = new Animator();
         final GearsES2 g1 = new GearsES2(0);
+        g1.setSyncObjects(g1); // this is master, since rendered we must use it as sync
+        // g1.setUseMappedBuffers(useMappedBuffers);
+        g1.setValidateBuffers(true);
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 0.0");
         final GLCanvas c1 = createGLCanvas(shell1, composite1, 0, 0, g1);
         a1.add(c1);
         display.syncExec(new Runnable() {
-           public void run() {
-            shell1.open();
-           } } );
+            @Override
+            public void run() {
+                shell1.open();
+            } } );
         a1.start();
 
-
-        Thread.sleep(1000/60*10); // wait ~10 frames giving a chance to create (blocking until master share is valid)
-
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c1, true));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 1.0");
+        final SWTTestUtil.WaitAction waitAction = new SWTTestUtil.WaitAction(display, true, 200);
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c1, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 1.1");
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c1, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 1.2");
         Assert.assertTrue("Gears1 not initialized", g1.waitForInit(true));
 
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 2.0");
         final Animator a2 = new Animator();
         final GearsES2 g2 = new GearsES2(0);
         g2.setSharedGears(g1);
@@ -279,13 +321,13 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         c2.setSharedAutoDrawable(c1);
         a2.add(c2);
         display.syncExec(new Runnable() {
-           public void run() {
-            shell2.open();
-           } } );
+            @Override
+            public void run() {
+                shell2.open();
+            } } );
         a2.start();
 
-        Thread.sleep(200); // wait a while ..
-
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 3.0");
         final Animator a3 = new Animator();
         final GearsES2 g3 = new GearsES2(0);
         g3.setSharedGears(g1);
@@ -293,17 +335,29 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         c3.setSharedAutoDrawable(c1);
         a3.add(c3);
         display.syncExec(new Runnable() {
-           public void run() {
-            shell3.open();
-           } } );
+            @Override
+            public void run() {
+                shell3.open();
+            } } );
         a3.start();
 
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c2, true));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 4.0");
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c2, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 4.1: Exception "+(null != waitAction.getException(true)));
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c2, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 4.2: Exception "+(null != waitAction.getException(true)));
         Assert.assertTrue("Gears2 not initialized", g2.waitForInit(true));
 
-        Assert.assertTrue(AWTRobotUtil.waitForContextCreated(c3, true));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 5.0: Exception "+(null != waitAction.getException(true)));
+        Assert.assertEquals(true,  GLTestUtil.waitForRealized(c3, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 5.1: Exception "+(null != waitAction.getException(true)));
+        Assert.assertEquals(true,  GLTestUtil.waitForContextCreated(c3, true, waitAction));
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 5.2: Exception "+(null != waitAction.getException(true)));
         Assert.assertTrue("Gears3 not initialized", g3.waitForInit(true));
 
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 6.0: Exception "+(null != waitAction.getException(true)));
+        final long t0 = System.currentTimeMillis();
+
         final GLContext ctx1 = c1.getContext();
         final GLContext ctx2 = c2.getContext();
         final GLContext ctx3 = c3.getContext();
@@ -327,11 +381,10 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         Assert.assertTrue("Gears2 is not shared", g2.usesSharedGears());
         Assert.assertTrue("Gears3 is not shared", g3.usesSharedGears());
 
-        try {
-            Thread.sleep(duration);
-        } catch(final Exception e) {
-            e.printStackTrace();
+        while(System.currentTimeMillis()-t0<duration) {
+            waitAction.run();
         }
+        System.err.println("TestSharedContextVBOES2SWT3.test02AsyncEachAnimator: 8.0: Exception "+(null != waitAction.getException(true)));
         // Stopped animator allows native windowing system 'repaint' event
         // to trigger GLAD 'display'
         a1.stop();
@@ -342,14 +395,15 @@ public class TestSharedContextVBOES2SWT3 extends UITestCase {
         Assert.assertEquals(false, a3.isAnimating());
 
         display.syncExec(new Runnable() {
-           public void run() {
-            c3.dispose();
-            c2.dispose();
-            c1.dispose();
-           } } );
+            @Override
+            public void run() {
+                c3.dispose();
+                c2.dispose();
+                c1.dispose();
+            } } );
     }
 
-    static long duration = 1000; // ms
+    static long duration = 2000; // ms
 
     public static void main(final String args[]) {
         for(int i=0; i<args.length; i++) {
