@@ -248,10 +248,10 @@ public class TestBug816OSXCALayerPos01AWT extends UITestCase {
                 }
                 frame.setVisible(true);
             }});
-        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas1, true));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas1, true, null));
         if( twoCanvas ) {
-            Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas2, true));
+            Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas2, true, null));
         }
 
         animator.start();
