@@ -1,5 +1,5 @@
 /**
- * Copyright 2013 JogAmp Community. All rights reserved.
+ * Copyright 2013-2023 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -98,6 +98,7 @@ public class TestGLJPanelResize01AWT extends UITestCase {
         System.err.println("Frame size: cols x rows "+cols+"x"+rows);
         try {
             javax.swing.SwingUtilities.invokeAndWait(new Runnable() {
+                @Override
                 public void run() {
                     frame[0] = new JFrame();
                     frame[0].setLocation(64, 64);
@@ -144,6 +145,7 @@ public class TestGLJPanelResize01AWT extends UITestCase {
         }
         try {
             SwingUtilities.invokeAndWait(new Runnable() {
+                    @Override
                     public void run() {
                         frame[0].dispose();
                     } } );
@@ -160,7 +162,7 @@ public class TestGLJPanelResize01AWT extends UITestCase {
         canvas.setMinimumSize(size);
         canvas.setDoubleBuffered(useSwingDoubleBuffer);
         final GearsES2 g = new GearsES2(0);
-        g.setVerbose(false);
+        // g.setVerbose(false);
         canvas.addGLEventListener(g);
         return canvas;
     }
