@@ -33,6 +33,7 @@ import java.lang.reflect.InvocationTargetException;
 
 import com.jogamp.junit.util.JunitTracer;
 import com.jogamp.newt.Display;
+import com.jogamp.newt.MonitorDevice;
 import com.jogamp.newt.NewtFactory;
 import com.jogamp.newt.Screen;
 import com.jogamp.newt.Window;
@@ -227,9 +228,8 @@ public class TestGearsES2NEWT extends UITestCase {
             });
         }
 
-        final Animator animator = useAnimator ? new Animator() : null;
+        final Animator animator = useAnimator ? new Animator(0 /* w/o AWT */) : null;
         if( useAnimator ) {
-            animator.setModeBits(false, AnimatorBase.MODE_EXPECT_AWT_RENDERING_THREAD);
             animator.setExclusiveContext(exclusiveContext);
         }
 
@@ -351,6 +351,10 @@ public class TestGearsES2NEWT extends UITestCase {
                            valReqSurfacePixelScale[0]+"x"+valReqSurfacePixelScale[1]+" (val) -> "+
                            hasSurfacePixelScale1[0]+"x"+hasSurfacePixelScale1[1]+" (has)");
         NEWTDemoListener.setTitle(glWindow);
+        {
+            final MonitorDevice mm = glWindow.getMainMonitor();
+            System.err.println("Monitor: "+mm);
+        }
 
         snap.setMakeSnapshot();
 
