@@ -7,6 +7,9 @@ import java.io.PrintStream;
 import java.nio.FloatBuffer;
 import java.util.Random;
 
+import com.jogamp.math.FloatUtil;
+import com.jogamp.math.Matrix4f;
+import com.jogamp.math.Vec3f;
 import com.jogamp.opengl.DebugGL4;
 import com.jogamp.opengl.GL;
 import com.jogamp.opengl.GL2ES2;
@@ -17,8 +20,6 @@ import com.jogamp.opengl.GLException;
 import com.jogamp.opengl.GLUniformData;
 import com.jogamp.opengl.TraceGL4;
 import com.jogamp.opengl.fixedfunc.GLMatrixFunc;
-import com.jogamp.opengl.math.Matrix4f;
-import com.jogamp.opengl.math.Vec3f;
 import com.jogamp.opengl.util.GLArrayDataClient;
 import com.jogamp.opengl.util.GLArrayDataServer;
 import com.jogamp.opengl.util.PMVMatrix;
@@ -103,7 +104,7 @@ public class TriangleInstancedRendererWithShaderState implements GLEventListener
 
 		initShader(gl);
         projectionMatrix = new PMVMatrix();
-		projectionMatrixUniform = new GLUniformData("mgl_PMatrix", 4, 4, projectionMatrix.getSyncPMat());
+		projectionMatrixUniform = new GLUniformData("mgl_PMatrix", 4, 4, projectionMatrix.getSyncP());
 		st.ownUniform(projectionMatrixUniform);
         if(!st.uniform(gl, projectionMatrixUniform)) {
             throw new GLException("Error setting mgl_PMatrix in shader: " + st);
@@ -169,7 +170,7 @@ public class TriangleInstancedRendererWithShaderState implements GLEventListener
 
 		projectionMatrix.glMatrixMode(GLMatrixFunc.GL_PROJECTION);
 		projectionMatrix.glLoadIdentity();
-		projectionMatrix.gluPerspective(45, aspect, 0.001f, 20f);
+		projectionMatrix.gluPerspective(FloatUtil.QUARTER_PI, aspect, 0.001f, 20f);
 		projectionMatrix.gluLookAt(new Vec3f(0, 0, -10), new Vec3f(0, 0, 0), new Vec3f(0, 1, 0));
 	}
 
