@@ -60,6 +60,9 @@ import com.jogamp.newt.opengl.GLWindow ;
 import com.jogamp.newt.swt.NewtCanvasSWT ;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
+import com.jogamp.opengl.test.junit.util.SWTTestUtil;
+import com.jogamp.opengl.test.junit.util.TestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -74,6 +77,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
     {
         float r = 0f, g = 0f, b = 0f;
 
+        @Override
         public void init( final GLAutoDrawable drawable )
         {
             final GL2 gl = drawable.getGL().getGL2() ;
@@ -85,6 +89,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             gl.glBlendFunc( GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA ) ;
         }
 
+        @Override
         public void reshape( final GLAutoDrawable drawable, final int x, final int y, final int width, final int height )
         {
             // System.err.println( ">>>>>>>> reshape " + x + ", " + y + ", " + width + ", " +height ) ;
@@ -100,6 +105,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             gl.glLoadIdentity() ;
         }
 
+        @Override
         public void display( final GLAutoDrawable drawable )
         {
             // System.err.println( ">>>> display" ) ;
@@ -137,6 +143,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             }
         }
 
+        @Override
         public void dispose( final GLAutoDrawable drawable )
         {
         }
@@ -155,6 +162,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
         }
 
         final Runnable resizeAction = new Runnable() {
+            @Override
             public void run()
             {
                 System.err.println("[R-i shallStop "+shallStop+", disposed "+_shell.isDisposed()+"]");
@@ -174,6 +182,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
                 ++_n ;
             }  };
 
+        @Override
         public void run()
         {
             // The problem was originally observed by grabbing the lower right
@@ -221,6 +230,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             _display = display;
         }
 
+        @Override
         public void run()
         {
             System.err.println("[K-0]");
@@ -256,13 +266,15 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
         volatile com.jogamp.newt.Display swtNewtDisplay = null;
 
         public void init() {
-            SWTAccessor.invoke(true, new Runnable() {
+            SWTAccessor.invokeOnOSTKThread(true, new Runnable() {
+                @Override
                 public void run() {
                     display = new Display();
                     Assert.assertNotNull( display );
                 }});
 
             display.syncExec(new Runnable() {
+                @Override
                 public void run() {
                     shell = new Shell( display );
                     Assert.assertNotNull( shell );
@@ -280,14 +292,16 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             Assert.assertNotNull( composite );
             try {
                 display.syncExec(new Runnable() {
-                   public void run() {
-                    composite.dispose();
-                    shell.dispose();
-                   }});
-                SWTAccessor.invoke(true, new Runnable() {
-                   public void run() {
-                    display.dispose();
-                   }});
+                    @Override
+                    public void run() {
+                        composite.dispose();
+                        shell.dispose();
+                    }});
+                SWTAccessor.invokeOnOSTKThread(true, new Runnable() {
+                    @Override
+                    public void run() {
+                        display.dispose();
+                    }});
             }
             catch( final Throwable throwable ) {
                 throwable.printStackTrace();
@@ -298,31 +312,46 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
             shell = null;
             composite = null;
         }
-        class WaitAction implements Runnable {
-            private final long sleepMS;
-
-            WaitAction(final long sleepMS) {
-                this.sleepMS = sleepMS;
-            }
-            public void run() {
-                if( !display.readAndDispatch() ) {
-                    // blocks on linux .. display.sleep();
-                    try {
-                        Thread.sleep(sleepMS);
-                    } catch (final InterruptedException e) { }
-                }
-            }
-        }
-        final WaitAction awtRobotWaitAction = new WaitAction(AWTRobotUtil.TIME_SLICE);
     }
 
     @Test
     public void test() throws InterruptedException, AWTException, InvocationTargetException {
-        final Robot robot = new Robot();
+        /**
+         * Use AWT _after_ SWT (4.26) or else .. (on GTK/X11, OpenJDK 17):
+         *   (java:786260): GLib-GObject-WARNING **: 04:32:25.870: cannot register existing type 'GdkDisplayManager'
+         *   (java:786260): GLib-CRITICAL **: 04:32:25.870: g_once_init_leave: assertion 'result != 0' failed
+         *   (java:786260): GLib-GObject-CRITICAL **: 04:32:25.870: g_object_new_with_properties: assertion 'G_TYPE_IS_OBJECT (object_type)' failed
+         * SIGSEGV (0xb) at pc=0x00007faabf781b30, pid=786260, tid=786261
+         *
+         * JRE version: OpenJDK Runtime Environment (17.0.4+8) (build 17.0.4+8-Debian-1deb11u1)
+         * Java VM: OpenJDK 64-Bit Server VM (17.0.4+8-Debian-1deb11u1, mixed mode, sharing, tiered, compressed oops, compressed class ptrs, g1 gc, linux-amd64)
+         * Problematic frame:
+         * C  [libgdk-3.so.0+0x38b30]  gdk_display_manager_get_default_display+0x0
+         *
+         * Native frames: (J=compiled Java code, j=interpreted, Vv=VM code, C=native code)
+         * C  [libgdk-3.so.0+0x38b30]  gdk_display_manager_get_default_display+0x0
+         * j  org.eclipse.swt.internal.gtk.OS.isX11()Z+6
+         * j  org.eclipse.swt.internal.gtk.OS.<clinit>()V+1929
+         * v  ~StubRoutines::call_stub
+         * V  [libjvm.so+0x81b665]
+         * V  [libjvm.so+0x7faa0c]
+         * V  [libjvm.so+0x7fae23]
+         * V  [libjvm.so+0x8eb27e]
+         * V  [libjvm.so+0x8ee3c4]  JVM_FindClassFromCaller+0x124
+         * C  [libjava.so+0xd138]  Java_java_lang_Class_forName0+0xc8
+         * j  java.lang.Class.forName0(Ljava/lang/String;ZLjava/lang/ClassLoader;Ljava/lang/Class;)Ljava/lang/Class;+0 java.base@17.0.4
+         * j  java.lang.Class.forName(Ljava/lang/String;ZLjava/lang/ClassLoader;)Ljava/lang/Class;+43 java.base@17.0.4
+         * j  com.jogamp.common.util.ReflectionUtil.getClassImpl(Ljava/lang/String;ZLjava/lang/ClassLoader;)Ljava/lang/Class;+209
+         * j  com.jogamp.common.util.ReflectionUtil.getClass(Ljava/lang/String;ZLjava/lang/ClassLoader;)Ljava/lang/Class;+3
+         * j  com.jogamp.nativewindow.swt.SWTAccessor.<clinit>()V+785
+         */
+        // final Robot robot = new Robot();
 
         final SWT_DSC dsc = new SWT_DSC();
         dsc.init();
 
+        final Robot robot = new Robot();
+
         final GLWindow glWindow;
         {
             final GLProfile gl2Profile = GLProfile.get( GLProfile.GL2 ) ;
@@ -344,12 +373,17 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
         }
 
         dsc.display.syncExec( new Runnable() {
+            @Override
             public void run() {
                dsc.shell.setText( "NewtCanvasSWT Resize Bug Demo" ) ;
                dsc.shell.setSize( 400, 450 ) ;
                dsc.shell.open() ;
             } } );
-        Assert.assertTrue("GLWindow didn't become visible natively!", AWTRobotUtil.waitForRealized(glWindow, dsc.awtRobotWaitAction, true));
+
+        final SWTTestUtil.WaitAction awtRobotWaitAction = new SWTTestUtil.WaitAction(dsc.display, true, TestUtil.TIME_SLICE);
+        final SWTTestUtil.WaitAction generalWaitAction = new SWTTestUtil.WaitAction(dsc.display, true, 10);
+
+        Assert.assertTrue("GLWindow didn't become visible natively!", NewtTestUtil.waitForRealized(glWindow, true, awtRobotWaitAction));
 
         AWTRobotUtil.requestFocus(robot, glWindow, false);
         AWTRobotUtil.setMouseToClientLocation(robot, glWindow, 50, 50);
@@ -396,15 +430,7 @@ public class TestNewtCanvasSWTBug628ResizeDeadlockAWT extends UITestCase {
 
         try {
             while( !shallStop && !dsc.display.isDisposed() ) {
-                dsc.display.syncExec( new Runnable() {
-                    public void run() {
-                       if( !dsc.display.isDisposed() && !dsc.display.readAndDispatch() && !shallStop ) {
-                           // blocks on linux .. dsc.display.sleep();
-                           try {
-                               Thread.sleep(10);
-                           } catch (final InterruptedException ie) { ie.printStackTrace(); }
-                       }
-                    } } );
+                generalWaitAction.run();
             }
         } catch (final Exception e0) {
             e0.printStackTrace();
