@@ -165,9 +165,9 @@ public class TestTiledPrintingGearsAWT extends TiledPrintingAWTBase  {
                 frame.pack();
                 frame.setVisible(true);
             }});
-        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas1, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas2, true));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas1, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas2, true, null));
 
         animator.setUpdateFPSFrames(60, System.err);
         animator.start();
