@@ -47,8 +47,9 @@ import com.jogamp.newt.Window;
 import com.jogamp.newt.awt.NewtCanvasAWT;
 import com.jogamp.newt.opengl.GLWindow;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
+import com.jogamp.opengl.test.junit.util.TestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil.WindowClosingListener;
 
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class TestCloseNewtAWT extends UITestCase {
@@ -112,11 +113,12 @@ public class TestCloseNewtAWT extends UITestCase {
                 frame.setVisible(true);
             }
         });
-        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(newtWindow, true));
-        final WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
+        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true, null));
+        final GLWindow obj = newtWindow;
+        Assert.assertEquals(true,  NewtTestUtil.waitForRealized(obj, true, null));
+        final TestUtil.WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
 
-        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, true, closingListener));
+        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, true, closingListener, null));
     }
 
     public static void main(final String[] args) {
