@@ -46,8 +46,9 @@ import com.jogamp.opengl.awt.GLCanvas;
 
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
 import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
+import com.jogamp.opengl.test.junit.util.TestUtil;
+import com.jogamp.opengl.test.junit.util.TestUtil.WindowClosingListener;
 import com.jogamp.opengl.test.junit.util.UITestCase;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil.WindowClosingListener;
 
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class TestWindowClosingProtocol01AWT extends UITestCase {
@@ -55,7 +56,7 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
     @Test
     public void testCloseFrameGLCanvas() throws InterruptedException, InvocationTargetException {
         final Frame frame = new Frame("testCloseFrameGLCanvas AWT");
-        final WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
+        final TestUtil.WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
         final GLProfile glp = GLProfile.getGL2ES2();
         final GLCapabilities caps = new GLCapabilities(glp);
         final GLCanvas glCanvas = new GLCanvas(caps);
@@ -68,8 +69,8 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
                 frame.validate();
                 frame.setVisible(true);
             } });
-        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true, null));
 
         //
         // close with op: DO_NOTHING_ON_CLOSE -> NOP (default)
@@ -77,7 +78,7 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
         WindowClosingMode op = glCanvas.getDefaultCloseOperation();
         Assert.assertEquals(WindowClosingMode.DO_NOTHING_ON_CLOSE, op);
 
-        Assert.assertEquals(true, AWTRobotUtil.closeWindow(frame, false, closingListener)); // nop
+        Assert.assertEquals(true, AWTRobotUtil.closeWindow(frame, false, closingListener, null)); // nop
         Thread.sleep(100);
         Assert.assertEquals(true,  frame.isDisplayable());
         Assert.assertEquals(true,  frame.isVisible());
@@ -95,7 +96,7 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
 
         Thread.sleep(300);
 
-        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, false, closingListener)); // no frame close, but GLCanvas's GL resources will be destroyed
+        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, false, closingListener, null)); // no frame close, but GLCanvas's GL resources will be destroyed
         Thread.sleep(100);
         Assert.assertEquals(true,  frame.isDisplayable());
         Assert.assertEquals(true,  frame.isVisible());
@@ -115,7 +116,7 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
     @Test
     public void testCloseJFrameGLCanvas() throws InterruptedException, InvocationTargetException {
         final JFrame frame = new JFrame("testCloseJFrameGLCanvas AWT");
-        final WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
+        final TestUtil.WindowClosingListener closingListener = AWTRobotUtil.addClosingListener(frame);
 
         final GLProfile glp = GLProfile.getGL2ES2();
         final GLCapabilities caps = new GLCapabilities(glp);
@@ -129,8 +130,8 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
                 frame.validate();
                 frame.setVisible(true);
             } });
-        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true));
+        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true, null));
 
         //
         // close with op: DO_NOTHING_ON_CLOSE -> NOP / HIDE (default)
@@ -141,8 +142,8 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
 
         Thread.sleep(300);
 
-        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, false, closingListener)); // hide
-        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, false)); // hide -> invisible
+        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, false, closingListener, null)); // hide
+        Assert.assertEquals(true,  AWTRobotUtil.waitForVisible(frame, false, null)); // hide -> invisible
         Assert.assertEquals(true,  frame.isDisplayable());
         Assert.assertEquals(false, frame.isVisible());
         Assert.assertEquals(true,  glCanvas.isValid());
@@ -152,8 +153,8 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
             public void run() {
                 frame.setVisible(true);
             } });
-        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true));
+        Assert.assertEquals(true, AWTRobotUtil.waitForVisible(frame, true, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, true, null));
         Assert.assertEquals(true,  frame.isDisplayable());
         Assert.assertEquals(true,  frame.isVisible());
 
@@ -165,8 +166,8 @@ public class TestWindowClosingProtocol01AWT extends UITestCase {
         op = glCanvas.getDefaultCloseOperation();
         Assert.assertEquals(WindowClosingMode.DISPOSE_ON_CLOSE, op);
 
-        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, true, closingListener));
-        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, false));
+        Assert.assertEquals(true,  AWTRobotUtil.closeWindow(frame, true, closingListener, null));
+        Assert.assertEquals(true,  AWTRobotUtil.waitForRealized(glCanvas, false, null));
         Assert.assertEquals(false, frame.isDisplayable());
         Assert.assertEquals(false, glCanvas.isValid());
         Assert.assertEquals(false, glCanvas.isDisplayable());
