@@ -49,8 +49,8 @@ import com.jogamp.newt.MonitorMode;
 import com.jogamp.newt.opengl.GLWindow;
 import com.jogamp.newt.util.MonitorModeUtil;
 import com.jogamp.opengl.test.junit.jogl.demos.es2.GearsES2;
-import com.jogamp.opengl.test.junit.util.AWTRobotUtil;
 import com.jogamp.opengl.test.junit.util.MiscUtils;
+import com.jogamp.opengl.test.junit.util.NewtTestUtil;
 import com.jogamp.opengl.test.junit.util.UITestCase;
 import com.jogamp.opengl.util.Animator;
 
@@ -105,7 +105,7 @@ public class TestScreenMode01bNEWT extends UITestCase {
     static void destroyWindow(final Window window) throws InterruptedException {
         if(null!=window) {
             window.destroy();
-            Assert.assertTrue(AWTRobotUtil.waitForRealized(window, false));
+            Assert.assertTrue(NewtTestUtil.waitForRealized(window, false, null));
         }
     }
 
@@ -121,7 +121,7 @@ public class TestScreenMode01bNEWT extends UITestCase {
             testScreenModeChangeImpl(screen, monitorVp.getX(), monitorVp.getY());
         } finally {
             screen.removeReference();
-            Assert.assertTrue(AWTRobotUtil.waitForRealized(screen, false));
+            Assert.assertTrue(NewtTestUtil.waitForRealized(screen, false, null));
         }
     }
 
@@ -141,7 +141,7 @@ public class TestScreenMode01bNEWT extends UITestCase {
             testScreenModeChangeImpl(screen, monitorVp.getX(), monitorVp.getY());
         } finally {
             screen.removeReference();
-            Assert.assertTrue(AWTRobotUtil.waitForRealized(screen, false));
+            Assert.assertTrue(NewtTestUtil.waitForRealized(screen, false, null));
         }
     }
 
